(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14677,        490]*)
(*NotebookOutlinePosition[     15752,        527]*)
(*  CellTagsIndexPosition[     15708,        523]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Technology"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hal Varian\nJanuary 1992"], "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Cobb-Douglas Production Functions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"We use Cobb-Douglas production functions a lot in our examples, so it makes \
sense to get a good idea of what they look like.   Here is the simplest \
example:\n"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"ContourPlot[x1 x2,{x1,0,10},{x2,0,10},ContourShading->False]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Let's see what happens to the CD production function as we vary the \
parameter ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Do[\n\tContourPlot[x1^a x2^(1-a),{x1,0,10},{x2,0,10},\n\t\
ContourShading->False,\n\tContourSmoothing->True,\n\tAxesLabel->{\"Factor \
1\",\"Factor 2\"},\n\tPlotPoints->12],\n   {a,0.1,0.9,0.1}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["After ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " has generated this set of graphs, click on the second bracket from the \
left---the one containing the entire set of graphs---and press Command-y (or \
Alt-y, depending on your system).  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " will animate the set of graphs and you can see how the shape of the \
isoquants changes as you change the parameter ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Leontieff Production Function"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Here's a picture of the Leontieff production function.  Again, we  we \
change the parameter ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Do[\nContourPlot[Min[a x1,(10-a)x2],{x1,1,10},{x2,1,10},\n\
ContourShading->False,\nPlotPoints->50],{a,1,9}]\n"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Here's what happens if we have two Leontieff technologies.  We can put any \
amount of input into one or the other"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"ContourPlot[Min[x1,2 x2]+Min[2 x1,x2],{x1,1,10},{x2,1,10},\n\
ContourShading->False,PlotPoints->50]\n"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Let's try to build up something that looks like a Cobb-Douglas production \
function out of Leontieff functions.   To do this, we want to pick the \
parameters of the Leontieff function to lie on the CD isoquant.  First we'll \
generate a list of plots, and then we'll superimpose them:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"listOfPlots=\nTable[\n\tContourPlot[Min[a x1, x2/a], {x1,1,10},{x2,1,10},\n\t\
ContourShading->False, Contours->{4}],\n{a,.5,2,.1}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Show[listOfPlots]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "It's a little ragged, but the idea is there.  If you want to make it look \
nicer, set ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotPoints->50",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " or so in the original commands.  However, this will take a lot longer to \
plot.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Technical Rate of Substitution"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "We saw in the text that the Technical Rate of Substitution of the \
Cobb-Douglas production function is given by",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" (x2/x1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".   Let's draw lines with this slope that pass through each point on the \
curve  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1*x2=10",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\n\nThe formula for a straight line  with coordinates ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(y1,y2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" that passes through a point ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(x1,x2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is \n               ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" y2 = x2 + m (x1 - y1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\nAt a given point on the isoquant,",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" (x1,x2), ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["the  slope of the tangent line is ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x2/x1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\nMaking this substitution gives us\n                ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" y2 = x2 - (x2/x1)(x1 - y1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\nFinally, since the points",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" (x1,x2) ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["are all on the isoquant",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[", x2=10/x1.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Making this substitution gives us\n                ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" y2 = 10/x1 - (10/x1^2)(x1 - y1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".\nWe want to plot this family of lines for a number of values of  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["In order to do this we will use the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" function ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Table .  We  ca",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n construct a list of  10 of these straight lines as follow",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Table[10/x1 - (10/x1^2)(x1 - y1),{x1,1,10}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now we just feed this list of functions into the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["command.  However, before we do that we need to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Evaluate",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" the table, to convert it to a form that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" can understand.\nWe also set the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["AspectRatio",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotRange",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" so the graph will look nice.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Plot[Evaluate[Table[10/x1 - (10/x1^2)(y1-x1),{x1,1,20}]],\n\
{y1,0,10},AspectRatio->1,PlotRange->{{0,10},{0,10}}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Notice how the set of tangent lines \"reconstruct\" the isoquant ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1*x2=10.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  "The family of  tangent lines completely describes the shape of the \
isoquant.  This simply geometric fact will have profound consequences later \
on.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["Homothetic and Homogeneous Functions"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "\nIt is easy to recognize a homothetic function since the formula for it's \
tangent lines will only depend on ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1/x2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".  This is just another way of saying that the TRS is constant along lines \
through the origin.  This is trivial to verify for the Cobb-Douglas \
production function, so let's look at the CES production function.  It is \
convenient to define the CES production function first.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["CES[x1_,x2_, rho_] := (x1^rho + x2^rho)^(1/rho)"], "Input",
  AspectRatioFixed->True],

Cell[TextData["The TRS for this function is given by"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["D[CES[x1,x2,rho],x1]/D[CES[x1,x2,rho],x2]"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
x1^(-1 + rho)*x2^(1 - rho)\
\>", 
"\<\
  -1 + rho   1 - rho
x1         x2\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[TextData[{
  StyleBox["It is easy to see that this is just ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(x2/x1)^(1-rho)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["", "Input",
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["The CES production function"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\nLet's take a look at how the CES production function changes as the \
parameter changes.  First we generate a series of plots of the function, then \
we animate it by choosing a plot and hitting Control-y."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Do[\n\tContourPlot[(.5 x1^rho + .5 x2^rho)^(1/rho),{x1,1,10},{x2,1,10},\n\t\
ContourShading->False,\n\tPlotPoints->20],\n   {rho,1.05,-10,-1}]"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 365},
WindowMargins->{{36, Automatic}, {15, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
MacintoshSystemPageSetup->"\<\
AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 2, 70, "Title",
  Evaluatable->False],
Cell[1819, 55, 105, 2, 70, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1947, 59, 110, 2, 70, "Section",
  Evaluatable->False],
Cell[2060, 63, 237, 5, 70, "Text",
  Evaluatable->False],
Cell[2300, 70, 114, 2, 70, "Input"],
Cell[2417, 74, 414, 16, 70, "Text",
  Evaluatable->False],
Cell[2834, 92, 248, 4, 70, "Input"],
Cell[3085, 98, 924, 30, 70, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[4041, 130, 110, 2, 70, "Section",
  Evaluatable->False],
Cell[4154, 134, 428, 16, 70, "Text",
  Evaluatable->False],
Cell[4585, 152, 164, 3, 70, "Input"],
Cell[4752, 157, 189, 4, 70, "Text",
  Evaluatable->False],
Cell[4944, 163, 155, 3, 70, "Input"],
Cell[5102, 168, 361, 6, 70, "Text",
  Evaluatable->False],
Cell[5466, 176, 185, 3, 70, "Input"],
Cell[5654, 181, 70, 1, 70, "Input"],
Cell[5727, 184, 517, 18, 70, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[6276, 204, 111, 2, 70, "Section",
  Evaluatable->False],
Cell[6390, 208, 3670, 124, 70, "Text",
  Evaluatable->False],
Cell[10063, 334, 96, 1, 70, "Input"],
Cell[10162, 337, 1324, 46, 70, "Text",
  Evaluatable->False],
Cell[11489, 385, 167, 3, 70, "Input"],
Cell[11659, 390, 561, 18, 70, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[12252, 410, 113, 2, 70, "Section",
  Evaluatable->False],
Cell[12368, 414, 729, 20, 70, "Text",
  Evaluatable->False],
Cell[13100, 436, 100, 1, 70, "Input"],
Cell[13203, 439, 111, 2, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13337, 443, 94, 1, 70, "Input"],
Cell[13434, 446, 163, 8, 70, "Output",
  Evaluatable->False]
}, Closed]],
Cell[13609, 456, 381, 14, 70, "Text",
  Evaluatable->False],
Cell[13993, 472, 43, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14068, 475, 104, 2, 70, "Section",
  Evaluatable->False],
Cell[14175, 479, 282, 5, 70, "Text",
  Evaluatable->False],
Cell[14460, 486, 196, 3, 70, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
