(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21680,        752]*)
(*NotebookOutlinePosition[     22735,        788]*)
(*  CellTagsIndexPosition[     22691,        784]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Profit Maximization"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hal R. Varian\nJanuary, 1992"], "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Maximizing profit"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Let's find the profit-maximizing choice for the production function ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x^(1/2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\nWe start by defining the production function",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["f[x_] := x^(1/2)"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Profits as a function of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["are",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Profit[x_,p_,w_] := p f[x] - w x"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Let's plot this for",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" p=w=1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Plot[Profit[x,1,1],{x,.001,1}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"In  order to find the profit-maximizing level of input, we solve for that x \
that makes the derivative of profit equal to zero:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Solve[D[Profit[x,1,1],x]==0,x]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note that the solutions to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Solve",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " are a list of solutions; in this case the list has only one element in \
it: ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/4",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".   In order to find the input demand function, we can do this same \
calculation for arbitrary values of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["p",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Solve[D[Profit[x,p,w],x]==0,x]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Of course, we should always check the second-order condition to make sure \
that we really have a maximum."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["D[Profit[x,p,w],{x,2}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["When ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is positive, this is certainly a negative number",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["The profit function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Finally, we want to calculate the profit function for this technology.  In \
order to do that,  we take the the expression for profit and substitute the \
optimized value of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  In ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[", you substitute for a value by using the notation ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["/.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Profit[x,p,w]/.{x->p^2/(4 w^2)}"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["The Cobb-Douglas profit function"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"We can do the same sort of thing when there are several factors.  For \
example, consider  the Cobb-Douglas technology"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["f[x1_,x2_] := x1^(1/4) x2^(1/4)"], "Input",
  AspectRatioFixed->True],

Cell[TextData["The profit function is"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Profit[x1_,x2_,p_,w1_,w2_] := p f[x1,x2] - w1 x1 - w2 x2"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We can plot profits as a function of the inputs, with prices all fixed at 1. \
 We will do both a 3-D plot and a contour plot:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Plot3D[Profit[x1,x2,20,1,1],{x1,0.01,80},{x2,0.01,80},Lighting->False,\n\
ViewPoint->{2.107, -2.506, 0.854}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"ContourPlot[Profit[x1,x2,20,1,1],{x1,0.01,80},{x2,0.01,80},\n\
ContourShading->False]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Let's solve for the optimal value of the two factor inputs.  Just as before, \
we take the derivatives with respect to each input, set them equal to zero, \
and then solve the resulting system of equations.  This time we'll give the \
solution a name so we can use it later"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"solution=Solve[{D[Profit[x1,x2,1,1,1],x1]==0,\n\
D[Profit[x1,x2,1,1,1],x2]==0},{x1,x2}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Notice that we have two solutions; only the positive one makes economic \
sense.  We select it by using [[1]] to take the first element of the list."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["solution[[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We can do the same calculation for arbitrary values of p, w1 and w2.  Since \
we know that we'll get two answers, we'll select the first one right off the \
bat and call it solution"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"solution = Solve[{D[Profit[x1,x2,p,w1,w2],x1]==0, \n\
D[Profit[x1,x2,p,w1,w2],x2]==0},\n{x1,x2}][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["The profit function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"To find the profit function, we just substitute this solution back into the \
definition of profit:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Profit[x1,x2,p,w1,w2]/.%"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData[
"\<\
(p*(p^2/(w1^(1/2)*w2^(3/2)))^(1/4)*(p^2/(w1^(3/2)*w2^(1/2)))^(1/4))/
   4 - p^2/(8*w1^(1/2)*w2^(1/2))\
\>", "\<\
          2                   2
         p        1/4        p        1/4
p (--------------)    (--------------)
              3/2        3/2                         2
   Sqrt[w1] w2         w1    Sqrt[w2]               p
----------------------------------------- - -------------------
                    4                       8 Sqrt[w1] Sqrt[w2]\
\>"], 
  "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["Comparative statics"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Once we have solved for an optimal choice, we want to see how it responds \
to changes in the economic environment.   In the current context that means \
examining how the demand functions respond to changes in prices.\n\nIn ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " the easiest way to do is is by using total derivatives.  Consider a \
function ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["g[x,a]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".  The first-order condition that a maximum value of x must satisfy is",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["D[g[x,a],x]==0"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Totally differentiating this gives us"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Dt[D[g[x,a],x]]==0"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
Dt[a]*Derivative[1, 1][g][x, a] + 
   Dt[x]*Derivative[2, 0][g][x, a] == 0\
\>", 
"\<\
       (1,1)                (2,0)
Dt[a] g     [x, a] + Dt[x] g     [x, a] == 0\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[TextData[{
  StyleBox["Note the notation ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" uses.  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dt[a]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" would be written ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["da",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" in standard notation. \n    ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(1,1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["                                  2                         2\n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["g     [x,a]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" would be ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["d g(x,a)/dx",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[", the second derivative. \n\nSolving this for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["dx=Dt[x]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" gives us the answer we are after",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Solve[Dt[D[g[x,a],x]]==0,Dt[x]]"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
{{Dt[x] -> -((Dt[a]*Derivative[1, 1][g][x, a])/
       Derivative[2, 0][g][x, a])}}\
\>", "\<\
                    (1,1)
             Dt[a] g     [x, a]
{{Dt[x] -> -(------------------)}}
                 (2,0)
                g     [x, a]\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[TextData[{
  StyleBox[
  "In classical notation, this simply says that\n                             \
     ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["                      g ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox["12",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[
  "\n                                   dx =    -da   ---\n                   \
                                    g",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold"],
  StyleBox["11",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->"Subscript"}]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Since we know that the denominator of this expression is negative because of \
the second-order conditions, the sign of the entire expression is determined \
by the mixed partial derivative in the numerator."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Profit maximization with one input"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Let's apply this to a profit maximization problem.  We have"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Profit[x_,p_,w_] := p f[x] - w x"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Take the derivative of this expression and solve for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dt[x]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Solve[Dt[D[Profit[x,p,w],x]]==0,Dt[x]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["This expression shows us that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["decrease when ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" increases and increases when ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["p",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" increases.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["Maximization with several variables"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The same logic applies if there are several variables.  The only tricky part \
is that the second order condition is messier.  Suppose that we have a \
function f[x1,x2,a] and we want to know how x1 and x2 respond to changes in \
a.  The FOCs are"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["FOC={D[f[x1,x2,a],x1]==0, D[f[x1,x2,a],x2]==0}"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Take the derivative of this list with respect to a and solve for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dt[x1]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dt[x2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["]",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Solve[Dt[FOC],{Dt[x1],Dt[x2]}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "This expression is somewhat messy.  Luckily, the denominators in this \
expression are simply the determinant of the Hessian matrix of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["f.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  We will verify this by direct calculation:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"hess={{D[f[x1,x2,a],x1,x1], D[f[x1,x2,a],x1,x2]},\n      \
{D[f[x1,x2,a],x2,x1], D[f[x1,x2,a],x2,x2]}}"], "Input",
  AspectRatioFixed->True],

Cell[TextData["MatrixForm[hess]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["detHess=-Det[hess]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now substitute solve for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dt[x1]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dt[x2]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" again, substituting back into the total differential",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Solve[Dt[FOC],{Dt[x1],Dt[x2]}]/.{detHess->HH} "], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Just as before, the response of the choice variable to the parameter depends \
on the mixed partial derivatives, and the sign of the denominator is \
determined automatically by the second order conditions."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Profit maximization with two factors"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Now let h[x1,x2] be the production function and totally differentiate the \
FOCs"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"solution= Solve[{Dt[D[h[x1,x2]-w1 x1 - w2 x2,x1]]==0,\n       \
Dt[D[h[x1,x2]-w1 x1 - w2 x2,x2]]==0},\n       {Dt[x1],Dt[x2]}][[1]]"], "Input",\

  AspectRatioFixed->True],

Cell[TextData[
"The determinant of the Hessian is just as before; we'll compute it and \
substitute it in as before:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"detHess=-Det[{{D[h[x1,x2],x1,x1], D[h[x1,x2],x1,x2]},\n      \
{D[h[x1,x2],x2,x1], D[h[x1,x2],x2,x2]}}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["solution/.{detHess->HH}"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "This gives us a very simple expression for the comparative statics result: \
the change in ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is the change in ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " times the second derivative of the production function with respect to",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" x2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" plus the change in ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" times the  cross partial.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 509},
WindowMargins->{{20, Automatic}, {Automatic, 31}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060001T1T00000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 94, 2, 70, "Title",
  Evaluatable->False],
Cell[1828, 55, 109, 2, 70, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1960, 59, 94, 2, 70, "Section",
  Evaluatable->False],
Cell[2057, 63, 454, 15, 70, "Text",
  Evaluatable->False],
Cell[2514, 80, 69, 1, 70, "Input"],
Cell[2586, 83, 359, 14, 70, "Text",
  Evaluatable->False],
Cell[2948, 99, 85, 1, 70, "Input"],
Cell[3036, 102, 355, 14, 70, "Text",
  Evaluatable->False],
Cell[3394, 118, 83, 1, 70, "Input"],
Cell[3480, 121, 203, 4, 70, "Text",
  Evaluatable->False],
Cell[3686, 127, 83, 1, 70, "Input"],
Cell[3772, 130, 1123, 42, 70, "Text",
  Evaluatable->False],
Cell[4898, 174, 83, 1, 70, "Input"],
Cell[4984, 177, 181, 4, 70, "Text",
  Evaluatable->False],
Cell[5168, 183, 75, 1, 70, "Input"],
Cell[5246, 186, 384, 14, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5653, 202, 99, 2, 70, "Subsection",
  Evaluatable->False],
Cell[5755, 206, 857, 29, 70, "Text",
  Evaluatable->False],
Cell[6615, 237, 84, 1, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6740, 240, 109, 2, 70, "Section",
  Evaluatable->False],
Cell[6852, 244, 193, 4, 70, "Text",
  Evaluatable->False],
Cell[7048, 250, 84, 1, 70, "Input"],
Cell[7135, 253, 96, 2, 70, "Text",
  Evaluatable->False],
Cell[7234, 257, 110, 2, 70, "Input"],
Cell[7347, 261, 201, 4, 70, "Text",
  Evaluatable->False],
Cell[7551, 267, 162, 3, 70, "Input"],
Cell[7716, 272, 139, 3, 70, "Input"],
Cell[7858, 277, 348, 6, 70, "Text",
  Evaluatable->False],
Cell[8209, 285, 141, 3, 70, "Input"],
Cell[8353, 290, 226, 5, 70, "Text",
  Evaluatable->False],
Cell[8582, 297, 66, 1, 70, "Input"],
Cell[8651, 300, 256, 5, 70, "Text",
  Evaluatable->False],
Cell[8910, 307, 155, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[9088, 312, 99, 2, 70, "Subsection",
  Evaluatable->False],
Cell[9190, 316, 174, 4, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9387, 322, 77, 1, 70, "Input"],
Cell[9467, 325, 556, 15, 70, "Output",
  Evaluatable->False]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10073, 342, 96, 2, 70, "Section",
  Evaluatable->False],
Cell[10172, 346, 891, 27, 70, "Text",
  Evaluatable->False],
Cell[11066, 375, 67, 1, 70, "Input"],
Cell[11136, 378, 111, 2, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11270, 382, 71, 1, 70, "Input"],
Cell[11344, 385, 255, 9, 70, "Output",
  Evaluatable->False]
}, Open  ]],
Cell[11611, 396, 1681, 60, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13315, 458, 84, 1, 70, "Input"],
Cell[13402, 461, 329, 11, 70, "Output",
  Evaluatable->False]
}, Open  ]],
Cell[13743, 474, 852, 28, 70, "Text",
  Evaluatable->False],
Cell[14598, 504, 282, 5, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14903, 511, 114, 2, 70, "Subsection",
  Evaluatable->False],
Cell[15020, 515, 134, 3, 70, "Text",
  Evaluatable->False],
Cell[15157, 520, 85, 1, 70, "Input"],
Cell[15245, 523, 388, 14, 70, "Text",
  Evaluatable->False],
Cell[15636, 539, 91, 1, 70, "Input"],
Cell[15730, 542, 792, 30, 70, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16563, 574, 112, 2, 70, "Section",
  Evaluatable->False],
Cell[16678, 578, 321, 6, 70, "Text",
  Evaluatable->False],
Cell[17002, 586, 99, 1, 70, "Input"],
Cell[17104, 589, 601, 23, 70, "Text",
  Evaluatable->False],
Cell[17708, 614, 83, 1, 70, "Input"],
Cell[17794, 617, 513, 16, 70, "Text",
  Evaluatable->False],
Cell[18310, 635, 156, 3, 70, "Input"],
Cell[18469, 640, 69, 1, 70, "Input"],
Cell[18541, 643, 71, 1, 70, "Input"],
Cell[18615, 646, 611, 22, 70, "Text",
  Evaluatable->False],
Cell[19229, 670, 99, 1, 70, "Input"],
Cell[19331, 673, 281, 5, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19635, 680, 116, 2, 70, "Subsection",
  Evaluatable->False],
Cell[19754, 684, 155, 4, 70, "Text",
  Evaluatable->False],
Cell[19912, 690, 187, 4, 70, "Input"],
Cell[20102, 696, 175, 4, 70, "Text",
  Evaluatable->False],
Cell[20280, 702, 157, 3, 70, "Input"],
Cell[20440, 707, 76, 1, 70, "Input"],
Cell[20519, 710, 1131, 41, 70, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
