(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    297952,       5964]
NotebookOptionsPosition[    291486,       5738]
NotebookOutlinePosition[    292244,       5764]
CellTagsIndexPosition[    292201,       5761]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Profit Maximization", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal R. Varian
January, 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Maximizing profit", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Let's find the profit-maximizing choice for the production \
function ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x^(1/2)",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".\nWe start by defining the production function",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["f[x_] := x^(1/2)", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Profits as a function of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["are",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Profit[x_,p_,w_] := p f[x] - w x", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Let's plot this for",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" p=w=1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[":",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Plot[Profit[x,1,1],{x,.001,1}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1Xk4VV0bBnAhaVRSKZQkpKKEJNySSiVTZEglMjSb0kAyViJRkVCUSEim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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.001, 1}, {0., 0.24999997490665946`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5493628475159335`*^9}]
}, Open  ]],

Cell["\<\
In  order to find the profit-maximizing level of input, we solve for that x \
that makes the derivative of profit equal to zero:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solve[D[Profit[x,1,1],x]==0,x]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    FractionBox["1", "4"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5493628476459355`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Note that the solutions to ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Solve",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" are a list of solutions; in this case the list has only one \
element in it: ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["1/4",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".   In order to find the input demand function, we can do this \
same calculation for arbitrary values of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["w",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[":",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solve[D[Profit[x,p,w],x]==0,x]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    FractionBox[
     SuperscriptBox["p", "2"], 
     RowBox[{"4", " ", 
      SuperscriptBox["w", "2"]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5493628477159367`*^9}]
}, Open  ]],

Cell["\<\
Of course, we should always check the second-order condition to make sure \
that we really have a maximum.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["D[Profit[x,p,w],{x,2}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["p", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", 
     RowBox[{"3", "/", "2"}]]}]]}]], "Output",
 CellChangeTimes->{3.5493628477684374`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["When ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is positive, this is certainly a negative number",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["The profit function", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Finally, we want to calculate the profit function for this \
technology.  In order to do that,  we take the the expression for profit and \
substitute the optimized value of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x.",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["  In ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[", you substitute for a value by using the notation ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["/.",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Profit[x,p,w]/.{x->p^2/(4 w^2)}", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "p", " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox["p", "2"], 
     SuperscriptBox["w", "2"]]]}], "-", 
  FractionBox[
   SuperscriptBox["p", "2"], 
   RowBox[{"4", " ", "w"}]]}]], "Output",
 CellChangeTimes->{3.549362847829688*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Cobb-Douglas profit function", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
We can do the same sort of thing when there are several factors.  For \
example, consider  the Cobb-Douglas technology\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["f[x1_,x2_] := x1^(1/4) x2^(1/4)", "Input",
 AspectRatioFixed->True],

Cell["The profit function is", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Profit[x1_,x2_,p_,w1_,w2_] := p f[x1,x2] - w1 x1 - w2 x2", "Input",
 AspectRatioFixed->True],

Cell["\<\
We can plot profits as a function of the inputs, with prices all fixed at 1.  \
We will do both a 3-D plot and a contour plot:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Profit", "[", 
    RowBox[{"x1", ",", "x2", ",", "20", ",", "1", ",", "1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x1", ",", "0.01`", ",", "80"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x2", ",", "0.01`", ",", "80"}], "}"}], ",", 
   RowBox[{"Lighting", "\[Rule]", "None"}], ",", 
   RowBox[{"ViewPoint", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2.107`", ",", 
      RowBox[{"-", "2.506`"}], ",", "0.854`"}], "}"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJytnWV0VVe0toO7Q3DXoCEJxEiy48GDFgvuEIITpLhLcHcoroXi7m6F4JSi
BYq7c3tH5zNX7+Y7Pxjj+5WRh8XOOu/ytec7T/7mMTVbJXRycvoruZNTon9+
nrs6oNCfPw8N4Of2gqmGN1n/LWD7o4CyL+46W/DFU6vl7O6e3jp4vPy2czeL
KK81Pb5tiq1HArKcvd9xapGyyvOFZiz72vnDnqM+bl8Cb5T/jvdd8vO4p5Mr
fMezjrwbV7Vw4He8i1/KS4udQr7jJ16WyfvxWth3vPDyOm0it1T8jg+I6rtu
6aQq3/ErGRe++xxd/TueveWd+SsK1fiOH/Z/e6D2pJrf8a7ZUzz49q3Wd1z1
FV0XiZ78zs/1Zz8frOYepDrDXZaXG1vmRrCFzvAlh7pdyJoyxEJn+JWcUR61
RgRb6Aw/H3my++g5QRY6w69XeLIlUcdAC53h2QrV/5AqhWWhM3zKmLnTGnyr
YKEzPPbDmY9P1nlb6Ayv17VJKtcy5S10hrcsv9M/dpibhc7w2R+b53HtWspC
Z/idravTv5hb2EJn+NKCbrO+lsipuqOfJf2TcnD05Hd+TnpQpvGWZmGqM/xM
k+lvKuUPV53hP808VdApfbjqDE9zb9adFEPCVGf4df/irsUWh6rO8ALhB2ZV
HRGiOsMXtbwbd9wvWHWGdx7b19PjbKDqDI+wdnarEmqpzvChwzL3zRDipzrD
b1eygupc8Fad4f4Fup30CSyvOsN3R+dc1nK8m+qMTvRzdIYvlf7J/4efFj35
nZ8Fno49agVHqM7wkEMNy2TuH6E6w1dfmOSVxjVCdYa/bO/3LHh4uOoMrzYg
S/7cs8JUZ/j7jtWuxfQNVZ3hVZ5OOnHRI0R1hh99VMj75Kkg1RmevuWpFycr
B6rO8KI3VyZO2DpAdYYvm9J4S1iaCqoz/MTmtElHTfJSndHDrjOc8Y7O8HrS
P7XewtGT3/lZ7crG4ydeGZ3hxQsG3etx0egMH1jy6ePhdSNUZ/jZdi/KRowP
V53hjQo0+rR7YpjqDB+aeUKlyHahqjN839CvGZPkCVGd9fOOfxS/f1OQ6gyf
8D71U6dygaoz/Hnqcddj/ANUZ3jszhJTaj71VZ353Had4b/L/InO8LQy3tEZ
Tv/k78HRk9/5OXb4l+LNbxmd4c19Z1xMM9ToDO96dtjZmteMzvCE+eMCXT8Y
neGPrE/dNjw0OsNbr5pWo94mozM8aO/1x1HNg1Vn+IIuAW793hiddZ2ZfWtF
466W6gy/4Voo9o8tfqozn8+uM/yarEfoDL8h8yc6w1/JeEdn+CDpn9QD3kL0
5Hd+nvJJ+rRXiNEZPq5bic7vNhmd4aVmna3W/G+jM3xNg4rzar8wOsP3bQhf
s+Gs0Rk+1+evtwknGJ3hz85uO1DeI0h1hic5d79t4X1GZ3iOwr+7bOnmrzrz
Oew66+eT9R2d4QVlPUJneHWZP9EZfkbGOzrDu0j/pH7wMaKnluPvntvzfLq/
0RneZtvJlUdGGp3hvvEt+y9caHSG15r9c8EWk4zO8GST5my40MzoDC+1o2rR
7FmMzvDgzON7ll5vdIZvPnX/xYCORmfqa9cZPkn2S+gMXyjru877wj/IeoTO
8CiZP9EZnkDGOzrD6Z/UG95O9OR3fvqNHrdv7j2zDsKTDHxSrUs6ozM894p1
tc+mMzrr3+1x8+KuJ2Z+hu8peKXLqLVm3oDvGxl3rFZdozM847GWA46cNfMG
9bLrDO8p+090hsfIfgmd4VVlfUdn+BBZj9AZ/rfMn+gMXyXjHZ3h9E8+DzyR
6Mnv/CzaaVWnrRFmvwH3XHrnVdWfglVneOWfPgxpH2R0hper2rLB8HRGZ3j5
JyfqHxhm1kH44XMPrm7dY85j/H27zvC6sp9HZ3hF2X+iM/yY7JfQGc76js7w
NrIeobOWl/kTneF1ZLyjM5z+yeeEe4ue/K7POecd+bar2dfBE6S538K9vdnX
wcv4/XVkUZClOsPbn3zdKziBv+oMn5Ur7cBq1c1+g79j1xneXM5H6AwfLvt5
dIZnkP2n7pOEs19CZ3igrO/oDJ8t6xE6w5k/0RleQsY7OsPpn3x++LfU/+qp
9ZOf6fJFuK/vaKnO8P1d8rQNmu+vOsPjXrcq8aW02T/DW5fq0mPFeG/VmefZ
dYbPkPMmOsPvyvkIneHFZD+PznD2n+gMZ7+EzvCnsr6jM7y0rEfoDN8t8yc6
w8vLeEdnfY70T3TR85/oye9azx23BxyMraA6w8du/jT8aQ4f1Rl+MsFZjwTj
PFVn/p9dZ/ifcn5HZ7gl5010hi+X8xE6w9nPo7PeE8j+E53hiWW/hM7wEFnf
0Rm+V9YjnR+Fe8n8ic7wtjLe0Rk+QfonesHRk9/1+SkT92932lN11nNMy1NV
L0SWU535d7vO8AVyH4LO8L1yfkdn+Ek5b6IznPORnjeEX5f9PDrDs8n+E53h
W2W/hM7w9LK+o7Oez2Q9Qmf4DJk/0RneVsY7Ouvnkv6Jjvp80ZPf+Xl2aZ+2
q2+7WcuK18zv+iyp/nxwbuuO0vkrWOmb/l2ssEt+/Vm9XruZ/ptDtJzuU369
sa1P+yz6O/9eSDj/H9417bPrr8ZYymnPylFLJiWrGWz1Kje4Yv9pJbX8xvw9
78dutZTz/4p3bH+11aVQq9Ow1Jv+TuCh5afXL3/LNYulnPLBU9rN8vkr1Crw
/KfQGVu9tfyNm0+vvUnsr5zy8U7xH/q3DLUuNFgcHxIToOUfDoyoca+Gr3LK
1+sxo9WcoSHWwebvNryfFKTldwyqn/uEr5dyys8bEnx7eotgK0+23J+qdQrV
8kM+1HdLcd1DOeU3XMt3sUDGICv2VFDwkooRWv7VjfpvMgaXVU75sdcy3Es7
27J+H9x2zKdClbV86ZztBvV8X1w55S+86+w0N5W/VdIr7nwNp2pavkjWnM9q
5S2onPJNt6UY/vM6H+vA2ytpLkRHavkqTrkrX0jjrJzyTju6Ttzr4ml1Pve4
7IBrNUx/qPp55OiDbwLglPcIGtZwzEB3K9fqb3WKV6yl5e33z3ZOeZ7zvn7r
2JZdymg5OP2Q/genH9Kf4SM93DrPuJ1A+yE/B8e6u0YPCdf+Bq9/Puz1s/fh
2q/gNZYVjHx+JFz7Dzy25fqeuUqFaz9RHrh3csWIMO0P8Hr1q83uVDJU2x2+
KGpWjov3grV94VXGX3r1pl+QtiP8l43Oee+/s7S94Avmu1Rrtdlf2wvuGn+g
7YbavmZeE33avn5RONXUEtpelD/69VVh17Oeqj+ccc3/hzOumc/hKwZELK53
18yn8O7NP56pmLC8Pp92YB7g+XDmAf4/nPbiObTbHzI/8Bw48wPPgdO+PId2
fiTzho434cwbPAdOf+A59IudMp/wHDjzCc+B0394Dv1oqMwzPAfOPMNz4PQ3
nkO/ey3zD8+BM/9oPxZO/+Q59FNXmZd4Dpx5iefA6c88h35dTOYrngNnvuI5
cPo/z2EcRMo8xnPgzGM8B8544TmMm4Eyv/EcOPMbz4EzvngO44n5jefA7fOb
fb/EPGZ/Dn8XzjjV+ZH9hoxrysMZd/x/fk5I/DkwsGk5/Z3y9VxaHp+W1/Q3
6jXKNq8yH696t33ti/QhOj7hHmvKZb1yOVjHG7zt89sZquQK1vED/6tys33j
UwXpeIDXGl9wyds9lvZv+IZZzoNLTfTX/goPCnnt1qmxr/Y/eNiB/WULv/HU
/gSfdLbsT4mbeGj/gB9PPmdK+GJXbW/4jiVlmn6Ic1Hd7O9V4apPo8sfEiww
8ybzJfMkusH311p5KL6EWY/geZL3nHwpPkx10/dXC44k258zTHWD5+47oe/6
nKGqGzy0uvvKSX8Fq25wv3llRyYfE6S66fvEX/1GZ0wbqLrBR/fu4fLgsb/q
pu/vHiYp+XqCr+oGr1upwPA7ab1UN3jrafOX3+9g+g060a/g6ES/4v/D94lu
lEc/+pu+1xSeV/SkPLrepx9Kebiz6KzvbUXvmtI/9b2t8FyiP+Vph/XSb7Vd
hYdJu+h7a2kfS/oz5eEVpL0oT7uFSD+nPLyutCPlac8J0v8pDx8p7Ut52vmo
jAvKw+9Ku1Oe9t8q40XfEwuvJ/2B8vSL5TJeKA9vK/2EeQrOfMVzmF+bRC69
NHmFOQ/w702F83z+/V3EuxEfDpt7Qp3Xt658syLW0nMovM3ARAvzlTLnffjb
wxlPPNpm3uvAA4rsyh91zlvPofA6RXd8ej7Z3KfDq/7aJPGDLO56DoVfrXN2
3uJjpfUcCv/ou3NPv8xF9Ryq+5EXt44d9cij51D4zOQpkz2fnkrPofA5Fzq1
mZbswR79/6KTXR/Wh0qLimw8+Na8F9D9TsvHLh82mvtq+KR5numyfDX3qPAb
i6YXTvLJ3O/Bd4Xu2lZor7l3gg+qcrLE4Qbm3gn+teOxYiuWmfsQ+LQPS467
tzD3jPDyQSVKtnnhpfrA57TNlSmwfjnVR/dNN050cV1g+gd60E8oB0cfyqNT
W+k/lNc4DtGN8uj3TvoV5eHoSXl0taS/UV7fV4rOlEfvutIPKQ9Hf8rTDtWk
f1IeTrtQnva5Lv2W8nDai/K022fpz5SH046U1/fw0s8pD6d9Ka/3itL/KQ+n
3SlP+w+UcUF5OP0h2cDXC0JKZ9Cf1T5v/+fvW1b7LBm69E1cSHlMz8oNy3cP
ss4+Wjbxwj/7QfjesAoXmi0PsnI2zXtlWkw55eum1Pyzaa4g6/Tx9u2Ci/gq
b+n+/u8ZBQOtvTmufe7VyVLeqfnj81FHAqwcZ51CT1cMVn47yevyEbcrWN2H
FRlXqHCY8iJHtqV4v97bOu1TJb6PU0VT/v7v1R8Hl7eKPe+S+9y1ysoPr3ve
+pelbtbgJdNbFd1STXniAl0mf9hfyuq05o+L/scilb/ufO7jz28KWzlHvvj4
sHxN5dlnrNyU/UZO/R2dOtn0gUf08X/SaZypN/+ObpSD28uj61rRE46u6Knt
Ibp2Fj3h6HpX9ISjazHRU58vut4VPeHoelT0hKNrctFT21V0fS966ucSXfOJ
noNX9kywNtG7AH4Wq/mySt5cpj/B8y9vUzr8pLf+zr/D+Z397dPuWSb5eWTS
3/l/TctMH93gURYrus6YfXNn59LnRbd0im7q46vtAi/o/PTTjsG+Wp6/U/ev
NQ0XnQu08gxslKDYDhfl1T/dvOy5Lsjav/LDBGuK0Wnn3H3HB3YznOdtqjq7
YmbnUKtHltD8Typ5afk6S65uWrYy0Co2cMKvMxP4K69YfIj7t9GW1enNk3wF
r5v2n/ZxRovlTfytoyszteu9JUR58Y8F4j/U8LUKNPX+9cykcOVXK/81M0cC
L6tfliYfCneqpLxP1wZFd/TxsC4eHxrYr2JV5W+vlj0/96irlc2KD2mX0YyX
C66JFr67889+KceDtpkH1lCe6w+3j2vf/zMvv/k4ds+TmqqnxqMKp7x36qKH
P6/LZNpD9KFdKAdHf8rTbrQX5WmfSGkXOO1Au/BcOO1CedqntrSLjgtpH9pF
+7+0zwxpFzjtU1LaBU77XJd2gdM+/aRd4LTPe2kXOO1zWdoFTvvkk3ZBN9qB
dqE83LK1C+OpmYwjfuf/PZFxx7yGrod7vb7VKV+odaR54rxTf6n1XX/Q9paf
qXsfWlpverCW4/9Rnt/5mX7p16t1C5pzAeue1fnk0ZK9zH23xrUKZ9/DOW7p
X0VLXrgcrr9rHKZw9j38+yP/3Tlin5vy/Ducz8N+fs3cdr+FXzP3YPbzOP2V
zx08/OcGQ0r5qp7wiwsz5MzT3Uf7N39n2tDFb/q+Nfcb9ufTv3nOW+8Ni1Z1
99b1Bj5uX9P7eQK99Pxpfw7jgfIrqjernuNeeV2f4JUybXRb0Lacnkvtz2H8
UD7p5zdte5xz1/UMfmHn1SQPCrrpedX+HMYb5RM+regS1sJV1z945i2VptYo
VErPsd/F28v4pLxTSq/FFVu56HoJ/7NGk0eXxxbW8639OYxnykem+K3Mqbn5
dX2FL0gY4vbVI6eee+3PYfzr+hh+c1J8iky6HsNvRu/Jm6JvEj0P25/DfEH5
CsXTJt06/XYA6zf8dtYNnYqeer+Hc7L9Ocwv9vHLem/nnJ/tz2E+spdnf+Bo
fmCev/tl+Ytdg4yfgfFEef4/44bxwnMYN4wXnsO4sT+H8cG4oDzjw16ecUD/
pzzjwF6e/k4/1zh86e/28vRr+jPl6df28vRf+i3l6b/f1V/6Kf2T8vRTe3n6
45/SDylPf7SXp9/9Kf2N8vQ7e3n6l/3+mf71XXuxz7Rx+z02/YD5+VTVvK6H
vwXrumLvt/Qf+hXrGs/l/60OHWqNGeyu/ZX/R7+Fqy/DurWl+JJgfS58xdmo
m4szmTgA+7igHM9nfdF7PPl8J+Vz8Xkcraf8HXv9+blzZbaBOxaEaj35Oc+3
aqJLT8z7Sn6+OBCX4N7WCP2d9bTBnLQN7/eI0N/1fZlwnsu4q3t94YlOIebe
nPrcFt3Qhc/Lugln3WO9g7OOsX5pf5Z1ifVI+6GsM6wvcNYN1gs46wDzP5x5
nflc13WZpy3mZ+HMu/b+rPs6W39AP/oPOsLRk/lL22dsvOuuAybeHl710fVv
e89E6HPQc9Uf10aHrTTPoT2PN+s8ZmPLCN03U37UjoW+r5ZFWCnSV6/8uGuJ
78YX/39Cney5yn478Z0P7vTwoV6lqt/6zgfX7NOr2g+uP/rOB5d/RPoNjZ69
+M4Hl2h7zhsBPm+/88FNWDe26Lj6H7/zwb16cLvG5Npfv/PB+Wz3+r1etgSq
P/c4xZaMn+z0IaFy7mvqVph86PqpxMq5l3HKvC3aa4aJN7j/MWmdTovSfPfe
LVv/e3mSNK9l5Wif2n9UypTm+fJ7Vvl3eN6xVwPnFI20fFYfC4qO/Kz1351p
Stz8pZHWQOfcmQeu+qb8a5/KTYruqWG1alT0VLmWiczn2n/OvevLGtboLxvv
nklv6p9q7PGq+71rWfEl3xYtez35d3EUfA64t9SDeqmeUg/qBW8p9aBe8FFS
D+oFvyD1oF7291yr854p7DEohfJV8rv9PebuTrnjW1w298zwydIv7b4t+qXd
Z0S/tPti6Jd2Hwf90u47iJN+aY+Tp1/a47rpl/Y45KLSL+1xs/RLe5wn/dIe
l4gue0Qn+KdaJaNXzqhpZR46/mOfQkY3fuff7e+LR/m4jslScJn2Q/dhb6aO
G1PSuuNzdmqJ9AuUT679JtonaVmry+4kfaN67FOesPiyoM0LS1oNBmUu3eUn
U575a+LNpBlfjbysvPSuK5WTRpS1so/e3beq035zHtlVIWWho+7W5Hwl228s
cVr5nYmrZ5ccU94q5BXXPNwlXvmLQVUmv/TzsPwCwgpUrXzG7P9lPryRZ9ir
ksXvK1+8ofn5eDdPa/ybwHF3k19U3izTzCK5qntbCctcW/824TXl2w5OfnQi
UwVredbTNyrX/VN5oQ39+l4u4mP9PKD26M/u15VrXNnEXEU/dHxmzhGtb8zP
nsPPGpd39Mn6Wc38efpl4gV5r/hbJZ2aeMxzvqM88fa59weesaxEQ0Mn5T90
T/lv/V9erJfUsr7UODxy0jdTnn3qopqty53N8Vq5c9cVuRsMCLSKDjhZNme8
0WHU+wRn17sFWcXjHvs9b/FAeTKvvieyTQu2rtav1XL7azOfu1SqsTDb+yDr
wuVUWV/NfGjOy7Lf3dv0ZcqL1d6b/hCS0Wl25xBr9uLJ+/dVf6y8XOpDkRs/
hFhrP0xxvh37RPkiz+cH+kaFWSuODYyMe2F0y949ydH7D0KtSl+Xb3/07qly
9s3XS/l+9m5o5tU53+6ud2oWbm2f+ejtqWPPlX9b9CSg075w63K1p8WvlzHr
Uc6Mr2JGFK5oXd87e3WO5i+VexX9cPjx5QjroGdmz8cZDGf/feVG1/icBZ10
HP30cvqYtZGVrLuhkyL21n6l5dske9r14KhKlkv0jDN/jDf8SPW3hwo8rWxN
2/zoeew2017VsxdMW/FoZav5mdlZV08ynH38H2GP1vqlNOta/ozDv+0OqGrd
mjx/X5KTb7R864O73BfUrGr1jv1pe5mbhj88v/CIzz/7/lU3XPcGJjD72PzF
5+zL+A9v5Z9scPb/cM4Df80f9vu5u2Y92pB37IHUCSKtFAd31zrd4JOWD28y
LmL4q0ir7oSJ5Q8dN/pwTlh52GVwxG9JlH8oHdMiukoNa9npy+u2vDXr+Klb
j12GjK5pjRxT5M/Pr0159ivJZf+i87PMX/ZzaFeZp5i34FEyTzFvwSfJPGU/
hzLvMA/BA2TeYR6CM+/Yz6fMI8wrcOYR5hWd52UesZ9bmReYJ+DMC8wTOr5k
XrCfZxnnjHv4RRnnjHs449x+zmXcMo7hjFvGMZxxaz//Mg4Zlzq/yThkXMIv
yzi0n4sZV4wznedlXDHO4Iwr+3mZccK4gTNOGDdwxon9HF1HxgPjA854sJ+j
6feMA92XynrM+gzPIeso6yp8iqyjrKtw1j/WQ523Zf1jPYSzbrGO6bwk6xbr
mK4Xst6w/sBLyHrD+gOfJesE6wacdYJ1A878znyv/UHmd+Z7OPMy87TWU+Zl
5mk48ynzK5z5lPkVnlzmQeZFHb8yrzHPwR2dvxztuxzt0xztuxzt0xyd7350
P+ZoX+doP+Zo/+boXPmj+zRH+z1H+zRH+zpH59kf3b852gc62r852u85Okf/
6L7O0f7Q0b7O0T7Q0fn9R/d7jvaNjvZ7jvaHju4NfnQf6Gg/6Wgf6Gjf6Oi+
4kf3h472mY72h472k47uSX503+hw/+lg3+hon+nofsbRftLR/YmjfamjexVH
+1JH90KO9qWO7mcc7W8d3ds42t86uo9ydK53dE/i6F7I0T2Mo3stR/dIju7H
HN2DObrncXRf5Oh+w9E9hqN7Ekf7KEf3V472Y47uwRyt747ucxztAx3dvzna
Tzq6x3O0D3F07/Sj+1tH+2RH+yJH+yhH92M/um93tP93tK9ztA90dI/3o+cR
R+caR/tSR/tYR/eNP3rOcnRec7SvdrQPd3Qv+qPnR0fnUEfnAkfnCIf3tz94
LnZ0vnZ0rnF0DnJ0z/yj531H9waOzmWOznGO7sN/9B7D0X2Io3Olo3Ooo3v7
H72fcXTP4+heyNF5uWm5HA9npcis7zMntN4Qt2Z2oBXjwJd0cnC1jfsTfB+H
4yLvKe38gP/Dn7YO/D4PZN4KJeqOH2h8IY3O9K1xpoWfdUre98Nv5rntXHqE
j9XXO7p264HGl5TmmcuDZUM8LRcHcSYdZ/+0Io/1fdzIAXlPaec5ZsUWS7n3
+zyQ6EO8VqP0RVItyhqs733h7Ur2z9T1cahVKP3UaJfEpZVv9LzuOfVVmOpp
9yuhA7xy3q1TK7QNVh3UTzT1YpN5pYJUB3jmOnMT37pmWdSTfhU8eF+jnYVN
PeGpEzS5kGxsmNYTHuoSWCvmVbjW0/5+nPaF+/Xxuz8rSYRF+8J/jo7Nsqet
+Vxan+rJhobOD9XPpfn6Tg1K9/PwEP1c8Jwl07p2rh2s7avv54v2nnoydZBF
+8JbtHWKHbjBsmhf+OiTP5U9P97fon3hz2Z4JHg211d10/xyIa37Fhhj4qLh
ab9dX/q5mdENPmjBvbw3M0WobvCKZ5J9ebY1QscL3KnciiknHhg9NY9O4VJF
+2w2emq+vilxWeb7Raie8MonShfo/GuY6gn/lPXA2w7/6x8RPeGrcsSHB84K
UT01T+Do7q/vtAtWPeF5e73L06dwkOoJT9Uo59q4f9YT9ITfvT3QveMFf9WT
+b/f1E+uS8YGqp7ws4Hteo/fa8aLySO76X2J8aYfwv/u+ygucIjREx7Ttu2A
uKtGT/g+97tZ0hw3esITP43v8baT0RP+3Dl6cvcs4aon/MX7Jn9NLBWmesJj
W/TL87FYqOoJj9/knfdaqhDVU/Oa7L8VNuqK0RNe7HPRs79NCVQ94TVXFd05
IcCMa9b3jpNcOpWubPwR6k95/udK5zMhqie8g8+0EdnPmflH88WeyNKp1dNw
1RPu/HLc0JltjJ5wvx3dGhXrbvSE37tV6Y9lbkZPeP03n17+ltjoCY8r3iHl
5TJGT61PjeVtnlUwesLX98z6ewNXoyf8i9vmFtPSBKue8Lfpk0R3vWT0hHtl
b1O6wgSjJ/u39wNee8Rt8FM94Z3DrOLbFgernvCAlZurpTsfqnrCx3cfsmJD
ZqMnvEr6dqVOrgpXPeGe3jHvP50LVz3h/t/8BqZaZuZPeJNcYzYOmm/GOzzs
dP8UHa6Z8Q5PVWPKsBzvzXiHr3VO83fOj2a8w3smaNI47T3TP+HdM+Tp+8cO
oyd8xrxrS58PNHpq/rosaV9+GeqjesIn1qsXFVElSPWEX16x9I8av4SonvBV
4XU6TE8apnrCr91a22PU1jDVE15lzx8Hd74JUz3hmfNEfkx7M0z1hBfsvOlr
wo9mPYJPHjy1w+cQoyd805XhG1bHGD3hRcYfyXKkv9ETvsT5i2vKnkZP1efn
w8n61TN6wiskrnV0ajGjJ+evC0nePiuS21P1hPfK/7xV4t8t1RM+yyXlhezV
g1VPeNtBGcZk+md+QE948dBsOXrMDFU94Q2PxH2d9Xeo6gn/cqyKT+O/QlVP
+Mr212tvyW/0hM97uWNp6z5mfYe7TXx6K/5Xs77D9/d/6nv9pFnf4UO7NXtd
+0yg6gmfsCVxmaidZj3SfIejnqVIWCpA9eR8beUesODVMBNPCM/sl67+/Z7+
qqfmOVuZu/qcq2Y/DD+0JcPSBz3MfhgeMLlXpYN1Q1RPuP+TwQ9K7wxRPeHn
Y9LufHA0RPWEt2wzam2BfCGqJ/zlUuexnYYFq57wEoNmlpp+NEj1hJd8lu7q
lKeBqic804DWLlGfzH4Jfift5RShdwNUT3i3t+8uJ17lp3pqnsjxdXudijN+
M/gfd+bX2pnDV/WET/H0aFzwn2ZAT/ibD9fuHHEKUj3hTs2Hfe33Nkj1hF9u
3KTMkehg1RM+8l5Uab/Rwaon/Ei2nzZYn4NUT/iBPzbUC4g2+2r49Ygn6SL+
mffQU5/vPP1El78t1RPe5NikyccTGD3hvWo+z1Y2kdl/wlc3XPZbxmtm/6l5
ea/7ZC14pqjqCd9bf23xE9M8VU/4+L/2+zar7qd6wjN6lH3v1N1SPeFv780v
WubnQNUT3j3FvIvFkwSpnpqPrlrJ9LVcg1RP+OrNI9o23BGoesIvDw7MF+4Z
qHrC3QpezBM73lI9tZ49334KnhSgesJj0yQve/6sn+oJj/q4PEH1W76qJ/xd
wObrrse8VU/uP1fOO3Jv9eq8qif8+oC88zc9d1c94fsqhgXs/9Nb9YSfPPum
4rUlfqon/HajwIcnrweonvA0DxfVTz/cUj3hHa/MHp10j6V6wsvOKp13fDNL
9YRXLp+vbb8zAaonfEvsko6vJvmrnvD+TdfUyJfNT/WER+bevaZXG1/VE977
xK6QUyO8VU/4uHJfLm3u76l6cr+dOX9Sz4nr0qqe8I/uKXO/KemqesJH9xow
t/7S8qonfJF37lPRlo/qCc/zYHmKv2ZWUD3hf68Z/8uF+36qJ7zk9gtBZ7v6
q57wJSk2jfO/a+4T4LPPJBv6OZGf6gkfky9f855XfFVPeMIlez72jfFRPeHp
dnlErTztpXrCxzVI9+nNl/Kqm64/9xv+sSQyUOvZSHjDFSUiXeqZeSDr84JT
i3QtbFUev/fVhmJmHc9oy/PGczJL+VaDNy7486WZ31pK+3zZGBa3sJwZj7/5
fK1ydloB69sVt48NV5nz2u7mN67uiXG13JPWu1Chvpk/dwlP37bamHVtzPp+
XOK33y1x7lY3jVnfc0r7F79ffFiJiUFmv32qWIeORcpbwZd/Snn1nDlfE8d9
elrOJnP7mnNKjC1un/5wQOK3F65csWSVtzmPRPs9/9r+Rlnr9KPJvVqOMPvn
zvJ3P1bNtPf4JLN/ziZ/d+HKPaUvR5v93t6XWcL3bfWw6pQsv3VyEbPfayv1
qbFrxIgj+8z+JFO2RAWdK7tbe31bdbaCzf5kl9RzZvvFfXI3MutpK6nnQu/3
bm1TVFB9Cnl1/5Tthq+VM6j5+gx/mvMy/p2XL7d0OvjKnJdjo5pdiv6nXy7v
GjD63S1zXua+1PN1tZShK815mZ+hfc6UvvvY6NlT4uK9Vky/dW2f0TPfct/x
Wad4Wl/zNWuXL9yc7wpKPXONnhXwKpU5352Qeob3Pj91UyZzvusm9fzd7XW1
+P+cR3JJPQcvejKg7F6zfz4s9RzacnS95dFm/9xZ6tkwf8KoeonN/jmb1DPm
xbd1c9OY/V6HczcP3T5mWSm2vIi8ssycl/E35Whwq9LtTEbPLC0vuqfJZFlZ
l56v3TrY6Bkv9+HTB+7NWCnY6DngyczgmK3+VkDH/Tfjthg9+Tln457ZRbcb
Pc9nHJH3YCU/q82i4ykqtzd6Us+3VrImTVMYPfdIPYPH5hhR2d3omUnqmSH5
iekZfcx5+bTUM9Er/1/WFDDn5d5Sz6FLY/zSvTB6FpR69qn4cEDr5f85j0g9
p40OCq9W2ZxHDg1PktZ7SbCVouj5zK59/FVP/F9NWw3Z3fWNOS/HZP/ct8XT
IOvphCy9djf6z/2nvO9o1n56+sOjzXk5++qXD8d5BlmfUoQ3r1XM6InPJTrF
lwojI42e/JweHfV0R0GjJ/VcPSF2cfRaM96zSz1jDw/YkOG1Ge/RUk/nRKN/
/ZLF6LlP6tm6wMt1wdmNns5Szwsr01T8O4G5f+gg9TyUP2a9x3mj5x6p574W
D7YfHW/0pL5RMv+jJ/644gsGb3i7zJyXj53Of3DbsVDLalzt79KWuX/gfdbF
s15pn0415+VuzbK53c0Yag0ufdLzW11z/4A/6M/B2dbXnW/uH3K/TrsgbaMQ
K2zOgF41Jpj5k585zndLtiu90bOb1LNxtXv3Dv9n/jwi9Vwxs9bB/kvNeM8p
9QwaWfrn9P8Z752lnmsiavWZsdv0z0NSzylPb5xps8TomV3qWa3/xrzlehk9
e7+InHevYUWrVOcahZ98MOdl/INfZR1Ez4JDw1OnXxJhnRp0OWzaB7PO8r5y
t/UsY9OuoarnKWf/Pj5Pw63fT02P2F7T3D/gq+rwbGc97y3m/qHXCo8HLT3D
rbj8BzyK7zc6Uk/XNu1yzPE36yk/S71pceDFOrOe5pd63v8pWfmGn815uYfU
s/zA2h1zuxg9j0s93cLKJm/nY/TMK/WMrTdn4Hx3o2c3qeeRkFR/DM1q9Dy/
tOd9X88qVroMxbwftfdQPfFXuu98/SpH5QDV82epbwlZ99GT99EjtkU8i3Yx
9w9FT7bYP+FYJSvbOLeq5wub+wf8aE2jqg3uutjcP5xr3MB1R8ZK1t7bzzr1
PGT2P9RzYbX7vVMGmfNyUann6lxLj9c9ZM7Leg/R8ZeceQsaPc9IPeddubtq
b1OzvheSeg4e13XugMFmfe8t9ex1/pjbqTHm/uGU1LOo+5Tdr7+a/VWpRnNK
T8pY3drYwmdon42uJr+H+E+75R0/8MgHc16+9HTSnJ0Nq1l7mhw8fzO1uX8g
3oB9CHoOGjQq5V+/VLUyXPu15dJLwaonPj6PM48+Juxo7h9KZB4Ym+FpFWtF
tZdPLi4y9w/U84V3t4E1C5j3UIOknnv/LvL+wCZzXo6XevYscq9+7oLm/oGf
v73fG3g+xtw/9Jd69vr5zcQKC8x5+bzU82m933pujDH7paJSz7h6v3im72bu
Hw4kb+b7+m2kdaTcrNSXNrqYPDjiz305+MrDlAO8zHm5ZqOuo2ZHWoOfHetb
5ba/6qn5MEs/edbaClQ9o6W+7EPQE/9jx8RTClxwNvcPw44t2dvmWHVrTcrX
O5c0Nftn6jly4osrL++a83K01NMj6xDvzCPM/jyr1PNj0k5rxyU09w/7pJ6v
Fn2s/KiRuX/Qc0npdM8LlwtQPZ2lnu/3x8eU6u+neg6SevqWn7x61yxz7uh8
p1uT+S1rWr0S7nvjfzi/2Z+Lf9nH7XOmO396mPNyyZhpHilqWmmHte93abCv
6km8UOq3s5971QxQPXP0bH/q2Joa1t5N/TInfmypnocYT7IPQc+YPa0SN6lZ
w6rXO/P2TYnM/QP1TBsT1qNknDkv55B63t9XYN4JP8u8J5V6rvE++LTT2ADV
s5PUs4/nrKj8DfzN/YPUc3KHX18telJB9eRnpXQd9pSqZu4foqWe9R/HB6wa
ZO4fcu0ePqTS77WsZ5sWLz7T3+Rpwt/cuOqyLqkKlTXn5WSDt9/sWcs6tvpj
1GEnL9VT844WO7Tk5Bdf1fNI5M8vuuesZbXdfq/uh1Vm30m+lE69F9/1K2Tu
H3KxH5F9CHpST6c3OUttD/I39w9Sz6233ox8vd2clztLPS9V2lRj+50KqmcO
qeeTzxt69jzqq3oeknqO3vZkrX9XH7Ofl3rmLbD+fZsHZpy+3JN04hCvBNbc
l19fjXjpp/xQyl9TvO6Z13rfpUzjR33N/me+xMdNkXzI8LRyXg6S8zK6vZfn
H866PEvyHub+oe7Uub9eX5LaWpjyYY2Jdc292VH5u9OS9Uru8cSsXzvlHP2m
SK2QJmfM+jVJ/NCpxK8NTyR5acIlPw+8m/jlnVu4RU+eYObtNtJfyq6ZWej8
ELMO5ljQqnf43uxW3OnB+x88NOOFe4BUE9bnCslk1kfKj52WtNHUo6Z9F0k9
r0peBXhvqU/k5d63k3Qz7Z5577+6Tei7uuWcEvmUXxZ9Bk0reWBQZtMfekm7
XHP+N18x/JLw5ln/L08s7VVX8hjrOVF4R+H0q73Sjl75Mjby/PtxAHy0tOPO
yxF3OvcooOXXSz3PZj/Ub61T+f+87/63HdeUunai9npzn1NHdNjSpOGmc7nK
Ku8p7TLj8O1qnVeW13ng8/x/dc6cf/ajUxmLKS8o7fKpUIvl2eZ76PxAHqCp
xzyXDF5g9vnHG8QUPl+shFWn69iFd9ubc2gPW951fS8m5c8XTBv6eqbhBeV5
p9e+CO/9xuz/80leggO/FC6V6bLZx56W+5yJcxZemrLWnAu6L6l4o1/VYtaQ
PelGdT5p+iH3QpPzNa53qLw5L1D+7K2vE7ttM/uHQvJ3U71J6ZLkmtk/nJf6
x+04OznVM7PedZDPu1jyV8OHCF8unHbcI89xrt+y/tn6Zj4vQ7zGw2HdNqw1
62NGqU/S9IPjh0wx89J10cGjwZbyDaLMutlKPldU/fMF3v9i2v2Q6OD1LFGm
BF/Ne0/yPzQuXnVOXK4w5ZqvqccV/5tRhpOXIHkfp6NBQ02cSTa5X0rVoJ7L
0FQRWp58Bs5Vz8UF+JjyJ6T9aXfdt0s7u8t8Qvn+cj8wzMll2eVoU55zt/+t
8imaDjFxBZzTL42ZX/zodFN/zpXtM3T12lrF3ANwDr1YYG+FqyNCtTznJud8
n7Z1fGzOZZyzYpsdGV2hsslPwrmgZOKrDRN0MO89OUekbnPY5ekjc6/IvvdD
rn3lU8016wj75OjAWUuaRJt7NvZ1wQuCkz4s76Pl2Qfuk/6jcV/SX8bKPEB5
9jlrp++qnrR+BRNXIOvdvKK1hr797Gb2UbI+Wr9UO97jppf2K36eT54w5qab
p/6eR9br7amvjF5Xu5xy7p+fZnn1eGjicvp3iWf7Om5P0uyNXwUwPxBHF9J3
0NU0nmbdgUedds6ZprZ5HwTvfc6nm1OgGafwaZIPmXGncYOZC+05n9PMn3D3
yIp7pgwsofWH31j4rlKPeYV0HiPOrePjMVua3TXzFXxi0K9vWlU3527441OJ
gisNMvc58HGSn5l6wk9PODZgxxfzfgS+oFLZlnNemHaBVwnof+DeiXI6nzOu
S+1f0e+8T7ByzVtyeVOKZ3+Z/glP+DqF68hRYVqe+9tK6R8cvZTFlIf3Gbok
rERuU5543ZQp3Po+eGnuOeFbUq4vXyYyVMtz/9Z+S6o9d0v/pz8Lj/r2sPQv
ASFanvulVl2Ldrpb0PRneL8sxfde/Wzu+bk/WbNyXIvpl7y0PPzuzoWbU00O
1PLq7yk3YNOjuqbfwhc4+w57nsLcS3D+jdwTsafUqrJaHt595p5LbqfNvTrn
u3Jrqj5YsrmElod3rbmzcYMos2/n/LJpXodGTa4U1PLwsMPnO285Ytqd/bnb
0v1Lz4/LquXhG5q161olo5uWx8+x7/nKCX2OmHtU+G8lum3oucLMb5rXOjy4
+LDlZn9r/z4gxgv8WzKPcU7VzbkA/mxxqbQPklTQ8QLP7ffLgvcdvHUdhzcM
/qN65xHuuo7r9zAkbtb8ZS1XXcc1v/edL+ljv7nouNPv5ZH9HuNO84tXON1+
YtZsOu7gJ7MeXJLDL5GOO/i8AueWTh3zeg/66PcH9Z45we+mORfYvxcJffT7
Ga5cHRYVa/bt8Dcp2m6vt8/ck8DTzN5/wSXenOvh1To3qzt3pDnXw5NW3LGz
i6c5h8LDvb5uGLzQT/WBt7Ttb7We1/N5rZztqfrAO8ZHet7v6KH6wKN+bXU3
skhZ7W+NZD8ckPFIlxb5Tb+KEu7jUT8qer1Zf5vI/ys3v+++FY3Mveg60X+G
7Zy1mflc4sPRp7k8339n6mSdW5RXfb4N+PccdE3y+sLTyfnooXB085HnLJj3
+/mYDKa/dZZ6Tt1W/+TdqmY87pL9/PV279/muWP21buFe3e70KK9m9kvOcv+
/H2/4KN3tpp5lX9HB30PIu8HX+Q7+GnOx//Me/Ke6/7EJ/1f5jWc90rjd6+q
M/+dmcd4PxIyae7eHGXNeyvu+R+7PjiUMb+Zx7ivnjS1RWCpc17KuXcdbtOB
+8Pjrj0mWAtMf+AeLHhf4klJ55Uw8RJyT3IndnDuA7sLKq+wcs++FSX/Coir
6luu0JVSyl/J+cv6nHTIk+2mnuw3KibZcPHyxgw67prLv988/sed3i3MfVoq
afdKci5m3EVJ+Yw3rr/+u6rh9KtO6VftH5zNnDcXST8cYtuHRNAOC3O3Cp5a
ysSLyt+tIHlo4e+kf3658S9nfPVa8a8Odr9ACTkX23ms/N3mAXu7PeuRV59T
XOp/39X7Q4p1TqpbZjmnJ2pUZ0JsQtN/Dsu5NXKRy7sL/32fLueRnedGb3AP
M/2T8+PPvU8dyNzU8I7y3vnXX2dVP+lvOOeL2CWfnpcsYnheea867c+cPb7M
MH+X88Uf0o66jst7w3G7il44+J/1nfNFVt+ufcIrG057ZpL21f4p54t5qZ9f
PP7MjAveT5Vc+OhO8g3mHpjzRafjc1ZNfmH6Ie9fNncImuEz0Ec554u0R6Nb
H1xn1n3eL7wvl2Vi7Swm7oXzxZ+z4ko+9zRxHdyfL10a8ex+X3flnC8OxpfN
cm6yWfe5Hz512i9d915llHO+cJf+qfOD3Cs2fFxpbMymoso5X/wdWLbUhQOF
zT5E+tdX/3/7m/YfOV8cvv13I6fYnOZ9t/S3bVt+ilg/w5yzWEci7ub4dZOz
OSeyv608xfXZ4RnmXsL+fXCMd7hn1eNBGX8P1+fY/TVwP5lnSp54Wv1J12L6
fHt5np9fyr9vHJg36pyziReSe60nn/69f6OftZby8z9kSzTy6mv1JT2WeSzH
6CFLauQop+uXI78S5d0ajO9d+3opXb/s5eHNycuY4N97NtYvR36l9yv/7zzD
vBRky7cJ32/j6Ml5qnjL1EcqZTT7efJzDtqfKnmPumb8cl8R98uAxAN+Mud3
3Wc12Jt90VbTjsQLLZq4fXqdO6Y/RNvidijPeWfmoffjSmUznPX08k+vm6zL
YzjxQgvSuHbrliNC60k/Xd5w2qj1qc18RT7J31KdupKwsdm39Lb1T3hmm7+J
fsV8eGaxb/nLmww/KPVskbfqpf/NP8lz7PlFKQ9f3GJ6od2HTXlnB38XX9Jy
nw6/pepgeAeZt1ekHdWi1nDznHO3/9/9s72t/9DfttrWL9ZNp1QD/89zeH4H
Wz4TnpOxxrOJ1bZ9+K4fFv9ze4XQ2Qm/WwfLhc3bsX2h8eNTz4SuPgUGXHn5
Xb8d92vnz3MSrf1uvFd5+EvW8VWufuc3nB6e+mOefLe/8xve+xacocjl+9+N
R6cVLwrX8n35nQ57bPkcGI8XP6Wcdr6YyZPgqJ6OdPv/VX9Hujn6XI7a60c/
74+2L/Ma4zJC9oFwxu9nuY+Co6vWX3xQ8LPiC8PPA28v/iZ8KXB/8engr4Dj
N8EnAMc3Qby7lpf4f+K24ZMljp34Y+0XEo9NHC18r8QV83npL/bPC8fvxueF
bxPfFp8Xjv+IzwtfKT4aPi8cPwifF46vgc8LJz6fz6txqRJnzueFEy/NvSSc
uF/WJ8YH95Dcr+l7eLn3Y36Ep+pwdtK5piY/MBx/JXrC8Qmip8674ndDT3hV
8W2hJ/yq+I/QE46PBj3h+EHQU+spvgb9/nXhxOdr3Llw4sz1+7CFEy+Nnswr
jeT+Fj31/aTcl6In3F/8vOgJHyi+VPSE7xd/JXrC8QmiJ9xb/G7oCa8qvi30
hOM/Qk99vvho0FN9IeIHQU84vgb0hBOfj57wxxJnrt/fJ/NxrNx76/f3sX+U
e2b0hPcXHzR6atyN+HnRE55EfKnoqeuA+CvRE26JTxA99T2w+N3QE/5NfFvo
qXGp4j9SP4zw0eKjQU+4p/hB0FPjr8XXgJ7wUhKfz7zHOsa8h27wEPGJqw9Z
eBXxO6Mb/Jn4dtENjv8U3eBNxUeJbvAC4gdEN/hq8bWhGxx/FrqpP1t8RugG
XyN+GXSD4/tAN71/Ff8CurHO23WDfxAfPbrBP+IHF93g+JrRDT5W/LnoBg8X
nym6wSeJXxLd4PPF94du+nfFv4ZumudAfFjoBsdPhG7wSuKLQTf4LPF3oBv7
ILtu8FySZwDd4Pjl0Q3eW3zf6KZ5KcS/jG7w1OLDRTf1YYifFN3g7uKLRDd4
cfH3oRv8hvjU1D8mHL8Vuuk5QHxD6AYfK/4XXUdknzjF9j2n8DHyHk3XEeEx
kp9B1xHh5BnQdUQ4fnldR4SvE9+3riNw8S/rOoJ/VHy4uo4IPyB+Ul1HhJcQ
X6SuI8JHib9P1xHh+NR0HRGO30rXEeH4htCT/bWbvA/V95rCz8r7R/SEk9cC
PeHkZ0BP9U9IngHNFyD8k/jl0RPeS3zf6AlfLP5l9ITjw0VPeEbxk6InHF8k
eurfFX+f+uKEVxefGnrC04rfStdlOZe4yntkXZeFL5L3trouCx8j+UB0XRZO
Xgtdl4WTn0HXZeFvJM+ArsvCe4hfXtdl4U7i+9Z1WfhE8S/ruiz8lvhwdV0m
TlL8pLouC8cXqesy5cXfp+uycHxq6Ml57qq8f0dPeDV5342e8OeSRwU94eQD
QU84eS3QE+4p+RnQEz5T8gygJ9xH/PLoqfHX4vtGT81bIP5l9ISvFR8uesLx
k6InHF8kesKJu8C/x/m3ivj4uC+Du4nPjnsueIj44/CDwfGF4ReC42/C96Jc
fDr52PcIx2+CD0Hj08U3QTw9nPh/4sLhxLET3wwnHps4Xb2Pl7ji3BK/An8p
8bH4ALkfOCV+QPxv8Bfig8PHpT4k8XPhR4LjS8IHAscPgp8B7ia+BuLy1ecq
8fnEl2t9JM6cOGm4t8RLE+8Lj5K4X94Xcj+Aj4/3hZrHBT+avC+E46vi/R8c
3yXv/+D4CHj/Bycenvd/cOK6iUtWH5LEJxeUeBTNFyXf14NfDj5NfHPEl8Dx
fxG3AcfXQHwGnPh84jDgqSTOnHgLvQ+ReGl8enoeF78e75ng+M54HwMfIvH/
vHeBE8dOHDaceGzi5zhXdhT/GvHucOLeiQ+Dx0j8Nu91OE8Rv51F5hnOC/h/
icuEZxDfLj5Y+Cfxw+LnhOcUXyfzDBx/IvMMfK347JhP4G7ib2I+gePTYT6B
vxS/CfMJHN8E8wk8ncT/E7+u96MSx35C3gdwLsCnjO8Xjv/3pMwz8AjxseLD
hAeKHxM/IRxfIb4jOP4j/DNwfDT4QOD4QfAzwO+Jr4G4fPgWic/fJ+8n2M/X
Ff9yd5ln4Phw8ZHC8ZPih4Tji8TnA+8lfh/8KvBP4lvBdwHHf4F/QOPHxUeA
H5j9M77gMzKf6L5a/K34M+GtxKeJTwaOXwa/h+brEt9HTpk34I/Fv4Bvlv3n
EPHP4v+EnxcfKL4R+ATxj+B/gI8SHwR+UfU7im8UX4T69sQfwXtZ1k3ixnlv
x/pCvDHxxPAUElfMvAT3k/hejd/le/Ykjpc4Xc03JvG6xOPCS0lcLnGx8DES
H8v8Bp8rcbDEK7C+EPfOezg48c/EE8CJW2Y+V/+cxCcTHwAnDpk4APXTS7wx
7/vhxBWzLsCJB2ZdgBP3y/6Qz/tB8mPwPp7yxP3ie4Hjf8H3Asf/wv4cvkHy
TPJ34eTfwCfD+ohfBp8MHL8MfgM470/xz2geFPHR4J+B46PBPwPHR4N/Bo6P
Bj8DHF9DAfk8cOLb8dtoPJH4bvDbwPHd4LeB47tpK+0Ed5M4efwSmn9CfBP4
aliXx4kfB/8DfKj4JijPOjVa/DiUh+ObwJ/DPI9PB38OvLr4dPBXwPFZ4Nth
vsW/g28Hjn8HPwZ8vPgy8PMwT94QX88lG28pcZ74eeD4enLZOL4e/B5wfB9D
bBzfB/4f5tUQ8QHh/4HvFh8Q/h+9bxEf0DHph/C14gPCT6J5B8VXgi+I+Xmz
+IPwk8CTia8EXxDnxAziD+J+Eq75xqU/wJuI34S4f42Xl/h/4mz0HCfx58Qf
wIk/J44cTpw58eJw4snZt2teDYkbJ/4b3lriw4nzhq+VOHDiueFXJd6b/T+8
psR1s/+He0n8Nvt/+BaJ02b/D/eUeGz0YR7Gd4M+cOLw0QdOvD36wDdLXL3G
07P+Svw8+hj/yr9x8uij3x8t8fDoAyfuHX3U9yPx7eij/hKJY0cfeKjEq6MP
/FeJS+f+R8+PEi8EZ/4n/zPrDnyf5DGmPPNYA8nnTHk4+Y31e45lvroheZ4p
D68reY8pz7yUSvI/U159ipIPmfL0B/JaE0cO3y9x+DxH46YlzzP3XXDyKnPf
BSdvMPddGp8r+W+579I4LMnjyn0X/IPkI+W+C55Q8mpy3wWPl/yQ3HfBAyXP
Ifdd8NOSr4/7Lq2n5J3jvkvHr+RPQzf6Dz4F9IGTXxp94ORPRh84eYDRB35d
8tmij/owJC8r+sAnSX5R9FHfieTJRB94Jsn3iD7wG5K3EH3geyT/HvrAr0ke
OfRhHOHXYN+u+zTxKSyz7cfwcaj/gTiB5P/6ONLb9mn4GuCal118DTyHfctz
8X1QHo7fgfLsW/KIH4TycHwQlNd8ZuIToTwcfwTlNX+M+EcoD8c3QXnGdTvx
lSyz7TdcZb/BcyiPzyK9bb+Bz4Ln6D5BfCjqryB/vPgvVB/yVYg/RfURji+D
8qzXfcS3Qnk4fg18Gow7/Br4GeA3xNdA3CQcPwL3inD8CNwrwvEjcK+o98/i
R8CHAMePwH0jHN8B940ahy6+A+4bdf4U3wH3jXB8B/hSGC/4U/BvwPFx4N/Q
85H4ONbZxhe+FfwD9E9L/Cn4UnQ9Eh8KvhT438LxpdDfFok/Bb8EnwvfBH4J
OL4J4v7hxP8T9w8n/p+4fzjx/5yjdT6X+H/i/uHrJf6f87X6VyT+n7h/+HSJ
/2d+gRP/T9y/fl6J/+c8Dieenzh+9fNJPD/ndPVNSjw/cfxw4vk5v8OJ5yeO
H048P+d6OPH8xPHDiecnjl99kxLPTxy/+gkknp97ADjx+dzfwr9JfD73ABqn
L/H5qWznVnwx9FvNjyL+l0j8HTJf5REfAf4W5iVLfC74W+AJhONvsZ9H8LfY
OT4W+Avxs7CPYn3kezGY9+D4C9g/MH75Hgr27XB8B+wr1M8t37/Qy8F9BZz+
ix+BOHj1bUg8PD4Eno8fgfMaz7HHu2p+BRvXfIrC8Q/oPbn4CJrbzvv4BfT5
tu+ZgtPu3/1daV8494Q6TiXOHx8In9fuB6H8Com3J84eTrw97zd5Dr4A/AD2
fJ6cvyiPL4D+oO0ocfKZHXB8IJrfRfwgXW33QvhB2kp52gU/CO2ieVbED4If
w64zfgy7zvsdcNZrvZ8UvwPvf+H4HfI7eL9G/4dXfXT92//6ETi38pxn8W/z
5H8WrveB6hOS/L34B+xxyPgH7HF6W2R+sMdT4R+w90/iy+08XuLL7Xq6Sxy5
fZ6ZIHH29vjwjhJnb69/AomPt9ef+Hh7HF0GiY+3fy7i9e3jnXh9+3j/S+L1
7ePdReLm7f3B0ed1VN6Rbo50dvS5HOngSDdHn8uRDo50c9RejtqXPJjMQ+TD
ZF+q9+eSDxN/rOYRkbyOGR2cm7if0Tyvkj+T+xk4eSC5n4EPl3yG2WUfxeft
U2zSea/5Ebqf0ffIkoeTfYue1ySfJPsTzYcqeRHZh8DJ70ceZPRfJPmQyecL
J68v73fgtyT/J+934NGSx5L3O/Amko+RvCpw8gqSP0WfI/nxyMtM/zkj+ZnJ
L6zxyZJnmDy58LaSL5d9IzxC8pSyP4STb5N9IHyf5I1kvwdfKfkP2dfB10oe
P3yY8PqSj641cSoyjsizTV5UeJTkR90k5xfGo9PVf/Nv5+L7j2z5M8mjCief
KvlA4eQFbSf9knmAOAryrsLJv0r+UDh5RMmDCScfJnmuNf+W5Ls+Kv0SPkzi
JcjrCie/K/lJ4a6Sp7Sw9H/4IMm3OUD6P7yn5I3cKf2feXKW5NkmTzScfNH5
eX/D9y9J3AV5ZuHkmyVfKryX5E0l76dyyf9J/kr4Y8ljSR5G+CfJx9haxgXz
/yLJB04+azh5rU/KuIBPlfzM5BeGk2eYPLkavyf5csn3qvn+Je8reUvhxSR/
aTEZL/CxkoeTPJLwCpJPknyIcPIikq+K+Zy8VeSl0vgree/GPAN/L3mcmGfg
QZKvCV868z/vB5k/NZ+T5H0i35n6YiTvGXE1et8l+fSIq4FPkbxnJeW5Gn8r
74W7kmdG2n2qvAe/Jn8XTp4x8sSh2xfJF3dQ/i6cPGN8HvZ15KlgHYSTL2Kz
7T6ffB3k0WA+IZ8G79k1T4D49/n8cPz7vB+He8g5lPkT3kD87C3ld9Y18kIs
ssWfD5L484H430WHwZJXobeDc5+j+woX2/umBvK+ifKaz6ztjvabShifkr1/
utjey8TKexn6gcb7fRiwIf9xk3/f3j/72uL3Ssr8z/PhMyLX7czrZ+LJ+LxW
//izoS1MXnR4C/fN036ODzdx+cJr2b6/AO5760HJAZ1NPAp83PSArXFpTX5j
+N6lDxdc8vXT+vD5fslSvb33AVMf+JZfThQcXDNC/y58mC3PP7x/55GH2uQy
8xo8Y79Tacr2CtDn8/drN99apV7zCH0O3J7fHm6VLZi3aB3zuXSfIPMnumu8
3D13r7DLxm+pcXEuaTNHFzf+QPix0YPm+PwnvyLcZ9Mu5wQZzX5F7yF7953X
7L3ZN8Bj2+5a3qy+2QfoffvBHltfDjK+CHh01YUx2cebfOD6/O3dU48b+p98
4Pin0vX4WrWV0Ud9T1le5f7nuGz201KvXdsm59u/1/jr4ZmbOZ3Zlu8/+dKJ
r4uofHjCHZNnCd5swKsufcoY3xr8j5mdlt4qbHwy8JVZvmUfesfk64b3G5D/
wuePpj/rfuxjjmMuH01/hrs/ufU6993/5Ovm7/4enG1HTxO3yt/P9uHjnLGf
zfd8wV1cqg1wOm/20/DIJW03nS1j8mTCT6aN6Vm43H++L1J4wvkxW8qFmPrD
n22Pju9SxdQf3uPJ1Wvv/E394fsWLT/1WwUzDvk7PRulyz1vpcnvp3EXtXc2
C8lq9tPwOfnjUkwtbvwh+v1Xe26VGDvQ5OuGH6l7dLXbW/P9VvqcI0+vljto
/KI8b1YD62/PhyavIDx4fbH1G1KY71OAu1c5vSHK2+x7NL/g0thE27P4mu+D
kP/XKPv2uFrxpj/DT7/dPC+Hlxmf6muW8Us/0PwQ0p/RV78/U/qD+pyJHy7+
5fCzNeZ7KODMAzxf46NkXGj/oN3oV6IjnHZkPKLrvHkJo1/HmrwW8EBZF/S5
wpmfqSfcV+Yl6glvLuNU+73w6tLPNd877Sz9SvuPcNpd8++xv3qYqoHvCuPb
h4+vM7Pt112mneAtZV3jc8G3yvqicVrC68i6oPnY8c/a5lv4n7b5R9cx2/iF
z7WNF3iorT9rXivpn9RH44dlntfvpZW/31Dmef1eWuHMhzG2c19NWd+1fRnv
si5o+wpn/tT2FZ5A5qVCtv3tAdnf8nfh7B9OOjgPUh94gKxH1Af+WeZt6gN/
KvOhfh7hl2Veam/bb4+35WWFL03Wfl6hVSbPAjxO9jnar4SzD3FxcH7UfiX8
qayn2q+Es+5ovxLeXeZz7VfCmVdVd+HlZT5U3wvnvlrbMlzsaeJl4TMyVsz2
dbS5R4azf9P8/MLZX/F54QGyXzrg4Lyp+caFr5L9g+bnF/6nrLPooPWR9Uvz
yQtnHUEHjX9j/hdd4PZ5XuOy+j0ZkbePyTuHTsyffC54nMw/PAfOPlDzWgtn
X6TfG0K/s+WdhtMPqbfu86W9qLfmXX6fynlZDxMPpPf/tryycOLZ9PuYHORf
ssfTtrfda32Te62mtnMi7/31e72F7+xe7tvP68z3wsA51+j6Je3MucbReVZ9
+8Ibi3+N+sFvDW7gPq6V+d4Ee1wf5eF8LuoHp/78rt8DIOdB/h79qObnKkWH
x5i4JTh5tpWTF9+Wn5b+4iXnZcrDG8v5UfPmST8qkXX39YU7jT+Tf08g52L6
s8ZlyTrL/4ePt+Wx1+9Jk/mE32kHxhE62+NL0dMeH6L5esi3bevPtA/tiI78
ey3R2dH9Q0fb/UMFW75HbTfRrant/sGez5D2qif3A01t9w9OojM62N9jat4Z
Wx6w/wH0BwMr
   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmwf4V9Mfx7/3fu8999ohI7Ps/sgKLZGyIhKpjCjZFJKMoqTQUCjSUrJH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         "]], Polygon3DBox[CompressedData["
1:eJw1m3ccltP7x+/nfs59n8de2SPZm8ziayeRjJAdJUQpEjLaAyGKEqVNGSmV
IkRGQiKhkkjIysyev8/b5/z+OK/n+tzn3POcc43PdT31Wnds3iHPsuyDapYF
/a5dy7Kn9JsLjJO8ZZllbYUvET5ReCfhq4WvEj5DeC21J4UrwmMlr4pZdrLw
KF2vl/ALGj9ceKXwRcJLNO5n4aMrWdZZx9bRsZnCVR1/QPJS/f4q3Ej9V6v/
PJ0/RfhRHe+s/h/0u4b6TlLrpv5t1H+5+tvp+Mnq/0q/hfqaqnVV/8oiy3ZX
/286/qz662p8B+H2wqcIbyvcUfhy4ebC9YSvEO4gfKrwumrPCBfCD0oer491
va79h461lPytrn+s5Ibqv179nwnvJvyL8DPCX+o3aPzxajfqeb6KHj9Ucnf1
f67xewj/oXGzwOpvJDxY/TcK76DnuUr4SvWfLvyY+lvoWhuqfaW+7dU6qf8K
9Z+m/n84pr7LhE8SXq7r76j+74SfEv4r+Nwv1G7QPb7U9Rqr/x7J3dT/hfAx
wkOEuwp/pPN3EP5G5z0p/LDe+Qad+5eOXSB5Qx17XvIa6n9Y8vpqs4Sj8ATJ
hdpDwqt1vWGSD9bz3S58i/ovFp4ufJPwQvWfxVoSvk14kfA5wk8L3yH8vnBL
4ZJnEP5JeDjvo+drIXxs8PPP1PgBwktYO6zldL/FwucK/63xZwg3Cf7++6m/
j3BP4VbCTwj3E35b488UXlP4IuHT1d9X+DnhwcLL1d9aeLjw0cJ3CR8hPE24
r/CCqvfHs8J3CX8ofAHrQ9/3IN6/6vUyS/13C39U9f3XFr5E+Azd7ybh9sIv
CD8tfC3fWniI8McafyFrU3iQ8DLh84X/0PudJnxM8Pqpr/5ewt2D+3cRvlb4
6uDvPUr4eOH7dH4j4b2EuwvfGPy9g/D5wicJ9xQeIdwkrd+jhEcKHyd8r/DR
zLXwpcIzhJsJT0j6Y7rwCcLjhM8UHi/cRPgB4bOEJwgfx3oRvkD45GD9cX/p
/XC3+o8UHi3cVHiY8DHCNeELhU/V+N7CY4SbC49Wf2Phir73TlqvXdR/tvAe
6u+q/uuD18ODwmcLP6TxxwtPEe4t/GbV+2134RuFrwtej2sJXyzcQrif8BrC
bYRPE+4jvKdwN+EbgtffWOFThcfoeseiP4RbC08Wbpr0K/NxscYPEt486dc2
wncKbyF8jfBFwgOFv42e33FV3+9r4ZOER1Y9P5uqvS68kcY/Lnml+o8QHqj+
G4Q3U5snXEf9UyRvovaa8IbCkyVvmPTjecL9hTdK+rGl8K3CdZJ+PF/4NuGt
1N4S3kx4Os+rNl94E+FpvI/aG8IbC0/lfdXeFN5U+AnJUW2i8K96vvt5Fh3/
UvhQzdlQreUaOg/9rf4RfG+1ScK/C4+UvLHaq8Ib6LxJYJ1zsM49RG0TyfN0
/Gv1HybcUef8Utg+HRn8PTZgTwvXhB+SvB57VrgUHs/+V5uMfta5oyQv0vHV
wkfpelfp2EY69orwejo+UfLZ+t53qO8R9d0svG9aTz2C9/8n6j9A+Cb1dxFu
oP5bwepvw/wIdxa+UPgOdJ1wF+GXq7a/U5O+eku4BfOd7ENrjR+AftT7baf7
D1R7SmMaJn16c7D9fTzpg/lV24tNkv1opf7b0YdqZ+ncXXWdTyR/quc9kPM1
/jrhQ5J+7a/xl7C+0Nka20C2YKrG7piev1Pw8+2f9GGvYH1ZR22u8PrCj0n+
ufD6PUL4ReY26Z/Xq7bHk4V7CM+r2h4/lvbXa1Xb74lpP79atf0/IOnv3sH6
8U9d/3ThxsH27PjC9utaPe8rklcVtncHBc/HAF2nv/onqe2rY8OFb5M8We0w
9oDeca7kn3TOVvg6ajcJt9B1ljBfGj9A+HG1E9CZrAPJE9X2Er5f+HbJm6sd
Hjxf7bGlwvtIvkXXe0Xyjzq2JddWmyP8vfAWkgcwhvWhY3dIPhX9KrmB5Hd0
/2PQT8IHCr8t3Bx7InyX8ELhvrrGS8Lzde+DhE8S7id8uvoX17xf6uj63Xh+
HWsU/b26Sn5P/d2FnxdeqTHv6to9hWfjT7Dno/fHZsy3jp2sczrq2AOSd9Hx
13R+b52zeWbf73X0g8Ycof7v8AE0Zvvo/bqb5HnoF/02VP9BarMkb6Pxx0nO
eAbhLdUaSN5f7Vl8UvWPkLwCHcK3VZsuvJvaAZK3xl+T/Lf6P9X4rYQbC/8p
vEL4ON2/B/6lji+q2V/leXvr2CmF/dMthPsINxe+VG2q5Hpqe0u+Te169pPw
7ZK3UDtS8g98L56X9Sb8Oz4BOla4HfpUx25F37E+2c+sP8kt9TyDK57zTPLl
OjZDeE++ieQJOjZI8hVaz/Mkf6Pvu7Hkx9VeF35Zv9urDUVf6XciPlvuNdlO
v4PU/sXXVjtV8nNqddXuFr5Sv0Nyr/Wca6gNzL02Oecuyffk7rtG+DRk3bOe
fl9Umy/56dzfZmv9Pqv2hNqWrH/9zlCbnltmzxCITFXbNPeeu1y/k3O/D3uy
vX6nqG1W8Zhpai/kvt8QHeuk36e4vtqd6Hv9Pqm2TcXHZnKuvtnhwt9g44Nt
MLa4FTpf3+4DHatp3BieX2M7qD3J3lRrKHlu4ffkfR9grvSOO0veT/LLulYr
4XuwXbpeVfIF+EPCg9X/rvq78k3S+mwgeU0d74+9Zw2zdvD7sR/oYD3L6NzP
0wUdo99zdc5dFa+xv0vHF9tJ/lLH7ivsQ+FL4WP9Izxc5xRq17LH9TtM7ZfM
x+7P7fPg++CD/avxn+NTch3Wgu7VUTLxYQfWWOH4anvhr4WHCZ+C3a3aZ8N3
61V6/2Mb2e/nFt7/rJlGkifrmnvrgo9KflX9Q4WXpe97UfQeYr0sTvuhPvGH
5CVpP6H/3q94fb5T9X6jjz0wp+r9xLnM/5P4pIV1Jzr06sLzxHy9n/RnP/YI
e0PyR/hvhdfLIvZcYX9kBfpPralwH+ax4vWIreiHXqx4vWIrBgl/UPF++77q
NcO7LUtrYEh0/6Ckj0vhpdhr4U+FhwkPF15b9/1M+M7C/azvFfjIhWOvecLX
oeNDen61o7AHhXXTFkm/MH8zhZ9hPxe2U9irrTPrT3Qka3Fmml/sAPZgq6Qf
TxPuy/5J+vF0Pd+t2ELhb4mthF+teE1tHW1XsC+d1I7Uuetg8yTXV5sU/E34
NujkQfi00e/CO20r+V/iROG91EYHfwe+B3vwMcn/qP++inXgKHwknfMa3xc7
UPP+wP+5VPh94R80/l7h3dFXwd+Qb/mEWp/gNcRamqZ2DT5t7vXyF/OLHtH1
Xpd8rd7lY12vKftd/btr7AzhXjq+t/AZGtObWJtvKHn9imP6bYWbSY4Vx9C7
RPMfe0h+Q+fXU/+J6qtVHKNfHR2f/y35OfXvgL4RXrdiDmPXaH5kT8nz1b+d
+puzXtR+0rFcc3Ku5D10fIH62+p3SsVrmrXdqrBuqah9ofF1hU+QXKp9TYyp
628seWcdf17nX1zY90Hn4hP+pHa25N30+6b6Lyns66DTd5dc0f3PkXyT5LfU
/4+uuY+e90wd26XwfGN/scMr1H+hfh+tWIfBj+A34z9vpdYs2A5jjzdJ9pPv
vbBi+4Vv9UPp/dg3+au8E+/2llr3wv4T9hc7vLzm9+L9Fqb5+jh4fq9Ta1J4
HbGe0LfHCm/PnpK8TsWczuBo3cD3PIvYUv0bSH6b55HcW8dekPwVMU60DkIX
MQdn6/wTNaa75I2Tv4OPjq9eV+0c4buj9Um/9P2aFfbF6iR71a3wu3VU66Bz
exS+NzYD2/FNYT6nQbC/ToxNrA3nAfdBTE5s3lZ4HWIPrfE/dO63xCCSX8Wm
sQd0bAS6QPKvklfh08F9qX0nrEtkJ+a+/7aS95X8GP4OcTZ2Su0Zvq3aT0kf
HKH+sYX3FnsM3Txa7XfmU+MXYhOC732l2uHCN+sZt8ns89WLtiHYEowS9hc7
gj1BRxMvcj++fVcdWyA8Su0X5lr4bckjdY2vKl6TH+raizW+muzjMYW/7wbq
q4+vVPgaPXO/A9cei49V8ZhukkerreJZhb8r7Y9tnXyecyQ/q9Ykd4y0MtnW
44Wb4atIPqxmLghO6FOdf7hwf+EGwtthm6P9Mfyyxdhj9EbVMdF2cAvRtggf
Cd/vfWKK5C80Zg9H3++ZZNvZ/7n6DsEXwz8obMv/s+lwDjr+d5ofdGEf3Wtf
yU3x3zR2Ed8w9z241+Dcc8Gc4Bv+q2P1JTfEV0M3FD6XZ3i68JpgbVyqdojw
dLVjc+tQ4qM3hO/NPSfjC/tgoyT/ltk3O5CYt+Jrv1DzmmPttUj7j5gGG8R6
3UzvPlFtV3xeYnDJk9T2Ev5c+DLJ03TOwbk5kjurnnPmPk/6o7nG3IJuy823
HqrrrwrWl7PVtwT/JjcfvDw4BiYW5ht8pPE/6tiaGnsy19P1VwuvJfkUtR5V
68dNKr5Hr6q/H+/HGu1d9fc7KPc1+f7MGXPHnsM/nCx8YLof47GB6DC+1zbR
MTSxNDEzXPfrGvu/3DrrUf2eEq1LiQm+RJfq98i0fvHdF6kdldsHm8Ue5Vsl
nxrfeona0bl9qtn4mtGx1kuS35P8HPYltz/JemcfsB9YU6yttaJjmVd07F3J
b+j30Nw6epJ+3ylsh9EZYyRfnNufwid4Lff1m6XrzZLcED4q2L/fQdc7WPid
4PhyR+E2ue+HDzFX8hl650fV96DGXAW/ofZRcHy2m8b/D84mOD7cPdr/gv9/
SOfOKcxJwE3AWZA7gFOBW+mZmZuHk4CbgEMkVzECHodYvmLOA84V7hUO9fvC
nCrcKjkCcgu/FeaXGwXzh78yBt0ZzG/+wHog1g3mQ0/OrWvRVz1yc9Jw05zz
pca2l1w38xpgLXBNuEk4U+7FPdE9Bwc/y1HBuRw4M7gz7gH3CmfMvYkxePbj
g2MPbEwT9HWw7eEZ4WJPyfzscMRwxYz5rvA7H8zzpG/BsYbChwSPvUC/s6rm
HOEeWVesL2LaOWr7B3Ob7N8p0TEssSw67A7mN7dtX0O/Y3Nz0HDRcOxw7cSI
2GfW/Du5Y058+cP1+5Zac7XOFdvI/rljZvYLa3Re7pgU/XuYfudzr9xcCDby
+mSj0I93544dT0+2Bv2GnoPThttmjr/C/ujY6mT/Tsptx7BnHOue2479kuzp
f3Od259thD7OHSOi+9HPI3LzAsRG7OH3csf0+Lvs2cW57S72l/jhlNzfhNjx
zOBvVSY+vXmKleEg4SLhrOGu0YHsb/YeupGcB7kPOEpyheQYyO3AyZF7wMah
/+oH2z7uyb3xMfrmzoGQCyFnQm4GDo9cBzkXuD04RHIv5EzgFvlGfCt8BvyW
cbnnGv2H3YDDh8vvlTmXhs0iViEOxpbBUcKlwtHCXcIpwi3CKZIrJIc2t2pO
htzauGhdCY/yYXQ8jy+2Pv5rdM6I3FFf4Z1L+1jE1mcF+17oEPxJ/Ep0y/nR
8weHAXfCHt2Pdw3eu6yJ/YUPDF4r5CzIZcHpkssgx0CuixwXuQdyNuTK4GjJ
5ZDzeK9qjoFcyKOSzyNW0z1PDI752ctNg7kAdB7xBHEFuhAbAl91TWHbgk4l
XqibdC05JXJPAzPnmp6Mtg/YiQXRnDe5L3JUcOHdgnPNdwrvw/NHr0d8nH9L
51jI/cGJk3tBZxM/EUehy7Hp8Dedkq2H44TrJL6rqe+P6L3NHief0lLXmCo8
kdhK+MfSsSsxbAveJZrbI6ZaWjq+g7skRnu/NCf6WXAOGa4Ujvfz4Jwt3O8B
0VzsLhXzPcer9aw4R7CkNGd6Y+F4Gy71wGiuZ1e1QGwSvV+JOQZEc47vBeds
4SKPitZfxCjEoo2juQg40kW6/v7RXCE5Lub3iGj9Qkx+WzTndDd+VmYuqqGO
XVExZ4s/dEi0LiFm74O9jN5PxDC9JK8THYvDIcMlt1B7RNd6QM/YSdc+LFrf
wlnfLPkG9V9ecQ5mY+GDorkjOGP8ZTjqdfU8EzJz1/+L3v9wGHAxzOfa+ICZ
uezDo7k2OPf+0ZwJ3Mn4zM8zl/djPtS/pvrXg0OqmBPn+n1Lcxes4SujY+K8
sA0mVq4fzb3CGcCnEXMRezXLHMvuF83l7qgG/7oea7ZibuhmtVtLzxVrlLW6
bzSXTw4efbFPdOyLT0d8cEfp+gD2GHuNGDorHD8QWxPT4xfiHxLrwxHgN+I/
wh3cWXotokPQJTeVXlvE1FcJdy8dW7JH2gv3KB07w7FfHs2pUxdBfQRce//S
+X32NHsbzg7ujvwW3H2/0lwQHHmn6BisrfbqObljMzi8s/DRK+b24PTh9qnv
2EPybRqzU2aOYyf114nm8ttzffIHaptmjtE7qG8DvqHky9RaqW/DaG6/Hf3C
60dzSXCqrGdyiuQWyTleWzqnSW6TnOM1pXOQ5CLJOXYR/qO07oMjYf6J5+Ge
ydswn9dFc0HoJHQTnC6cIXt8L8l/6ZxtJbdE50seVGb/5SLWU/tccozWRRdh
k4V/K81lwImwnp5PHAR80Z6S/ywd+7OmWFtfq21Ucc0I8SkcEFwQx66J5ijJ
mTDH7BdiIGIh4q0nomtI4J3gn77g/UpzS8zBx4VrUuAx4DM+U9+9pbkl9Bm1
KIxhLDU2K9T3ifAumW02tnto6XNZg9TWUFMDL8U1VqZ8ELlbYi5ir7tKx0qs
MWpJqCGBB4MPW66++0o/ax21VaVrVODBeOaPhScV5rXhtx/HVpQ+lz1HbctP
pX1pOCn2D/qd3Bo5zNWFc4r42Yz5uXSOmlz1Ap1/fdqP+PpwnCdGr1dyNehw
dDn7m9gBDuq4tF+ILeBwmqT9SGwAZ4p9qKN7bq7rv51Z/5ETJjc8V/jK0jl5
cvPk4K8unQMnF04O/brSOWxy2eTkrypTTj44p9+5dM6U3Ck5707ELujT4Bz0
bjXXYFGLRQ3Xheofg34JrtHapeacNrltanTalq7RoVaHHPilpXPg5MKfF75M
eGDpXBmcMfZujWhdS44R/UzND7U/szWmnfBM4t3gmhVqV6iZonaKnPolpWvK
qC2j5quN8Gjep/Cevjiao+tcmK+Hu3uE9y+sA9pG14hRK/a0zr8oPR9rF450
D3R/9N4ipv427c89M3Oye0bXTxHLwznsJXlOzXkXbPKB6X5w1nN0zq417/92
hflicj0v1ZyXw+Zie3l+OOsZ+HuS2wbnIfC5u6j/FR1bq7A/0yDN10aFdSC6
kPVZKRy/kAtHn8JpsYd2r9m+rcMeQAeXXl/UOCxP65f53aCwzkR3zq6ZZ8Xm
YHvgWLsU5tjhXuFI4XHhc+FOqTGYWnWNE7UH1JxMq7rGhVoUapDGp3wSsQE1
J9SekFOn9oUamAcTv0htDBw5OVVsLv4KNStPpHiLWhb4q+eqrjkgPr6P/VHY
ZmO7B6X4rG2KL8iJkLcl5iNXgj7FNpNDPzNaf56bmTOm9gL98X2wz7w86Ztv
g31q9M/MmmsIdxZeUdi/I+fBGv8g+WvkuufreoOiczDkIF7GJ69ZH8G5wM/A
JfZgPRa2KdgW4lF4Lviu55M/B4eNTllc2v8hV49Pta76lwqfU7g+ZdPkX5Kj
waYsK+2vwOVjQ34X3jk4x41PdVDy78grkV+6J8033Do2e9+a9xPcNz7APpI/
ULugcH0l+ZrO0VwQPHabpM9/D47J0e/Yq4sK10OQGyDnQV4fHxlf+emaOS5s
xCfJvvwaHMNTC4k9+jOYo8C+4B+01O+DFdcCLKs5B0B95Ha63i3oi8I2FlvL
fiLHjo+Gr0ZNzSMphtmB2ELtssI+Gr4aNWBjq66RojaMOWau4eA+KV3D90DV
NYPU9lEzM6XqGi5qadrXXFtIjeGxwsODa3+oAWom3AH7WTVndFzpmrzNkz1B
31GjRK0SNUpnl67Bo5bzmMy1eR35HvB6+ETqvxL7XnWMcrLwpdhH4TH4bPjS
wj9X7XM3EW6HfRQeJ3yU8O2699fCo4QP43upf5XwaHxA4ctY/8Jj8bFK8zmD
Eh8EH3NaNH/xbtIH1MBQm0TND7Ux5BBuTvw0uQVqrn5P3+McjX8k+H2o0aVW
lxqpP9L7nVu6xgp+5sjM/BE1j7ckfhuu6YxovoWcx6+la3SoPW2cuXYHe7JZ
so/YF2o2hyb+CK6Jms97El9GLSj7EY6NmqLtJV+Bz5ae7ySdf02yp68l+0FM
uFayVy3TfK9K35/5IV6dn/gD4tt7a/7eo9N6GCr8Vfr+JwjfI/yl8EjhpqVr
2qhto4btLOG7aubve2aOf6mxm1h1jSW1d9RgPV51TSO1WdTYkV9vlZn/Yv2H
wj4j+o6avMeqzr9TqwdfRj1Da/wP4Quj863knNeOrsFdndb36Un//lh1je5O
Nc/nGsn+M3/UFI5M/B+1oHCkIdlfuFNqstdM9p/575TsM/adWJEazlGJ/6M+
gHqB0YlvLNP6XZb4Adbr8LT/HknnDxH+THhY2o+Da+YPBqb1fkE0f7I02Ye7
1b808QuHltYncB4thXdkrZTOle6W9BM1yJ9XXaNObTKcDfWWnYO5HHQvsQL6
hnwkPgKxad9g34E55F5dg+cWnwCu5dpgXwGdRO0OuWV0FflYfH1qfsgHUu9D
bElNxytV+3jvq++FYN+PNcTauTd4bbFmWbtTg32h/xWOpd7NXP9EToVY6Z3M
uRZ8PGKh6cG+Hz4YvucTwb7ZXoVjGWrQyD/iM86V/HiwL1m/5tgPm45tX6Mw
1wAfBi+Gj7pE8uxg3xWfdqnwi8G+bps0f/cl/wedzrdkTpibl9CZwl9UXU/4
SOlr8y3I388o7TvBYcFlMafsrVuD55r6GbgXaqTerdrXglvpn85hzbDWBwev
pVg4Nud9Z1a9hti7twWvLWw43AA6BF3yaGnunneFCzy4cGyKf0g9A/VBxKL4
B9QnUG9G7Ac/QX0D+XNiEXwW6gfZU+yth4N1JWucvTIueO3js8EF7Bfsy8EB
wAVgX+Gn0Ln46g8F62J0DrbmvmBdxJ7G9x8bvNfROfje44N10TulYxNsFrYL
Dg8ub3sd25p+3W9Z7vwI9TjMCXNzf+baT2pIV6b9SG0pNo5YYkKw7YOjgKvA
5sKfoSOxFcOCdSc2Hltfj/kpHXMQu88IjkWob4Nrgq+ivgNuj1hjQub6DWIE
6kPwufG9iSGIhaYExxbUnM1O+Sj4VHwtuCD8c+pJqFcgFsdnpD6TGGqx5OeD
Yys4EbiR7TLza8Qc1K8QExAbrIiOLfCxmZ+do/+LslNmvo8Yb5Hk54JjP+ok
iE1ZU9R7ElPBRTwZHGvBacJtEh9vU3MMTz5yauHYfu+auRtifmJ/ctTwe/hP
5xWuUYA/pEaM/Cg2C9t1f7CvkdWsn9CZrG/2IHuxX3Bs8n20L4QPjy//b/T/
LdCh7K/G6frj1c6XXK15/2HzWG/717ze8dHx1YlRsCVwcsQu5MjOz13fQ+4s
r3m/YyPRZ6Hm/YdNZX18FM2d4mPia1Zqfl50CPsXn4u1ODTYF8NnwhcaGexL
4YPiq+wT7Jvi/+HL7B3s+xMLsxaIN8YE61Ns2bRg32DdFPsRT00Oto2sPWJe
3gkfAl9qRLBvgX5hLwwJ9h3x2chd3BHsy30XHSvhc+J7fhP9fwB8VHxVfDps
zz3Bvh4+GrmNO4N9N2witnFAsG+Hz0cuZGCwL/hXdC0APgX259doX5aYjtju
52hfAJ8C3+KfaP2InmT+iUF5X96b2PTF9H2xidjG2en9+P7o8j+j7RUxMPbt
72j9SwyNPVwezR39kL43OuS/2r7cuoUYle/PPBC7Ui9D7LNRZr7542hf/cc0
f9SXEatQgwufTX003CScIXwz9dhwjdQcwg8TQzJfzBu+DRzgB8IvBXOD1KTB
d5NDeyO4JgU8Gn+qMB/LnoVDWq1zf4+OhYlhiWV/iva18MnwzX6Ljp2JmYmd
f4n23YgpiC1WR/t2+Gj4aj9Ex8rE1MTWxPDLsS/B3NSP0b4KPiG+ITUw8PHw
q2cWrvGDLydntyD4/1zoUvhBeEJqFMkPUFPVujAnukz9LwdzpXCgHwrPCeZG
4Zw+wt4Gc1HkfMj97KpjdWv2ufG9nwrmeqhP+TnYh8KXgl+fUHGOglxFn9K6
Ap1BbqNudG3EQxXzx/DJyOTQj47OL5Gr4xrw88SE6DZ0HLkM4lX0Dte8Irom
nloTakrhp+FLqeV5rGJ+lBpCdM3DFfPh1NPRR30FtRzEsMSyxDzUzsCfM5Ya
d/IzI6JrKaipgG/kHYllqcnh3YeUjl2IYchfTovmXqnRIP88V/0PZI7R2J8v
J31MTMH+fa107EhMx35/tbSvi8+L/ni99P9hiDHRb3OSviEmRJ8Qr/NfAnLQ
1G68kvQfMR764o3SsSQxD/rpzaTf8Mnxzd8q/X9GfHh8+beFX8wcAxELzRee
ljkmRZ8uKB0b4ePj688rHUsR82FfqHGiVoQaePgu/qNA7dC4ivl86mH4P+aM
wvVP/H/g88w1VNRSwd/i71BDNSaaY4Nrw6cnN4rPjO8MJ3994kvYp+zXdmm+
4Ia5B/U2XUvvFfYMuawP8FsrrrkmPzuc+1f8HyP8D3xAfEH4hnODa+YnpfoT
6qluLF07RM0QtUNcH11FzRn5Dmrun8ld8zUh8UVDsNUV1/JSczWzcPwLH9St
9LOjc8i9cf2RFefkyM2R78CXxOfA9yD/hi9JDWsbybeX9gXJCZEbIh+Cr4RP
hG+0eXQt39iK8z1wPOS72UPsJfJDYyrWIeTeyFdQq07Neutonxvfm3iEWlry
rdRScc7/55O4NjURh0b/B2Rl5negnoqa9hWZ/4NxaXR+h7VAjpBc4YDSuoUc
F7muYaVrg+DnyH3Db1HX2DGdf0tp35Sc1by0347I7CPhK5FDJ5dOPLet5IWl
ufINkz2nBmlp7voIapPg2KinYA2xljjWKNVQEEuOiq4lokZpVrS/ylpBl8JV
vRVdF0J9yIzoGlBqoch5PxWdEyM3tqOe9wW+femxcBxwHeRDeFdqJqideDO6
boT6kenRNRTUUvAM9WrmqOGqpyd+7vvSY9FfcDcL1brkroe6RPL/Af+d3ms=

         "]], Polygon3DBox[CompressedData["
1:eJwt13m811Mex/Fft9+9v9JClhbTxKWSJW3KtJgZhAqhjSylXTXa92kxLRJa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         "]]}]}, 
     {GrayLevel[0.82], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlNlTzmEUx9/39/R73xaVZGkaNUVIhmGirFlbUJbsO9kzcYfwB/gPDDdu
jKHcusGFJYwLN4yxjSyJbEVERPl85zwX5/2c5zzn9/x+7znf8+TXHao9GEQi
kROYw+L8JMNE2MFGiP8BfsN6o5FIN2zHuvHfwclYG346eVVR8/vxY/4cnZeE
JZCXDG+G5l+AjnUUPwH+g/16VufDQviQ54v9Wv4v/D78XvgHSyTWB89xVhL+
DdjJOobfBV9ineS/guN5RzF+Ebwe2vefhVfikUgB+81wlLNvHw2PsZeG3+hs
fwx2mfVYOA5rwa9lLxt/FZzoLD4J/oAcF+mB1axHwho4CEshnursP5VE7ZvO
kNwKT8M7+g7ym2A9eRn4B5zltvr8mc5yZsE3qh9ntgV2zgRi9+LWh6LA+iJf
fRrAX8P+JrhWxKrxN/vvUa31nh2s5xCvg/m+JqrNfCyPnAVwLzaJ+D5YieUS
r4JbseH42+BirJGcJToPO4VfBhdiJ/EXweVYPf4KuB7L4tkN8AX/YRe8BR9j
8/Bvw2tYBTlX4aW49UR+ja/zMmfP65yNznovDbwOTDfSz+/ANPBefQxNf9Jh
6PWZonfBwTBOPMNZD9SLBmf9Vt9Xw8+whzO/BKZdaXggsD7OZv8u3A2HEtvj
bH40R9+lI6/JQmf1Ut22O1srLs0e0RwRv8j3FDvT4VT4yb9X729iL5U6HCX+
KLRB1iw8wdJVw9A0J+2lOZst9Xta1GZbj3yEI6RRmAWfEcyGzaHpWHr+CTtC
+y/qS5efta+BaU060x3Q52fzL8yM26xI22VeA3Od9Vt9X+lMB9JDuTPNSXs7
YWnM9Ka+H/a90H+RBqawfhA37UrDW+B07Dz+DNjC3lL4FJbAcp4tdaZX6Xa/
s7qlBfYflS+t5sT8bOCvU99UN3KGwSGqD/FM+Jxn8uBxWOH1X+nrp36pH/d9
PTQ/rV6HupOizu6rwFnNNJfKUT/a/YznsJdObq6/i3SW3tXgddgc2H5qYPdU
m78H3gZ2f+m8AvgfHT6qvw==
         "]], Polygon3DBox[CompressedData["
1:eJwtk0tvjVEUhvfZq1+/9rQu1TpudU0viVCiWlQMEIII0RCiITRBGLhNqF/g
LxgYItTUBAPVU6Q0ROJWNCEYEI1Lq67lWd4zePM9a+219157rfXNbj/SejiG
ENaiInTSQhiDYyy6lISwDPs8/jnYLXAdasqE0Ijq4SVoTVTMUvg+eybyLcN3
ET4O/yJ2BPse9rWUu+A6dBm+i+8TXMz+Y8Q+xLfQFHMd7kdbsadiX4AXmPb6
use9icr7C3e8hZ8RswF/B7483JkqN8/xKnwGDRDbjCrhXnSQ+AZiBsilG7uK
2H34XqbK6Tuxn6Ny7UXvYT7hKGsPgFfYg8SchZ+zZyf+yV4T+AXag53DPpdq
zzCxH6LO8pw8t2b8d+DH+BI44/vhPl/HPs19cynSPDgP17M+31TTbzBh/2vt
ZzTxrSm8199UAR8yvfU3XELsKDn8icrZ6/c66i09KEtsEfbNRHfO8HqbcrmN
lpvm4RY8zTQrPjPV8C60Mei9u+H9pnp6fQ/AFSjFLseeAK8zne/9Wu91Q+V+
HvYUU8/b4G2mWfCa+vltplr7jJUVzjuBrzNRPp5Xf6Kar2Btr6kXm/hWez3w
bfa70Tifd+yZ8Co0K6req+GPUf3y+RyEuzizFM6w9gjOo3dR83cD3m7K1/u/
A16ErmDXYjfCW0x3+zy3mnqcxS429b7B1FufcZ/1HMpG1WSSqcZea895OrzY
dLb32/vekyr/lfATuIbvKOf/Re34f0T9jz4DP+GvUfPt8zMEdyfqz3j2PYU7
vEes96FT2NEK7yfGTPX3/HKFf7/E9B6fn1K40tQb71EV/A/RaXp5
         "]], 
        Polygon3DBox[{{1473, 768, 767, 510, 1444}, {1475, 783, 782, 11, 
         886}, {1962, 151, 829, 828, 1990}, {1439, 5, 744, 743, 1472}, {1565, 
         540, 844, 843, 1988}, {1979, 181, 818, 817, 1980}, {1987, 868, 867, 
         61, 1512}, {1993, 810, 307, 478, 1946}, {1451, 794, 793, 13, 1450}, {
         1403, 461, 254, 801, 1499}, {1403, 800, 799, 14, 1402}, {1945, 196, 
         812, 811, 1946}, {1448, 11, 780, 779, 1474}, {1989, 832, 831, 151, 
         1591}}]}]}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt00dsj2EcwPGXGjcchIRqFZVIuIkQbo4So3aN2pQOtfem9lZ7qxVb7dZo
URRV1T20CXFxcnPzeRKHT7+/93n+K+/7NGFGZlJGiyiK/tJkCHOBPz+1Wetb
R1EHc4y5wRxvTouJopKWUXSDWzS2jaKbuoCPfOI2Jdbv6h3S+EyptVK9Rx73
SedLYK9MH/CIh2TwlTJ75fqYpzwhk29U8IwC8sNv8NqFWkkVz3lJtfUXmhVm
angVfpf1Ii1kEbXUhfdbf61vecNi6pkZvtNesc7iHUtoCL/H+mx9zxw+sJQV
lNtbpnNJZTLJdGnlfe7rQPe4q7nCPMgca640d9MqjdNqjdca7a61mqB12kPr
tac2aC9t1ET9rr21STt5joN9fn/f3ey6b3gGrle3ca9dp2uRpmiejtJcHao5
OkCztY+u0FhN1XaarJEOkz++Z4j+dt3R5/cz/zK3N8eZC92PRGdpku+fx3Tm
U+x9y3Ui15nGVVLCs7B3TSdwhankhmdpfYpeZjwXucS58HztXdDzjOMMZ8PZ
sH5ST3OKsRwP59f6Cc3hGEcZE56z9cN6hAMc4iCj2cd+drM3nAOv3aNJ7GQX
2ewI58Dedh3FVraxiS3hrNvbrCPZwMZw9q2t1fWsYwSrwxmzvkZXsorhuJ1R
53Df3WOXUZY53/zj///3P6gGkB0=
       "]], Line3DBox[CompressedData["
1:eJwl0ckuQ2EYBuC/1RpaVfM8s7JyGdYuwQWYFobErYiNiAthg4QNERLzPE+l
lPKcWDx53//7m5PvnPaMjA2PxkIIc7woCTmfDOFBP4iHcMgRx2yZn8hTzjjn
ghXzS3nFNTesmd3KO+554JEn1t09yxdeeSPHOxvuPmSeT74o8M0PRX4JJSFs
+21MxikhQZId81JZRjkVpFg1T8tKMlSRZde8WtZQSx31NLDprlE20UwLreyZ
t8l2Ouiki2723fXIXvroZyTa29qDMisH5JBvPBvt4Zxxnon20lP6dLSnXqZP
6Wl92XMTzil9KXp3vUJf1IueVa4X5GT07npen9BL9Zw+Hn0ffSH5/1//AU4r
Pxw=
       "]], Line3DBox[CompressedData["
1:eJwl0ckupFEAhuGDYC1ERJogYqbbWGbaPM/zrMwEa4kLcAd9BUiwdQcSQ2LD
Qky9dhmeTi+efO85/59KpSo7ejh2EBNCOOZvfAhlNiU2hC/dpE8TQ0h1HtBn
Ok3P63Odrnf1D5uREMKRztRF+kRn6Yj+oy+8n+N8pi91rr7WVzpP3+hkXePL
VDo/OxfYaue8uBDyKaCQIu69W2xLKKWMn/ziybNyW0ElVVRz9+/zbYRa6qin
gVvPGm0TzbTQyov737aNdjro5NF9l+2mh176eHXfbwcYZIhhRhhljHEmePPu
pJ1imhlmmePds3m7wCJLLLPCh2erNsoa63y627CbbLHNDg/ud+0e+1z6TZNi
///X3y2YMbo=
       "]]}, {Line3DBox[CompressedData["
1:eJwV0DdOQ1EQBdBBIq2AnFxRgERoTDCZFbAEREOyCa1JNmByXAI1gjXQATU0
WCKshPOKozue+/X/yJnFwkK+JiKWqNZFFBsidhhhmd7aiKzc5YE9PuojVuQT
RfOo3OeRA5roa4x45Tm9zzNjskSZZr50q+m9unF5yBFZ+xa5lr6ly8ljvu0H
aDWvp+/pJuSg3Q8Vcxv5dINuUp5wSjsF3jxX0k2Zzzing377d8q6ab8vuKST
qv1Guk83I6+4Tv+PfZfcTHfrZuUNv/ZDdJu30u26OTls98etuYdtKrp5+Wl/
J+/JpLvtX+Q/LiowwA==
       "]], 
      Line3DBox[{1501, 465, 1861, 427, 1461, 571, 528, 1949, 565, 1948, 1750, 
       1826, 2269, 428, 1862, 1751, 1827, 2252, 1673, 1863, 2077, 2105, 1828, 
       1674, 1864, 2078, 2106, 1829, 1675, 1865, 2263, 1752, 1830, 1676, 1866,
        1753, 1831, 2015, 2231, 1867, 1754, 1832, 2253, 1677, 1868, 1755, 
       1833, 2254, 1678, 1869, 2079, 2107, 1834, 1679, 1870, 2080, 2108, 1835,
        1680, 1871, 2264, 1756, 1836, 1681, 1872, 2265, 1757, 1837, 1682, 
       1767}], Line3DBox[{1522, 1697, 2117, 1521, 1696, 2116, 1520, 1695, 
       2115, 1519, 1694, 2114, 1518, 2170, 2021, 1517, 2169, 2020, 1516, 2168,
        2019, 1515, 1693, 2113, 1514, 1692, 2112, 1513, 1691, 1983, 2279, 
       1984, 1076, 1970, 1972, 1973, 2242, 2102, 1953, 1775, 1840, 2241, 2018,
        1877, 1774, 1839, 2093, 2240, 1911, 1875, 1773, 1995}], 
      Line3DBox[{1536, 1702, 2122, 1535, 1701, 2121, 1534, 1700, 2120, 1533, 
       2175, 2026, 1532, 2174, 2025, 1531, 2173, 2024, 1530, 2172, 2023, 1529,
        1699, 2119, 1528, 1698, 2118, 1527, 1090, 1526, 2171, 2022, 1525, 
       2243, 1781, 1954, 1780, 1524, 2255, 1779, 1878, 1778, 1523, 2099, 2275,
        1777, 1876, 1776, 1974, 1999}], 
      Line3DBox[{1550, 1705, 2125, 1549, 1704, 2124, 1548, 2183, 2033, 1547, 
       2182, 2032, 1546, 2181, 2031, 1545, 2180, 2030, 1544, 2179, 2029, 1543,
        1703, 2123, 1542, 1105, 1541, 2178, 2028, 1540, 2177, 2027, 1539, 
       2083, 2176, 1786, 1538, 2257, 1785, 1880, 1784, 1537, 2256, 1940, 1783,
        1879, 1782, 1975, 2000}], 
      Line3DBox[{1564, 1706, 2126, 1563, 2194, 2042, 1562, 2193, 2041, 1561, 
       2192, 2040, 1560, 2191, 2039, 1559, 2190, 2038, 1558, 2189, 2037, 1557,
        1120, 1556, 2188, 2036, 1555, 2187, 2035, 1554, 2186, 2034, 1553, 
       2085, 2185, 1788, 1552, 2084, 2184, 1882, 1787, 1551, 1416, 1941, 1881,
        1977, 1976, 2001}], 
      Line3DBox[{120, 965, 119, 964, 118, 963, 117, 962, 116, 961, 115, 960, 
       114, 959, 113, 958, 112, 957, 111, 956, 110, 955, 109, 954, 108, 953, 
       401, 107, 952, 400, 623}], 
      Line3DBox[{1577, 1718, 2137, 1576, 1717, 2136, 1575, 1716, 2135, 1574, 
       1715, 2134, 1573, 1714, 2133, 1572, 1713, 2132, 1571, 1135, 1570, 1712,
        2131, 1569, 1711, 2130, 1568, 1710, 2129, 1567, 1709, 2128, 1566, 
       1708, 2127, 1790, 1842, 1707, 2266, 1884, 1789, 1841, 1128, 1912, 1883,
        1960, 1996}], 
      Line3DBox[{1590, 1728, 2147, 1589, 1727, 2146, 1588, 1726, 2145, 1587, 
       1725, 2144, 1586, 1724, 2143, 1585, 1150, 1584, 2195, 2044, 1583, 1723,
        2142, 1582, 1722, 2141, 1581, 1721, 2140, 1580, 1720, 2139, 1579, 
       1719, 2138, 1793, 1844, 2244, 2043, 1886, 1792, 1843, 2270, 1914, 1913,
        1885, 1791, 1961, 2008}], 
      Line3DBox[{1603, 1736, 2155, 1602, 1735, 2154, 1601, 1734, 2153, 1600, 
       1733, 2152, 1599, 1165, 1598, 2197, 2048, 1597, 2196, 2047, 1596, 1732,
        2151, 1595, 1731, 2150, 1594, 1730, 2149, 1593, 1729, 2148, 1592, 
       2247, 2046, 1796, 1846, 2246, 2045, 1889, 1795, 1845, 2094, 2245, 1915,
        1887, 1794, 1998}], 
      Line3DBox[{1617, 1742, 2161, 1616, 1741, 2160, 1615, 1740, 2159, 1614, 
       1180, 1613, 2201, 2052, 1612, 2200, 2051, 1611, 2199, 2050, 1610, 1739,
        2158, 1609, 1738, 2157, 1608, 1737, 2156, 1607, 2198, 2049, 1606, 
       2248, 1802, 1801, 1605, 2258, 1800, 1890, 1799, 1604, 2100, 2276, 1798,
        1888, 1797, 2006}], 
      Line3DBox[{1631, 1746, 2165, 1630, 1745, 2164, 1629, 1195, 1628, 2208, 
       2058, 1627, 2207, 2057, 1626, 2206, 2056, 1625, 2205, 2055, 1624, 1744,
        2163, 1623, 1743, 2162, 1622, 2204, 2054, 1621, 2203, 2053, 1620, 
       2086, 2202, 1807, 1619, 2260, 1806, 1892, 1805, 1618, 2259, 1942, 1804,
        1891, 1803, 2005}], 
      Line3DBox[{1645, 1748, 2167, 1644, 1210, 1643, 2218, 2066, 1642, 2217, 
       2065, 1641, 2216, 2064, 1640, 2215, 2063, 1639, 2214, 2062, 1638, 1747,
        2166, 1637, 2213, 2061, 1636, 2212, 2060, 1635, 2211, 2059, 1634, 
       2088, 2210, 1809, 1633, 2087, 2209, 1894, 1808, 1632, 2261, 1943, 1944,
        1893, 2004}], 
      Line3DBox[{1659, 1813, 1300, 1658, 2230, 2076, 1657, 2229, 2075, 1656, 
       2228, 2074, 1655, 2227, 2073, 1654, 2226, 2072, 1653, 2225, 2071, 1652,
        2224, 2070, 1651, 2223, 2069, 1650, 2222, 2068, 1649, 2221, 2067, 
       1648, 2090, 2220, 1812, 1647, 2089, 2219, 1896, 1810, 1646, 2101, 2277,
        1947, 1895, 2003}], 
      Line3DBox[{1772, 1690, 1768, 2238, 1511, 1689, 1766, 2237, 1510, 1688, 
       1765, 2236, 1509, 1687, 2111, 2082, 1508, 1686, 2110, 1764, 1507, 2235,
        2017, 1763, 1506, 2234, 2016, 1762, 1505, 1685, 1761, 2233, 1504, 
       1684, 1760, 2232, 1503, 1683, 1985, 2109, 2081, 1952, 1982, 1981, 2278,
        1971, 1759, 1950, 1969, 1455, 1951, 1758, 1771, 1910, 2239, 1909, 
       1874, 1770, 1966, 1838, 1380, 1908, 1873, 1769, 1956, 2014}]}, {
      Line3DBox[CompressedData["
1:eJwVzrkuRGEYBuBPkChcgU5jMhEEERHhClQaiW7EMrYzNAqFdexjG1ujUEtM
RxQKDbUErcKSKF3BxDPFk+/93zc5OY0jucGkKiIyNNREPNBbG3HBOT91EfW6
Eol3D2e860/dcnXElW1W7uaEV1vR/bMVbTNyF9/6Y/eIT1veNi0/6TvdQw54
sy3YPvRT3u3sU+DZlrVNym3sscu9fliflVvYYZtr/YB+Qm5mixff3XQvbf22
cTnNl37DzVf+w9ZhG5Mf9Sl3nTVWba22O3mUpkpHiRUW7Wn7rZzhV152b1gi
sad0Q3Ifc+SY5x9lDzRS
       "]], 
      Line3DBox[{1051, 1213, 1340, 1298, 2219, 1037, 1199, 1338, 1296, 2209, 
       1023, 1185, 1336, 2260, 1294, 1009, 1171, 1334, 2258, 1292, 995, 1157, 
       2246, 1332, 1290, 981, 1143, 2244, 1330, 1288, 967, 2266, 1129, 1328, 
       1286, 953, 1115, 1326, 1284, 2184, 939, 1101, 1324, 2257, 1282, 925, 
       1087, 1322, 2255, 1280, 911, 1075, 2241, 1320, 1278, 898, 430, 2239, 
       1277, 1276, 891, 565, 1433, 557, 558, 1967, 415, 1342, 447, 1303}], 
      Line3DBox[{1052, 1214, 1299, 2220, 1038, 1200, 1297, 2210, 1024, 1186, 
       1295, 2202, 1010, 1172, 2248, 1293, 996, 1158, 2247, 1291, 982, 2138, 
       1144, 1289, 968, 2127, 1130, 1287, 954, 1116, 1285, 2185, 940, 1102, 
       1283, 2176, 926, 1088, 2243, 1281, 912, 1460, 1459, 2242, 1458, 1279, 
       899, 1456, 1455, 1434, 1257, 892, 1379, 2269, 1378, 1355, 1226, 1432, 
       1452, 2249, 1369, 1368, 1343, 1225, 1438, 1481}], 
      Line3DBox[{1053, 1215, 2221, 1039, 1201, 2211, 1025, 1187, 2203, 1011, 
       1173, 2198, 997, 2148, 1159, 983, 2139, 1145, 969, 2128, 1131, 955, 
       1117, 2186, 941, 1103, 2177, 927, 1089, 2171, 913, 1076, 1467, 1457, 
       1469, 900, 1464, 2278, 1463, 1435, 1258, 893, 2252, 1066, 1356, 1228, 
       879, 1371, 2267, 1370, 1344, 1227, 1489}], 
      Line3DBox[{1054, 1216, 2222, 1040, 1202, 2212, 1026, 1188, 2204, 1012, 
       2156, 1174, 998, 2149, 1160, 984, 2140, 1146, 970, 2129, 1132, 956, 
       1118, 2187, 942, 1104, 2178, 928, 1090, 914, 1466, 2279, 1468, 1465, 
       1471, 1470, 2109, 1260, 1436, 1259, 1311, 2105, 1232, 1357, 1231, 1304,
        1394, 2103, 1230, 1345, 1229, 1440, 1490}], 
      Line3DBox[{1055, 1217, 2223, 1041, 1203, 2213, 1027, 2162, 1189, 1013, 
       2157, 1175, 999, 2150, 1161, 985, 2141, 1147, 971, 2130, 1133, 957, 
       1119, 2188, 943, 1105, 929, 2118, 1091, 915, 2112, 1077, 901, 1262, 
       2232, 1261, 1312, 2106, 1236, 1358, 1235, 1305, 2271, 1395, 1234, 1346,
        1233, 1441, 1491}], 
      Line3DBox[{218, 1652, 203, 1638, 188, 1624, 173, 1610, 158, 1596, 143, 
       1583, 128, 1570, 113, 1557, 98, 1543, 83, 1529, 68, 1515, 53, 1505, 38,
        1866, 385, 23, 1854, 373, 595}], 
      Line3DBox[{1056, 1218, 2224, 1042, 2166, 1204, 1028, 2163, 1190, 1014, 
       2158, 1176, 1000, 2151, 1162, 986, 2142, 1148, 972, 2131, 1134, 958, 
       1120, 944, 2123, 1106, 930, 2119, 1092, 916, 2113, 1078, 902, 1264, 
       2233, 1263, 1313, 1238, 2263, 1359, 1237, 1306, 2272, 1396, 1397, 1347,
        1443, 1442, 1492}], 
      Line3DBox[{1057, 1219, 2225, 1043, 1205, 2214, 1029, 1191, 2205, 1015, 
       1177, 2199, 1001, 1163, 2196, 987, 1149, 2195, 973, 1135, 959, 1121, 
       2189, 945, 1107, 2179, 931, 1093, 2172, 917, 1079, 2168, 903, 1071, 
       2234, 1265, 894, 1067, 2231, 1360, 1239, 883, 2250, 1064, 1372, 1348, 
       1445, 1480}], 
      Line3DBox[{1058, 1220, 2226, 1044, 1206, 2215, 1030, 1192, 2206, 1016, 
       1178, 2200, 1002, 1164, 2197, 988, 1150, 974, 2132, 1136, 960, 1122, 
       2190, 946, 1108, 2180, 932, 1094, 2173, 918, 1080, 2169, 904, 1072, 
       2235, 1266, 895, 2253, 1068, 1361, 1241, 884, 2251, 1374, 1373, 1349, 
       1240, 1447, 1485}], 
      Line3DBox[{1059, 1221, 2227, 1045, 1207, 2216, 1031, 1193, 2207, 1017, 
       1179, 2201, 1003, 1165, 989, 2143, 1151, 975, 2133, 1137, 961, 1123, 
       2191, 947, 1109, 2181, 933, 1095, 2174, 919, 1081, 2170, 905, 2110, 
       1073, 1267, 896, 2254, 1069, 1362, 1243, 885, 1376, 2268, 1375, 1350, 
       1242, 1495}], 
      Line3DBox[{1060, 1222, 2228, 1046, 1208, 2217, 1032, 1194, 2208, 1018, 
       1180, 1004, 2152, 1166, 990, 2144, 1152, 976, 2134, 1138, 962, 1124, 
       2192, 948, 1110, 2182, 934, 1096, 2175, 920, 2114, 1082, 906, 2111, 
       1269, 1268, 1314, 2107, 1247, 1363, 1246, 1307, 1398, 2104, 1245, 1351,
        1244, 1486}], 
      Line3DBox[{1061, 1223, 2229, 1047, 1209, 2218, 1033, 1195, 1019, 2159, 
       1181, 1005, 2153, 1167, 991, 2145, 1153, 977, 2135, 1139, 963, 1125, 
       2193, 949, 1111, 2183, 935, 2120, 1097, 921, 2115, 1083, 907, 1271, 
       2236, 1270, 1315, 2108, 1251, 1364, 1250, 1308, 2273, 1399, 1249, 1352,
        1248, 1497}], 
      Line3DBox[{1062, 1224, 2230, 1048, 1210, 1034, 2164, 1196, 1020, 2160, 
       1182, 1006, 2154, 1168, 992, 2146, 1154, 978, 2136, 1140, 964, 1126, 
       2194, 950, 2124, 1112, 936, 2121, 1098, 922, 2116, 1084, 908, 1273, 
       2237, 1272, 1316, 1253, 2264, 1365, 1252, 1309, 2274, 1400, 1401, 1353,
        1478}], 
      Line3DBox[{1302, 1301, 1300, 1049, 2167, 1211, 1035, 2165, 1197, 1021, 
       2161, 1183, 1007, 2155, 1169, 993, 2147, 1155, 979, 2137, 1141, 965, 
       2126, 1127, 951, 2125, 1113, 937, 2122, 1099, 923, 2117, 1085, 909, 
       1275, 2238, 1274, 1317, 1255, 2265, 1366, 1254, 1310, 1404, 2262, 1405,
        1354, 1479}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvGdQVNv6N4iigIhiwgiiIEkQREUQw6OggkgUlSAqKEElCSLJgCTFgCBI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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  Lighting->False,
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{0.01, 80}, {0.01, 80}, {-1.5681039730882915`, 
    49.90465673238451}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  ViewPoint->{2.107, -2.506, 0.854}]], "Output",
 CellChangeTimes->{3.549362852681013*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[CellGroupData[{

Cell["\<\
ContourPlot[Profit[x1,x2,20,1,1],{x1,0.01,80},{x2,0.01,80},
ContourShading->False]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJzMvXV4Vcmz9xtIcCe4SyDBE5wgq4EQSEhCBBncR4DgzjDo4O46g7u7DQ6D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   
   "], {{{}, {}, {}, {}, {}, {}}, {{}, 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl1EdwjVEYxvETDDFaorcwykIvKyUSo2yUIWpYCiFqGKPb60ZvUaLXYaON
3kVEibrQe7dRF9rvjMU/z3me877vOd+Xe2+DrNz+ExJCCAP8OVkxhLGVQmhR
I4TS1uuqhXCaXqoawmUUIJFfLz9Hr/CFmKBnsJ7xdKO98/Y20HxsQvvqIZRJ
DqG8vJW6XHX3kkKYRDP5iTTRfiX7bfhp/H376fo6IxVp6ISy6iqr22vuPuxG
Ab+HJtO2+mfp76a2KN5btsveTFlXWRdclV+S75RPl0/RM4NelG2T7cB2JPE5
zqtIW8d7utNUdetkeTjFF6NCfCd8OXqdn47PzplGC+Vd5FMr85iC5WYfjmdZ
v6KFfBGuIpO/qOe1/jd4hVxzasiqo6z9lu4yzj3OWufpOUN7yA6Y15OWsPfJ
M6bL0/n98o96t9ItSKwSQjY/2n5j/Y1wS89j56TJHvGB/2jGB1zhX8rHm9XQ
Ose6s3V9Nc+t8818QTfTcvF/Tp/xl+P/Bkf5I/EO1uvpBuRhI3LMGYPRGKSn
k5l9rdPoQf6480/gJOp7F/VQSp4S35PsApaauyR+HmQl4z4CSiABA+Ncz5uG
H55xS/w/xfdB+zqnv/P60HRZT9qP70W32R9KV9He9Jf7vlXzgF9jvVg2h17j
n8ifIlPWXf8m2RDrfDqYDojPR/9U8NmkGXz3+H2xX6RvhXtlyVbSVL4jetlr
puarZ/uOb9gsWyBrp7aOdRN1HfgUz/mdv6PmB02V9VHTkfbmR1hnYzjmufNc
HPXujuCvOy3gF2I+rqtfRINZi+lN/pD1DZpl3kAzhtHDsmLZTTOKcQs/+bvy
5vFz5FmK1NXlU5Adv3PuO4LW5uvgtp47aCF7yP+ms515jM6ix2ktMyY7syZN
0p8c37XZGfauWfej5/VeiL9LeBR/u/SuxbJ4hpr3eId29gpoU/OaoQnOmZUg
C/jiPY50n1Go63tSDykY5ewX9l7iKZ7jGbLiTLrGOWuxutr/39F/WaXFQg==

         "]]},
       "40"],
      Annotation[#, 40, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{3609, 3618, 4873, 4741, 4742, 4574, 4874, 4875, 3977, 5706, 
         3978, 5707, 3788, 5553, 5555, 5554, 3610, 4365, 5702, 5703, 5701, 
         5705, 5704, 4314, 3973, 5941, 3607, 4364, 3968, 5977, 3969, 4313, 
         3967, 5939, 3604, 4363, 3965, 5976, 3966, 4312, 3964, 5938, 3603, 
         4362, 5696, 5538, 5539, 5537, 3780, 5689, 3954, 5310, 5311, 4572, 
         4571, 4570, 4738, 4737, 3594, 3615, 4454}], LineBox[CompressedData["
1:eJwV1HlMl3UcwPHHAy8UUcjUmmblQda0zRLRXOFslVKKYksRLDHEA6Q82jyn
liguwdJa/VOCW1vZZWTHsmPdhW4Qhy4pTCskaFoqR9Ne3z/evL+f43s8X57n
N+KxgvT8LlEU1ftT1D+KVg6IohWYnRhFI+Ki6DjPwim5H8Q79Nx5bRQNNs6T
G8QTxIXxUbRdrUzuG67iKrlqfCv+whqfY981UbQfncYdmG5+L/UZ1ujNreIq
9Rau5hjrXI8lg6LoO/Uc/p4PypVjvr4m3Gv+n7xGLUXPas5Vf5ILxNW8gvOx
EtP0Nlo/lduc4zJGi0dhudxIzrfmH+EOjP9Rb+Bf0B/xODgwin5XrzQ+hqPi
T3DeeLC9h6CbffuK+yEOsfbug3nmlbmbGHuUcw9+hXfb5wAX86tciR/RYs5a
buY1/Fe4D+uvs06ydSeiXa4NF+TPo4u9DznPmATPhlK5rfoz9M5Fqd4SVMg1
6J3mDGuNn9W3hlPFp+RvEt+Ic87UhGbjI/I3W/N93sg9nGkDx/Aea3bV04N7
Iga90QvD9LfY+2+0Yop9ZuudzHfZr0L9PWRbZ5E4i3PV7uFscSofVi/mKeIU
tVnmT+LJ4nfV3kGdvTL11PACruXH9Zw1noo73MtEJGO3+Xmea6f8Ut7FyzjN
Ojd4prd5OL/F861TrP9pZ98e7tH8+frH6j/D6/V154t6LuEydiFH/Rn5xbyD
l/DPznOd/jesO5Rf50esX6R/JzrFmZ6pI9yH3omcJk7mfjhj/75cKPelcyQZ
V3CfcIccy+MxU30ct9n3HC8QN4d59liFOc6yXi2dN/Bcvmi/fs5UEt5f3sMP
OtsT+mfY9wH8a9wqn65+SP82jjW/Tb4dHeH7wzzrbZTP4E38ME81r7/+vRwX
3k1+KHy3+q/iCv5DX/0daEeZ+gA+wAO5nJ8zb7Nxsmca7Qz3mTOGJ4n3qT2P
RPWF4gTuxBBkiYfyfvUtnCJOMu9+82/hOPmz4VvnjvB7hcvhG0MbFunJdO7z
4T75Ai/kFziBX+RGa53GbxiG4aiVv9teBeavC/cf3m1xnfxp59jqmbZhpj3S
sEn9KX3pcnNQG84g14W74qLcJdxqfBsK1b7WP8qan1pvJH/GozneHklqTeE9
wEvY4n/xMm/kzeH/E957a6yyZiHGe5bV4Ts093Zxdvi/WSMOkb4S71kp9qBK
vJe7O0c31KMOJ615AtXqR8SLrTHBWh8Yf4hf1RoxTv2keDwf07NUz3HO40p+
Ldyh+jDkhu8ZP+n9SFzDH3M6L9SXFb45c8Y6e1e5RHFMuBs9DfxV+C3nq+Gd
0XMl/I7iMJaH3xEuci+HwjcvfjOcB/lyj4pXhm85/G7IZYiX8VFz6uVOhP+3
cU/khP85avA/CEIK+A==
         "]]},
       "30"],
      Annotation[#, 30, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{3678, 5399, 5502, 5501, 5556, 5506, 5507, 5503, 5505, 5504}],
         LineBox[CompressedData["
1:eJwV1nmUTnUcx/HLUCrrLFLokK1tRhhzDkNkLZWt7DNj5xxknLETYysSKUso
9IdMKGupME459lQ4xzZUJvs+Yzsdonr9/nif9/1+f5/7vb9757nPM1X7ZHYc
WiSKooyiUXS7dBRVLhdFN3l/mShK4xx1Ohei9eNRVMBTrbUoH0VTeGpsFO3T
W5MQRWuxQb0eZxy/ol87LooOyyXxEV5t3ioMtfaszDMYZu5V9SHHd+Oj6DQ/
LJvA5ZFj3hXrBx1f5kz5HXq31DfxpHkVUdw5cep4dJUraY/deGVZ85yzikvw
Cv7Qdb7k2ZzDB3EAbzhntjmv8yzONHeMGY3NbITx+uMQ67gcisnkcy+9nlgs
P1W+i15nLNCbj+/1xvJf8g30GyIV8+UXIF+/sWd0isfIVQ9/B3u7gWuOt+kn
Ws/lbJ6EiZgnOxcxMvs8k5+xF79gP6rLb+VqnMuF5jW1l47yTbhAfR0ZZqRj
q9wJHuhZHOcBnMeDZH/jdupfuX14XrxFfq5Zs9TNzZ/Nw8zroF/T/jZzX/0f
uIb6I9k+6t7IQL9wnvx5rsSV0US/KRa75hz5IXpvYzAyMRTtzXvavGqoijR7
6RH+dvI5zkvm+jiIA6gsv8P6Tozy3Edjodw2a4v4JddrjLJml8Et+0nlRkjT
nyG/Qm67fA91d3TDd3IrZSqZHxP2rm6gP0J+JHLlG6lT0TDcl/Vicjc5mdO5
q/57stPxk3wXdWd0wibry+Uqmn/HfaaqU/SHy24NnxG9HT7T97ixtacquB7n
us+P9YuGZ+Pc247Tubh6ueO0cB/qdtydO3EisqxHzs/kIjyC/7M+jmPUo7lo
eG/MT/E8BqnvWx/ID3gI3+WZ9vy53HRexjGuWcv8a/Zez/plTuYCTnMvdzhF
fZPr8xPm1zQ/T/2781/QayXXOnyvoJL1ihgvU4WroqV+CzTH8/InnRcX3iWZ
c+bU0TvNdfkCvyqXz0nqPziRy8vfK2XNfZwP1+QL/Bqf4w58idvyRZ4k3ya8
7+oC9VtcyN34Gr/j/hfbx1hexPfl75vfLLx/1nfpNeWW6mXh72gfzdQ3HL/M
1eWnOZ5hXinZvx2X5g/Uqx3PN3edcx/gH6y2NkdvN38iU4YjM9PdawbWy8So
i6JI+LxbXxj2yl9wQviu1O8ZvtPC97n8Q+riKIavrC8wfw+vkS8fvlPD+yzb
BxvlZ3gej+o9gnUya3FdbjNvwWP6/WVnyn0j/z73U/dFgnuKx175b61tCvcW
nlu4Z7mR6m6u3x1dw7uJHmjpWZUzOxZl0SF8R4V3PXw3OW+A2SVdd5e1nWFP
eoe5hrml9OMQj7Hh9868yfpl1VM4Q93K/Hj5z7iC/qfhnZBdzOtcp1Z4HuEz
y2v5X97Aibyek3gjL5Ev5Bs4Yu5RJNpLG7OS+Lj6GLI8g3Ky5+07lne75p6w
fzzQu4/e8j3tqRcy0Ae9sTS8P7yMz5p7DudRBXX1j+vX4TyeqDcBL5pXG0k4
oZ9lf2fseRq/i7b67ZDtmtnynfQ6I0/vnl5xfgjD9UagjuO6yLI2VP6SXpZ5
F3k4X+Y413nO2hX1VSwJ13PvS3kyT8UUtDVjlHyqPTdCPcd10Sv83js/FkVk
NsvO93yOOp7Hx3gBlwj/T4Rnpj7J5+TO4rg6V33KrD/D77c5vXDI3EHqgzyY
k+W+NmcisjEBuXqTuKrzq4T/QWSvhGen/yNvD9/leFPd28z+1uuH31NO4Xz9
BP3D+B+po1CA
         "]]},
       "20"],
      Annotation[#, 20, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV1WeQTmcYxvGjJEqiW6uG1WswWOWDunrvbTJYPXr0DUlE1KgjWsQgRYve
yegRwehE9GFNkIgyWkSQ3/PhP9dzX/d17lPe5z0nLnFQq4EpoiiamzKKUmWM
ol3Zo6h/bBRdtN4dE0V7MD9rFPXizaO9aXO9dPz0GC4/EiPwPFMUTcoRRc/o
CLkJvBQ0QqksUZTXcQd5F6z3Z46ibdbD6GF1vFmVME/93IzrdCJ9alYrfmuM
c/yPsp/RluoWeCPzGjFyd9U56J90mMwk2aG0oroCruiNlH3J60BXqtvTFXS8
7Pe0Z7YoekK708e0B02UHy53WV1FXQ1VsUwdTyujAiqhIuLMKu+Ym+4vGXec
+zayy5c0pxSKoQSK44173UK3YjPiw7OhS+Tb0KX0qjnXcB2Nzb9CL+O29Xj5
ceG5hPP6jcqhFCrxb7ueja4lOVybujC/GIpjjHwMPwdKqHPSWNR3vm5mJyI/
vyvtgo/lZ5tVkBeHm7I3sJ43VL2BDqP93etM653ys+gAdT7+ddlreOg6rtCr
yMPPixlyO+Sn037yuXmX9S/hmPxS599IY/g5EIvt8h/K9kWucE/6F+Uf0NO0
MM3Ez4Ks2CbfR7Y3MqoL6Z+SO0KPYh3q5XQ/dInzbbNvj+oXVKfjx9Ff1VP5
q/wu+dVp+AXoQf4W/l76nvotfj66Wz2GnxVr1An8tfQb8zfxtuvnVafi56Fb
1ZP5y82PVafg56Sb+Bv4q+kavLFeSZcjyTojMqO2/EKz52Odepn+d3hlvYQu
xsSwNn9Z+C9YL+ItDHOt59C5eGE9m87EKOv0eBc1zZ9j9mysUk/Vn45n1pPo
BIy3LmR2UTy0fuFZP8di6wS/QX387J5q0Rp4mQGyrzAq7DMk4Z592MG8TmiN
dmiLhvbIp7Lj0FTdAs1xS74RbYK6aBD2crgX82PC88SVsA9xLex/c/6gd3AD
t5Ac9gU/q2x2nFWfxzlM5J+kp3AcmfUzIQtOqM/gNMbKXQr7F7/hd1xAEX5O
2dx4pH6Cx5jEv08f4i7u4S8U9WxSemapMdHzmILJ+Md99nNfA9ALfdEnvH/M
mWb2DIxQjw6/HV7LD6XDMRBDMBilzW+D9miGzuiIb8M59dOEd6B1irDfXM8s
65/M3oN89sEL/nMc4D8K783wf+Y/oH+jrFm59PKgKX+Fa/8BJ9XlaQXE88vS
MpjD32f2ARTkp+W9jUPhG0JTogD/tdn/obz5+fTyh28Sf43+apxWV6Xd7LEq
/K60snou/xez66qL8uvRbPzD/Aw0Ibwf+XXoO+H6zI8L/1F1S/4Oup5/lleL
dldX4yfSGuE/xz9ifkN1SX4jmod/hB9LG6iL8+uH6zG7gN9lA3+n+gPPt0t4
1+KA3lTvqCnooe6p30DuCS1Am9Ha/ATUxR750bKjUEvdVD+/XJz5m+kW9Azf
cKwI32D5lfTL8C7kNdJviKeOK0QLoz6/ARbJ7ZX/mibJ1+PtCnvVuqD5O8Me
1m/smCboo56mt0p+Dr+E36lk2KP80rQUWoX9GL794Rj+R3QI5sm3UDdHQ7R1
PcXCN442o/1of/4gDMZ8+QXYY959+gAP0RrPwv2EZ4YZjnvid9krd5a2C+99
egan0d+1lqHvozTKoWz4RsvvDb8H9ofnLVfE7DF6Y1HdvdREDeyTrUMTUAs3
1bVpavl5smnCN1qdln5O9+svCe/B8K3VP0QT6dv0E5pMq3uONTDaeZfKJtGa
6rr20w7rr6z3hX0nvwAd1B3xhd4a+Qm0s7oT0jnvQpkb9F86P7x/+bVxLOwf
9QN+Ej1u5onwX3N8DNbqr8N5vXPh22qdnvYL39/w3pBZ5fmsDvsLj9Qrw76g
/wPNX3Uv
         "]]},
       "10"],
      Annotation[#, 10, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV03loz3Ecx/EPSa5t7PaPHFFmjE05/kELG//5j0RtJVEbojlytMw50ow0
MzPNNXIMu5irSK4iR+TMMUdE0XI/vn88f8/3+/V5fz99P9/f99svr3BaQYcQ
QqyfPzEhjO8VwpWeIUzibFSmhPAjPoR2fFEPTA6hP4rVaxNCWIfv6lLeiEPq
bYkhlGFcagjd9V1RhK3Wt6FdXc5lqFPv4gr8VFfbuwol6kpZFX6ra7gax9Q7
7b0LE+wfp4/BMtRaP4i/6jo+jOPqE3wSwfxBe9divbxedhod5Y18NpqTV9h7
N7LlCfpeWIEW6+fQSX6RW1Evv8SX0Vl+xN6HsFF+VXYNXeQ3+DrOyPfYuwoT
5Sn6ZKzETeu30E1+h2+jQX6X76G7/Ki967BZfl/2AD3kj/ghGuX77H3KfzhZ
foLn8Sp5LA/Wx3Aax3FTdD5O1/fkITyXS+UJnKGP5+GcyM3yXD6tz+F6ns+r
o3PwCH0SZ3IKt8ibvUd9vT99kCV/4T6/8uvoeVpPkxckhVCI1/pB+oEYgCfR
f+88T/mN+fOcLl9gdiHe6DP0wzAUrfq35p5zG79HlnyR2e2x1uRl/Ikz5VPd
4xQ806dyb4yUz+Jyc+/kO3i2/pc8N857wjm8H4vlNVzsjFvMLtCPcra96tG8
UL81+lasr9UX6Uu4WnbAdUv0tVxifR3GWvvgnsfwR35prtH/fYEb+CI38WHX
fOPH0Xk9n3fIdJ+v9Fk83b5tsnzOi94z8zM51XPojX/4i3yzG6L3FXOsb+ZN
0TdinyOuKZCtib4nZ16KZfgc3YPrlqtnWP8PPVekeQ==
         "]], 
        LineBox[CompressedData["
1:eJwV02toT3Ecx/HfkonYzGVmaWzMZWbmvrklMWWby39jQ8o1hm2hRDxR8owx
kntNIuSeJy65j2YkzS2U8mSuiVqK4XUevPf+fT+/7/me3zn/s/Ql1bGquBBC
oj/bE0PY1iWEhoQQzncP4QIuqy/hX7cQtvYIoTolhD2dQzhpfTg5hCNYITvE
BxGfFEInTsBg12dhof2BZi/j5fhr1gKe5j4fzCngVtkfnFAvdW29/nf8Wv2G
X/FbrtTbxOXOkKV/Hh9zzzrstt5kbi0f13/XjA3qO3zU/iHZevUa+80owzr1
QfkR+zXqjepdXOKaW567lFt5sfyMe3/We5q/8jp5ubwM/fWN4JGYLV/Eh/V9
jGZziSyGQc48EO/lM/klr5Xv9J5q8Eldpa7EarxVX9GXaX4mN6qnyzfr3YJm
9Qx1MQrxWN1fX4tnKOZVvEq+Q+89z/jC/lxnuyGfw9e5kvPtDY3Ors7hGOfy
I/3DuVQ9jEu4gg/IJ/BK9Xiu4In8XF7K16J3yFd5DeeZn82F6sFcxGnO16A/
nTMwRN7ot32E/fIpsqkYF30rXIAm+UW+hJi8n7ovRpvfTdYdA+QpnIyH9npy
KgbJG8x+iH3R+WUTkS+fzJPwTH6Wz2GWPEPdJ3oH5reXdUBfeQJ3RL29JO4S
/UbyB2bfx175KNlojJGP5Tw8lZ/iM5ghT1P3Qq75v7v61tBbHmf/n/U9e22t
2yFdftvsm6iVZ8tyMEo+nHPxRH48+j9CkTxVnYIc87+Y9w2p8p/8HbfttfAv
9Iq+C7Ovokb+13cT5D+s47kN6qzLzZqPYsxFEf4DanyTmg==
         "]]},
       "0"],
      Annotation[#, 0, "Tooltip"]& ], {}, {}}}],
  AspectRatio->1,
  Frame->True,
  PlotRange->{{0.01, 80}, {0.01, 80}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5493628536285276`*^9}]
}, Open  ]],

Cell["\<\
Let's solve for the optimal value of the two factor inputs.  Just as before, \
we take the derivatives with respect to each input, set them equal to zero, \
and then solve the resulting system of equations.  This time we'll give the \
solution a name so we can use it later\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution=Solve[{D[Profit[x1,x2,1,1,1],x1]==0,
D[Profit[x1,x2,1,1,1],x2]==0},{x1,x2}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x1", "\[Rule]", 
     FractionBox["1", "16"]}], ",", 
    RowBox[{"x2", "\[Rule]", 
     FractionBox["1", "16"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.549362853738529*^9}]
}, Open  ]],

Cell["\<\
Notice that we have two solutions; only the positive one makes economic \
sense.  We select it by using [[1]] to take the first element of the list.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["solution[[1]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x1", "\[Rule]", 
    FractionBox["1", "16"]}], ",", 
   RowBox[{"x2", "\[Rule]", 
    FractionBox["1", "16"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.549362853831031*^9}]
}, Open  ]],

Cell["\<\
We can do the same calculation for arbitrary values of p, w1 and w2.  Since \
we know that we'll get two answers, we'll select the first one right off the \
bat and call it solution\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution = Solve[{D[Profit[x1,x2,p,w1,w2],x1]==0, 
D[Profit[x1,x2,p,w1,w2],x2]==0},
{x1,x2}][[1]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x1", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["p", "2"], 
      RowBox[{"16", " ", 
       SuperscriptBox["w1", 
        RowBox[{"3", "/", "2"}]], " ", 
       SqrtBox["w2"]}]]}]}], ",", 
   RowBox[{"x2", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["p", "2"], 
      RowBox[{"16", " ", 
       SqrtBox["w1"], " ", 
       SuperscriptBox["w2", 
        RowBox[{"3", "/", "2"}]]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5493628539272823`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The profit function", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
To find the profit function, we just substitute this solution back into the \
definition of profit:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Profit[x1,x2,p,w1,w2]/.%", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", "p", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["p", "2"], 
       RowBox[{
        SqrtBox["w1"], " ", 
        SuperscriptBox["w2", 
         RowBox[{"3", "/", "2"}]]}]]}], ")"}], 
    RowBox[{"1", "/", "4"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["p", "2"], 
       RowBox[{
        SuperscriptBox["w1", 
         RowBox[{"3", "/", "2"}]], " ", 
        SqrtBox["w2"]}]]}], ")"}], 
    RowBox[{"1", "/", "4"}]]}], "+", 
  FractionBox[
   SuperscriptBox["p", "2"], 
   RowBox[{"8", " ", 
    SqrtBox["w1"], " ", 
    SqrtBox["w2"]}]]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.549362853993533*^9},
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparative statics", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Once we have solved for an optimal choice, we want to see how it \
responds to changes in the economic environment.   In the current context \
that means examining how the demand functions respond to changes in prices.\n\
\nIn ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" the easiest way to do is is by using total derivatives.  Consider \
a function ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["g[x,a]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  The first-order condition that a maximum value of x must \
satisfy is",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["D[g[x,a],x]==0", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["g", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "a"}], "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.549362854053534*^9}]
}, Open  ]],

Cell["Totally differentiating this gives us", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Dt[D[g[x,a],x]]==0", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Dt", "[", "a", "]"}], " ", 
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "a"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Dt", "[", "x", "]"}], " ", 
    RowBox[{
     SuperscriptBox["g", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "a"}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.549362854091035*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 StyleBox["Note the notation ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" uses.  ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Dt[a]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier"],
 StyleBox[" would be written ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["da",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" in standard notation. \n    ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["(1,1)",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier"],
 StyleBox["                                  2                         2\n",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["g     [x,a]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier"],
 StyleBox[" would be ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["d g(x,a)/dx",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[", the second derivative. \n\nSolving this for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["dx=Dt[x]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" gives us the answer we are after",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solve[Dt[D[g[x,a],x]]==0,Dt[x]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dt", "[", "x", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"Dt", "[", "a", "]"}], " ", 
       RowBox[{
        SuperscriptBox["g", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "a"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["g", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "a"}], "]"}]]}]}], "}"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.549362854127285*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 StyleBox["In classical notation, this simply says that\n                     \
             ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["                      g ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold"],
 StyleBox["12",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["\n                                   dx =    -da   ---\n           \
                                            g",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold"],
 StyleBox["11",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->"Subscript"}]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Since we know that the denominator of this expression is negative because of \
the second-order conditions, the sign of the entire expression is determined \
by the mixed partial derivative in the numerator.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Profit maximization with one input", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Let's apply this to a profit maximization problem.  We have", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Profit[x_,p_,w_] := p f[x] - w x", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Take the derivative of this expression and solve for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Dt[x]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solve[Dt[D[Profit[x,p,w],x]]==0,Dt[x]]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dt", "[", "x", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Dt", "[", "p", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["x"], " ", 
          RowBox[{"Dt", "[", "w", "]"}]}]}], ")"}]}], "p"]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5493628541872864`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["This expression shows us that ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["decrease when ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["w",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" increases and increases when ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" increases.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Maximization with several variables", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
The same logic applies if there are several variables.  The only tricky part \
is that the second order condition is messier.  Suppose that we have a \
function f[x1,x2,a] and we want to know how x1 and x2 respond to changes in \
a.  The FOCs are\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["FOC={D[f[x1,x2,a],x1]==0, D[f[x1,x2,a],x2]==0}", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5493628542235365`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Take the derivative of this list with respect to a and solve for ",
  
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Dt[x1]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Dt[x2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["]",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solve[Dt[FOC],{Dt[x1],Dt[x2]}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Dt", "[", "x1", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}]]}]}], ",", 
    RowBox[{
     RowBox[{"Dt", "[", "x2", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], "2"], "-", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}]]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.549362854274788*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["This expression is somewhat messy.  Luckily, the denominators in \
this expression are simply the determinant of the Hessian matrix of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["f.",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["  We will verify this by direct calculation:",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
hess={{D[f[x1,x2,a],x1,x1], D[f[x1,x2,a],x1,x2]},
      {D[f[x1,x2,a],x2,x1], D[f[x1,x2,a],x2,x2]}}\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.5493628543122883`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatrixForm[hess]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5493628543847895`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["detHess=-Det[hess]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], "2"], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.54936285443604*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Now substitute solve for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Dt[x1]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Dt[x2]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" again, substituting back into the total differential",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solve[Dt[FOC],{Dt[x1],Dt[x2]}]/.{detHess->HH} ", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Dt", "[", "x1", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}]]}]}], ",", 
    RowBox[{
     RowBox[{"Dt", "[", "x2", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Dt", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2", ",", "a"}], "]"}]}]}], "HH"]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.549362854476041*^9}]
}, Open  ]],

Cell["\<\
Just as before, the response of the choice variable to the parameter depends \
on the mixed partial derivatives, and the sign of the denominator is \
determined automatically by the second order conditions.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Profit maximization with two factors", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Now let h[x1,x2] be the production function and totally differentiate the FOCs\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution= Solve[{Dt[D[h[x1,x2]-w1 x1 - w2 x2,x1]]==0,
       Dt[D[h[x1,x2]-w1 x1 - w2 x2,x2]]==0},
       {Dt[x1],Dt[x2]}][[1]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Dt", "[", "x1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Dt", "[", "w1", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Dt", "[", "w2", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["h", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"Dt", "[", "x2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Dt", "[", "w1", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Dt", "[", "w2", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}], "2"], "-", 
       RowBox[{
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.549362854522291*^9}]
}, Open  ]],

Cell["\<\
The determinant of the Hessian is just as before; we'll compute it and \
substitute it in as before:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
detHess=-Det[{{D[h[x1,x2],x1,x1], D[h[x1,x2],x1,x2]},
      {D[h[x1,x2],x2,x1], D[h[x1,x2],x2,x2]}}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x1", ",", "x2"}], "]"}], "2"], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x1", ",", "x2"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["h", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.549362854566042*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution/.{detHess->HH}", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Dt", "[", "x1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Dt", "[", "w1", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Dt", "[", "w2", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["h", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"Dt", "[", "x2", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Dt", "[", "w1", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Dt", "[", "w2", "]"}], " ", 
        RowBox[{
         SuperscriptBox["h", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2"}], "]"}]}]}], "HH"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5493628546072927`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["This gives us a very simple expression for the comparative statics \
result: the change in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is the change in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["w1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" times the second derivative of the production function with \
respect to",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" x2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" plus the change in ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["w2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" times the  cross partial.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{763, 854},
WindowMargins->{{Automatic, 36}, {Automatic, 13}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001\n\
0000I00000400`<300000BL?00400@00000000000000060001T1T00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 82, 2, 83, "Title",
 Evaluatable->False],
Cell[664, 26, 104, 5, 47, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[793, 35, 82, 2, 71, "Section",
 Evaluatable->False],
Cell[878, 39, 432, 15, 48, "Text",
 Evaluatable->False],
Cell[1313, 56, 58, 1, 31, "Input"],
Cell[1374, 59, 338, 14, 30, "Text",
 Evaluatable->False],
Cell[1715, 75, 74, 1, 31, "Input"],
Cell[1792, 78, 334, 14, 30, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2151, 96, 72, 1, 31, "Input"],
Cell[2226, 99, 7244, 125, 241, "Output"]
}, Open  ]],
Cell[9485, 227, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[9708, 236, 72, 1, 31, "Input"],
Cell[9783, 239, 170, 5, 47, "Output"]
}, Open  ]],
Cell[9968, 247, 1054, 40, 49, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11047, 291, 72, 1, 31, "Input"],
Cell[11122, 294, 251, 8, 51, "Output"]
}, Open  ]],
Cell[11388, 305, 176, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11589, 314, 64, 1, 31, "Input"],
Cell[11656, 317, 186, 6, 46, "Output"]
}, Open  ]],
Cell[11857, 326, 363, 14, 30, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[12245, 344, 87, 2, 36, "Subsection",
 Evaluatable->False],
Cell[12335, 348, 812, 28, 48, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[13172, 380, 73, 1, 31, "Input"],
Cell[13248, 383, 307, 11, 66, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13616, 401, 97, 2, 71, "Section",
 Evaluatable->False],
Cell[13716, 405, 188, 5, 29, "Text",
 Evaluatable->False],
Cell[13907, 412, 73, 1, 31, "Input"],
Cell[13983, 415, 84, 2, 29, "Text",
 Evaluatable->False],
Cell[14070, 419, 98, 1, 31, "Input"],
Cell[14171, 422, 196, 5, 29, "Text",
 Evaluatable->False],
Cell[14370, 429, 535, 14, 52, "Input"],
Cell[14908, 445, 176858, 2902, 233, 118563, 1944, "CachedBoxData", "BoxData", \
"Output"],
Cell[CellGroupData[{
Cell[191791, 3351, 132, 4, 48, "Input"],
Cell[191926, 3357, 63819, 1073, 377, "Output"]
}, Open  ]],
Cell[255760, 4433, 343, 7, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[256128, 4444, 134, 4, 48, "Input"],
Cell[256265, 4450, 253, 8, 47, "Output"]
}, Open  ]],
Cell[256533, 4461, 218, 5, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[256776, 4470, 55, 1, 31, "Input"],
Cell[256834, 4473, 225, 7, 47, "Output"]
}, Open  ]],
Cell[257074, 4483, 251, 6, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[257350, 4493, 147, 5, 65, "Input"],
Cell[257500, 4500, 553, 19, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258090, 4524, 87, 2, 36, "Subsection",
 Evaluatable->False],
Cell[258180, 4528, 169, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[258374, 4537, 66, 1, 31, "Input"],
Cell[258443, 4540, 829, 31, 54, "Output",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[259333, 4578, 84, 2, 71, "Section",
 Evaluatable->False],
Cell[259420, 4582, 853, 26, 102, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[260298, 4612, 56, 1, 31, "Input"],
Cell[260357, 4615, 288, 10, 30, "Output"]
}, Open  ]],
Cell[260660, 4628, 99, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[260784, 4634, 60, 1, 31, "Input"],
Cell[260847, 4637, 688, 25, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[261550, 4665, 1580, 60, 104, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[263155, 4729, 73, 1, 31, "Input"],
Cell[263231, 4732, 777, 27, 52, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[264023, 4762, 807, 26, 99, "Text",
 Evaluatable->False],
Cell[264833, 4790, 277, 6, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[265135, 4800, 102, 2, 36, "Subsection",
 Evaluatable->False],
Cell[265240, 4804, 121, 2, 29, "Text",
 Evaluatable->False],
Cell[265364, 4808, 74, 1, 31, "Input"],
Cell[265441, 4811, 367, 14, 30, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[265833, 4829, 80, 1, 31, "Input"],
Cell[265916, 4832, 478, 16, 57, "Output"]
}, Open  ]],
Cell[266409, 4851, 743, 30, 30, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[267201, 4887, 100, 2, 71, "Section",
 Evaluatable->False],
Cell[267304, 4891, 316, 7, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[267645, 4902, 88, 1, 31, "Input"],
Cell[267736, 4905, 636, 22, 33, "Output"]
}, Open  ]],
Cell[268387, 4930, 566, 23, 30, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[268978, 4957, 72, 1, 31, "Input"],
Cell[269053, 4960, 4663, 142, 141, "Output"]
}, Open  ]],
Cell[273731, 5105, 489, 15, 48, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[274245, 5124, 149, 4, 48, "Input"],
Cell[274397, 5130, 1157, 40, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275591, 5175, 58, 1, 31, "Input"],
Cell[275652, 5178, 1601, 50, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277290, 5233, 60, 1, 31, "Input"],
Cell[277353, 5236, 795, 28, 30, "Output"]
}, Open  ]],
Cell[278163, 5267, 576, 22, 30, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[278764, 5293, 88, 1, 31, "Input"],
Cell[278855, 5296, 3776, 115, 138, "Output"]
}, Open  ]],
Cell[282646, 5414, 276, 6, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[282947, 5424, 104, 2, 36, "Subsection",
 Evaluatable->False],
Cell[283054, 5428, 148, 4, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[283227, 5436, 177, 5, 65, "Input"],
Cell[283407, 5443, 3277, 110, 95, "Output"]
}, Open  ]],
Cell[286699, 5556, 170, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[286894, 5565, 150, 4, 48, "Input"],
Cell[287047, 5571, 736, 28, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287820, 5604, 65, 1, 31, "Input"],
Cell[287888, 5607, 2479, 83, 93, "Output"]
}, Open  ]],
Cell[290382, 5693, 1064, 40, 49, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

