(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5606,        180]*)
(*NotebookOutlinePosition[      6682,        217]*)
(*  CellTagsIndexPosition[      6638,        213]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Profit Function"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hal R. Varian\nJune, 1992"], "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Profit function"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Recall the profit function for the Cobb-Douglas technology that we derived \
in the last chapter.   We will repeat the derivation here without comment, \
since we already saw it done in the previous chapter.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"f[x1_,x2_] := (x1^(1/4))*(x2^(1/4))\nProfit[x1_,x2_,p_,w1_,w2_] := \
p*f[x1,x2] - w1*x1 - w2*x2\nsolution=Solve[{D[Profit[x1,x2,p,w1,w2],x1]==0, \n\
                D[Profit[x1,x2,p,w1,w2],x2]==0},\n                \
{x1,x2}][[1]]\npi[p_,w1_,w2_] := Evaluate[Profit[x1,x2,p,w1,w2]/.solution]\n\
pi[p,w1,w2]"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Convexity of the profit function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Let's graph this function to make sure that it is really convex.  First \
we'll fix ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and look at how the function behaves with respect to",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" p",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Plot[pi[p,1,1],{p,1,4}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now let's look at a 3D-plot and a contour plot, fixing ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["p",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" at 1.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Plot3D[pi[1,w1,w2],{w1,1,50},{w2,1,50}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"ContourPlot[pi[1,w1,w2],{w1,1,50},{w2,1,50},ContourShading->False]"], "Input",\

  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["Hotelling's identity"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Finally, we want to verify that we satisfy Hotelling's identity, so we'll \
compute the derivatives of the profit function with respect to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  and compare it to the factor demand functions.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"deriv[p_,w1_,w2_]:=-Evaluate[Simplify[D[pi[p,w1,w2],w1]]]\nderiv[p,w1,w2]\n\
factorDemand1[p_,w1_,w2_] := Evaluate[Simplify[x1/.solution]]\n\
factorDemand1[p,w1,w2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"It is not obvious that these expressions are equal to each other.  But if we \
apply the right simplification, we see that Hotelling's identity works. "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["PowerExpand[deriv[p,w1,w2]]"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 365},
WindowMargins->{{52, Automatic}, {Automatic, 16}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
MacintoshSystemPageSetup->"\<\
AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 90, 2, 70, "Title",
  Evaluatable->False],
Cell[1824, 55, 106, 2, 70, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1953, 59, 92, 2, 70, "Section",
  Evaluatable->False],
Cell[2048, 63, 284, 5, 70, "Text",
  Evaluatable->False],
Cell[2335, 70, 360, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[2718, 78, 112, 2, 70, "Subsection",
  Evaluatable->False],
Cell[2833, 82, 856, 32, 70, "Text",
  Evaluatable->False],
Cell[3692, 116, 76, 1, 70, "Input"],
Cell[3771, 119, 391, 14, 70, "Text",
  Evaluatable->False],
Cell[4165, 135, 92, 1, 70, "Input"],
Cell[4260, 138, 122, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4414, 143, 100, 2, 70, "Subsection",
  Evaluatable->False],
Cell[4517, 147, 523, 16, 70, "Text",
  Evaluatable->False],
Cell[5043, 165, 218, 4, 70, "Input"],
Cell[5264, 171, 229, 5, 70, "Text",
  Evaluatable->False],
Cell[5496, 178, 80, 1, 70, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
