(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7164,        238]*)
(*NotebookOutlinePosition[      8238,        275]*)
(*  CellTagsIndexPosition[      8194,        271]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Cost Minimization"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hal R. Varian\nJanuary, 1992"], "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Minimizing costs"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Let's solve a cost minimization problem for a Cobb-Douglas function.  First \
we set up the Lagrangian,"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"L= w1 x1 + w2 x2 - \n   lambda*((x1^(1/4))*(x2^(3/4))-y)"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now differentiate the Lagrangian with respect to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["lambda, set the derivatives equal to zero, and solve f",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["or each of these variables.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"solution=Solve[{D[L,x1]==0, D[L,x2]==0, D[L,lambda]==0},\n\
{x1,x2,lambda}][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now substitute into the expression for costs to derive the cost function"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["c[w1_,w2_,y_] := w1*x1 + w2*x2 /.solution"], "Input",
  AspectRatioFixed->True],

Cell[TextData["c[w1,w2,y]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Let's check Shephard's lemma to make sure it works"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Simplify[{D[c[w1,w2,y],w2],D[c[w1,w2,y],w1]}]"], "Input",
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["The CES cost function"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here's a CES cost function with rho=1"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["L=w1 x1 + w2 x2 - lambda*(y - x1^(-1) - x2^(-1))"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"solution=Simplify[Solve[{D[L,x1]==0, D[L,x2]==0, D[L,lambda]==0},\n\
{x1,x2,lambda}]][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Again, we substitute into the cost function and verify Shephard's lemma:"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["c[w1_,w2_,y_] := w1 x1 + w2 x2 /. solution"], "Input",
  AspectRatioFixed->True],

Cell[TextData["c[w1,w2,y]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["{D[c[w1,w2,y],w1],D[c[w1,w2,y],w2]}"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["CES with rho=2"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here's the Lagrangian for a  CES cost function with rho=2"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["L=w1 x1 + w2 x2 - lambda*(y - 1/(x1*x1) - 1/(x2*x2))"], "Input",
  AspectRatioFixed->True],

Cell[TextData["FOC={D[L,x1]==0,D[L,x2]==0,D[L,lambda]==0}"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Unfortunately, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " finds this system of equations difficult to solve, so we'll have to \
resort to some tricks.  In general, if ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " finds a system of equations difficult to solve, try some transformations \
to make the system look like a system of polynomials---or, even better, a \
system of linear equations.  In this case, we'll introduce auxiliary \
variables",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" z1=1/x1 ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["z2=1/x2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".  With these additions, the system we want to solve is ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"transFOC=FOC/.{x1->1/z1,x2->1/z2}\n\
solution=Solve[Evaluate[transFOC],{z1,z2,lambda}][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["The demand functions and the cost function are"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["{x1,x2} = Simplify[{1/z1,1/z2}/.solution]\n"], "Input",
  AspectRatioFixed->True],

Cell[TextData["c[w1_,w2_,y_] := (w1 /z1 + w2 /z2)/.solution"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Simplify[c[w1,w2,y]]"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 365},
WindowMargins->{{4, Automatic}, {Automatic, 31}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
MacintoshSystemPageSetup->"\<\
AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 92, 2, 70, "Title",
  Evaluatable->False],
Cell[1826, 55, 109, 2, 70, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1958, 59, 93, 2, 70, "Section",
  Evaluatable->False],
Cell[2054, 63, 178, 4, 70, "Text",
  Evaluatable->False],
Cell[2235, 69, 110, 2, 70, "Input"],
Cell[2348, 73, 896, 32, 70, "Text",
  Evaluatable->False],
Cell[3247, 107, 134, 3, 70, "Input"],
Cell[3384, 112, 150, 4, 70, "Text",
  Evaluatable->False],
Cell[3537, 118, 94, 1, 70, "Input"],
Cell[3634, 121, 63, 1, 70, "Input"],
Cell[3700, 124, 124, 2, 70, "Text",
  Evaluatable->False],
Cell[3827, 128, 98, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3957, 131, 98, 2, 70, "Section",
  Evaluatable->False],
Cell[4058, 135, 111, 2, 70, "Text",
  Evaluatable->False],
Cell[4172, 139, 101, 1, 70, "Input"],
Cell[4276, 142, 144, 3, 70, "Input"],
Cell[4423, 147, 150, 4, 70, "Text",
  Evaluatable->False],
Cell[4576, 153, 95, 1, 70, "Input"],
Cell[4674, 156, 63, 1, 70, "Input"],
Cell[4740, 159, 88, 1, 70, "Input"],

Cell[CellGroupData[{
Cell[4851, 162, 94, 2, 70, "Subsection",
  Evaluatable->False],
Cell[4948, 166, 132, 3, 70, "Text",
  Evaluatable->False],
Cell[5083, 171, 105, 1, 70, "Input"],
Cell[5191, 174, 95, 1, 70, "Input"],
Cell[5289, 177, 1299, 42, 70, "Text",
  Evaluatable->False],
Cell[6591, 221, 145, 3, 70, "Input"],
Cell[6739, 226, 120, 2, 70, "Text",
  Evaluatable->False],
Cell[6862, 230, 96, 1, 70, "Input"],
Cell[6961, 233, 97, 1, 70, "Input"],
Cell[7061, 236, 73, 1, 70, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
