(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6450,        190]*)
(*NotebookOutlinePosition[      7525,        227]*)
(*  CellTagsIndexPosition[      7481,        223]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Cost Function"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hal R. Varian\nJanuary, 1992"], "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["U-shaped average costs"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Undergraduate texts are full of U-shaped average cost curves,  but it is \
rare to see an accurate plot of one.  Let's try to do this for the cost \
function ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c[y]=y^a+F.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  "First we'll set values for the two parameters, a and F, and then calculate \
the various curves.  Finally, we'll plot them.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"a=2\nF=1\nc[y_] := y^a + F\nAC[y_] := c[y]/y\nAVC[y_] := y^a/y\nMC[y_] := \
Evaluate[D[c[y],y]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Plot[{AC[y],AVC[y],MC[y]},{y,.001,5}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Let's do the same graph with a=4"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"a=4\nc[y_] := y^a + F\nAC[y_] := c[y]/y\nAVC[y_] := y^a/y\nMC[y_] := \
Evaluate[D[c[y],y]]\nPlot[{AC[y],AVC[y],MC[y]},{y,.001,3}]"], "Input",
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["Long-run and short-run costs"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Let's try to get Mathematica to draw the long-run average cost curve as the \
envelope of short-run average cost curves.   First we have to compute a \
short-run average cost function.   Since there is only one variable factor, \
we don't have to do any minimization---we simply solve for the variable input \
as a function of the output and the fixed factor."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"f[x1_,x2_] := x1^(1/2) x2^(1/2)\nsolution1=Solve[y==f[x1,x2],x1][[1]]\n\
cs[w1_,w2_,y_,x2_]:= Evaluate[(w1 x1 + w2 x2)/.solution1]\n\
acs[w1_,w2_,y_,x2_] := Evaluate[cs[w1,w2,y,x2]/y]\nacs[w1,w2,y,x2]"], "Input",\

  AspectRatioFixed->True],

Cell[TextData[
"Now that we have the short run average cost function, we have to solve for \
the long-run cost function.  To do this we differentiate long-run costs with \
respect to the long-run factor, and set this derivative equal to zero.  Then \
we substitute this result into the short-run cost function and divide by \
output to get the short-run average cost function."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"solution2=Solve[D[cs[w1,w2,y,x2],x2]==0,x2][[1]]\ncl[w1_,w2_,y_] := \
Evaluate[cs[w1,w2,y,x2]/.solution2]\nacl[w1_,w2_,y_]:= \
Evaluate[cl[w1,w2,y]/y]\nacl[w1,w2,y]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Plot[{acl[1,1,y],acs[1,1,y,5],acs[1,1,y,10],acs[1,1,y,15],\n\
acs[1,1,y,20]},{y,1,30},AxesOrigin->{0,0},PlotStyle->\n\
{Thickness[1/100],Thickness[1/300],\n\
Thickness[1/300],Thickness[1/300],Thickness[1/300]}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Note how the long-run average cost curve is the envelope of the short-run \
curves.  [The options in the graph just make things look a little clearer.]"],
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["Shephard's Lemma"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Take the production function"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"f[x1_,x2_] := x1 x2\nL=w1 x1 + w2 x2 - lambda*(f[x1,x2]-y)\n\
solution=Solve[{D[L,x1]==0,D[L,x2]==0,D[L,lambda]==0},{x1,x2,lambda}][[1]]\n\
c[w1_,w2_,y_] = w1 x1 + w2 x2 /.solution"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now check the derivatives of the cost function with respect to each of the \
variables:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["{D[c[w1,w2,y],y],D[c[w1,w2,y],w2],D[c[w1,w2,y],w1]}"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["lambda",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " equals marginal cost, and that the derivatives with respect to the price \
variables gives the conditional factor demands.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 365},
WindowMargins->{{12, Automatic}, {30, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
MacintoshSystemPageSetup->"\<\
AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 88, 2, 70, "Title",
  Evaluatable->False],
Cell[1822, 55, 109, 2, 70, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1954, 59, 99, 2, 70, "Section",
  Evaluatable->False],
Cell[2056, 63, 629, 19, 70, "Text",
  Evaluatable->False],
Cell[2688, 84, 149, 3, 70, "Input"],
Cell[2840, 89, 90, 1, 70, "Input"],
Cell[2933, 92, 106, 2, 70, "Text",
  Evaluatable->False],
Cell[3042, 96, 183, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3257, 101, 105, 2, 70, "Section",
  Evaluatable->False],
Cell[3365, 105, 434, 7, 70, "Text",
  Evaluatable->False],
Cell[3802, 114, 256, 5, 70, "Input"],
Cell[4061, 121, 435, 7, 70, "Text",
  Evaluatable->False],
Cell[4499, 130, 218, 4, 70, "Input"],
Cell[4720, 136, 264, 5, 70, "Input"],
Cell[4987, 143, 229, 5, 70, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[5248, 150, 93, 2, 70, "Section",
  Evaluatable->False],
Cell[5344, 154, 102, 2, 70, "Text",
  Evaluatable->False],
Cell[5449, 158, 234, 4, 70, "Input"],
Cell[5686, 164, 162, 4, 70, "Text",
  Evaluatable->False],
Cell[5851, 170, 104, 1, 70, "Input"],
Cell[5958, 173, 471, 16, 70, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
