(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9975,        329]*)
(*NotebookOutlinePosition[     11050,        366]*)
(*  CellTagsIndexPosition[     11006,        362]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Duality"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hal R. Varian\nJanuary, 1992"], "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Graphical duality"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Duality says that we can recover the input requirement set if we know the \
cost function or the conditional factor demand functions.  Here is a \
graphical demonstration of this fact.\n\nWe know that the TRS of the \
Cobb-Douglas production function is given by ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["-(x2/x1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".    Let's draw lines with this slope that pass through each point on the \
curve  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1*x2=10",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\n\nThe formula for a straight line  with coordinates ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(y1,y2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" that passes through a point ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(x1,x2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is \n                ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y2 = x2 + m (x1 - y1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".\nAt a given point on the isoquant, (x1,x2), the  slope of the tangent \
line is x2/x1.\nMaking this substitution gives us\n                 ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y2 = x2 - (x2/x1)(x1 - y1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".\nFinally, since the points (x1,x2) are all on the isoquant, x2=10/x1.  \
Making this substitution gives us\n                ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" y2 = 10/x1 - (10/x1^2)(x1 - y1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".\nWe want to plot this family of lines for a number of values of  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".  In order to do this we will use the Mathematica function Table .  We  \
can construct a list of  10 of these straight lines as follows",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Table[10/x1 - (10/x1^2)(x1 - y1),{x1,1,10}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now we just feed this list of functions into the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["command.  However, before we do that we need to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Evaluate",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" the table, to convert it to a form that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" can understand.\nWe also set the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["AspectRatio",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotRange",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" so the graph will look nice.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Plot[Evaluate[Table[10/x1 - (10/x1^2)(y1-x1),{x1,1,20}]],\n\
{y1,0,10},AspectRatio->1,PlotRange->{{0,10},{0,10}}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Notice how the set of tangent lines \"reconstruct\" the isoquant ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x1*x2=10.  ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["Recovering the technology algebraically"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Suppose that we are given a cost function and want to calculate the \
production function that generated it.  We simply calculate the factor \
demands and eliminate ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" from this system of equations.  Here's an example:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["c[w1_,w2_,y] = (w1^(1/2) * w2^(1/2))y"], "Input",
  AspectRatioFixed->True],

Cell[TextData["factorDemands={D[c[w1,w2,y],w1],D[c[w1,w2,y],w2]}"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Eliminate[{x1==y/(2*ww),x2==y*ww/2},ww]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The third solution is the one we want; this is a standard Cobb-Douglas \
production function."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["Recovering the technology numerically"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"There are not all that many technologies that have simple closed form \
solutions for both the production function and the cost function.  However, \
it is still possible to recover an isoquant numerically or graphically.  For \
example, here is the \"Generalized Leontieff\" cost function:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["c[w1_,w2_,y_] := w1 + w2+ Sqrt[w1*w2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["The factor demands are"], "Input",
  AspectRatioFixed->True],

Cell[TextData["factorDemands={D[c[w1,w2,y],w1],D[c[w1,w2,y],w2]}"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Let's fix ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" at ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["10",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", set ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w2=1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", and plot these equations as ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["w1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" varies.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"factorDemands=Evaluate[factorDemands/.{w2->1,y->10}]\n\
ParametricPlot[factorDemands,{w1,1,20},AxesOrigin->{0,0}]"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 365},
WindowMargins->{{20, Automatic}, {15, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
MacintoshSystemPageSetup->"\<\
AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 82, 2, 70, "Title",
  Evaluatable->False],
Cell[1816, 55, 109, 2, 70, "Subsubtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1948, 59, 94, 2, 70, "Section",
  Evaluatable->False],
Cell[2045, 63, 2691, 83, 70, "Text",
  Evaluatable->False],
Cell[4739, 148, 96, 1, 70, "Input"],
Cell[4838, 151, 1324, 46, 70, "Text",
  Evaluatable->False],
Cell[6165, 199, 167, 3, 70, "Input"],
Cell[6335, 204, 340, 12, 70, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[6707, 218, 116, 2, 70, "Section",
  Evaluatable->False],
Cell[6826, 222, 744, 25, 70, "Text",
  Evaluatable->False],
Cell[7573, 249, 90, 1, 70, "Input"],
Cell[7666, 252, 102, 1, 70, "Input"],
Cell[7771, 255, 92, 1, 70, "Input"],
Cell[7866, 258, 168, 4, 70, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[8066, 264, 114, 2, 70, "Section",
  Evaluatable->False],
Cell[8183, 268, 365, 6, 70, "Text",
  Evaluatable->False],
Cell[8551, 276, 90, 1, 70, "Input"],
Cell[8644, 279, 75, 1, 70, "Input"],
Cell[8722, 282, 102, 1, 70, "Input"],
Cell[8827, 285, 957, 38, 70, "Text",
  Evaluatable->False],
Cell[9787, 325, 167, 3, 70, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
