(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4782,        162]*)
(*NotebookOutlinePosition[      5856,        199]*)
(*  CellTagsIndexPosition[      5812,        195]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Utility Maximization"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Cobb-Douglas system"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Let's calculate the factor demands  for the Cobb-Douglas utility function.  \
"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"u[x1_,x2_] := x1*x2\nL= u[x1,x2]- lambda*(p1 x1 + p2 x2 - m)\n\
firstOrder={D[L,x1]==0,D[L,x2]==0,D[L,lambda]==0}\n\
solution=Solve[{D[L,x1]==0,D[L,x2]==0,D[L,lambda]==0},\n   \
{x1,x2,lambda}][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Here's the indirect utility function:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"v[p1_,p2_,m_] := Evaluate[u[x1,x2]/.solution]\nv[p1,p2,m]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Now check Roy's identity:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"{-D[v[p1,p2,m],p2]/D[v[p1,p2,m],m],-D[v[p1,p2,m],p1]/D[v[p1,p2,m],m]}"], 
  "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Here are plots of the indirect utility function with respect to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["(p1,p2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Plot[v[1,1,m],{m,1,50}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["ContourPlot[v[p1,p2,10],{p1,1,10},{p2,1,10}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "To find the expenditure function, we solve the indirect utility function \
for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["m",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["solution=Solve[v[p1,p2,m]==u,m][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["e[p1_,p2_,u_] = Evaluate[m/.solution]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"To find the money metric utility functions, just substitute:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"m[p1_,p2_,x1_,x2_] := e[p1,p2,u]/.{u->u[x1,x2]}\nm[p1,p2,x1,x2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Here's the indirect money metric utility function:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["mu[p1_,p2_,q1_,q2_,m] := e[p1,p2,u]/.{u->v[q1,q2,m]}"], "Input",
  AspectRatioFixed->True],

Cell[TextData["mu[p1,p2,q1,q2,m]"], "Input",
  AspectRatioFixed->True]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 365},
WindowMargins->{{28, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
MacintoshSystemPageSetup->"\<\
AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 95, 2, 70, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1849, 55, 96, 2, 70, "Section",
  Evaluatable->False],
Cell[1948, 59, 153, 4, 70, "Text",
  Evaluatable->False],
Cell[2104, 65, 252, 5, 70, "Input"],
Cell[2359, 72, 111, 2, 70, "Text",
  Evaluatable->False],
Cell[2473, 76, 111, 2, 70, "Input"],
Cell[2587, 80, 99, 2, 70, "Text",
  Evaluatable->False],
Cell[2689, 84, 126, 3, 70, "Input"],
Cell[2818, 89, 597, 23, 70, "Text",
  Evaluatable->False],
Cell[3418, 114, 76, 1, 70, "Input"],
Cell[3497, 117, 97, 1, 70, "Input"],
Cell[3597, 120, 413, 16, 70, "Text",
  Evaluatable->False],
Cell[4013, 138, 89, 1, 70, "Input"],
Cell[4105, 141, 90, 1, 70, "Input"],
Cell[4198, 144, 135, 3, 70, "Text",
  Evaluatable->False],
Cell[4336, 149, 117, 2, 70, "Input"],
Cell[4456, 153, 124, 2, 70, "Text",
  Evaluatable->False],
Cell[4583, 157, 105, 1, 70, "Input"],
Cell[4691, 160, 70, 1, 70, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
