(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     35837,       1261]
NotebookOptionsPosition[     30803,       1083]
NotebookOutlinePosition[     31582,       1110]
CellTagsIndexPosition[     31539,       1107]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Choice", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Slutsky equation", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Let's check the Slutsky equation for the CES demand functions when \
",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["rho=-1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold"],
 StyleBox[".  First we'll calculate the CES demands, etc.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["u[x1_,x2_] := 1/x1 + 1/x2", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["L= u[x1,x2] - lambda*(p1 x1 + p2 x2 - m)", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "x1"], "+", 
  FractionBox["1", "x2"], "-", 
  RowBox[{"lambda", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "m"}], "+", 
     RowBox[{"p1", " ", "x1"}], "+", 
     RowBox[{"p2", " ", "x2"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.548757836733308*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["firstOrder=Evaluate[{D[L,x1]==0,D[L,x2]==0,D[L,lambda]==0}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "lambda"}], " ", "p1"}], "-", 
     FractionBox["1", 
      SuperscriptBox["x1", "2"]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "lambda"}], " ", "p2"}], "-", 
     FractionBox["1", 
      SuperscriptBox["x2", "2"]]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"m", "-", 
     RowBox[{"p1", " ", "x1"}], "-", 
     RowBox[{"p2", " ", "x2"}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.54875783677831*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Alas, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" cannot solve this system directly.  However, we can use the same \
trick that we used before.  We define two auxiliary variables, ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["y1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["y2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and then solve the entire system of equations.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
firstOrder=Union[firstOrder/.{x1^(-2)->y1^2,x2^(-2)->y2^2},
{y1==1/x1,y2==1/x2}]
solution=Solve[firstOrder,{lambda,x1,x2,y1,y2}][[1]]
x1[p1_,p2_,m_]:=Simplify[x1/.solution]
x1[p1,p2,m]
x2[p1_,p2_,m_] := Simplify[x2/.solution]
x2[p1,p2,m]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"m", "-", 
     RowBox[{"p1", " ", "x1"}], "-", 
     RowBox[{"p2", " ", "x2"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{"y1", "\[Equal]", 
    FractionBox["1", "x1"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "lambda"}], " ", "p1"}], "-", 
     SuperscriptBox["y1", "2"]}], "\[Equal]", "0"}], ",", 
   RowBox[{"y2", "\[Equal]", 
    FractionBox["1", "x2"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "lambda"}], " ", "p2"}], "-", 
     SuperscriptBox["y2", "2"]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.548757836822313*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"lambda", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "p1"}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["p1"], " ", 
       SqrtBox["p2"]}], "-", "p2"}], 
     SuperscriptBox["m", "2"]]}], ",", 
   RowBox[{"x1", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"m", " ", "p1"}], "+", 
      RowBox[{"m", " ", 
       SqrtBox["p1"], " ", 
       SqrtBox["p2"]}]}], 
     RowBox[{
      SuperscriptBox["p1", "2"], "-", 
      RowBox[{"p1", " ", "p2"}]}]]}], ",", 
   RowBox[{"x2", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "m"}], " ", 
       SqrtBox["p1"], " ", 
       SqrtBox["p2"]}], "-", 
      RowBox[{"m", " ", "p2"}]}], 
     RowBox[{
      RowBox[{"p1", " ", "p2"}], "-", 
      SuperscriptBox["p2", "2"]}]]}], ",", 
   RowBox[{"y1", "\[Rule]", 
    FractionBox[
     RowBox[{"p1", "-", 
      RowBox[{
       SqrtBox["p1"], " ", 
       SqrtBox["p2"]}]}], "m"]}], ",", 
   RowBox[{"y2", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox["p1"]}], " ", 
       SqrtBox["p2"]}], "+", "p2"}], "m"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5487578370853276`*^9}],

Cell[BoxData[
 FractionBox["m", 
  RowBox[{"p1", "-", 
   RowBox[{
    SqrtBox["p1"], " ", 
    SqrtBox["p2"]}]}]]], "Output",
 CellChangeTimes->{3.548757837110329*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["m", 
   RowBox[{
    RowBox[{
     SqrtBox["p1"], " ", 
     SqrtBox["p2"]}], "-", "p2"}]]}]], "Output",
 CellChangeTimes->{3.548757837113329*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Indirect utility and expenditure", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Here's the indirect utility function:", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
v[p1_,p2_,m] := Simplify[u[x1,x2]/.solution]
v[p1,p2,m]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox[
  RowBox[{"p1", "-", 
   RowBox[{"2", " ", 
    SqrtBox["p1"], " ", 
    SqrtBox["p2"]}], "+", "p2"}], "m"]], "Output",
 CellChangeTimes->{3.548757837156332*^9}]
}, Open  ]],

Cell["\<\
To solve for the expenditure function, solve for income as a function of \
utility:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution2=Solve[v[p1,p2,m]==u,m][[1]]
e[p1_,p2_,m_] := m/.solution2
e[p1,p2,m]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"m", "\[Rule]", 
   FractionBox[
    RowBox[{"p1", "-", 
     RowBox[{"2", " ", 
      SqrtBox["p1"], " ", 
      SqrtBox["p2"]}], "+", "p2"}], "u"]}], "}"}]], "Output",
 CellChangeTimes->{3.5487578371973343`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"p1", "-", 
   RowBox[{"2", " ", 
    SqrtBox["p1"], " ", 
    SqrtBox["p2"]}], "+", "p2"}], "u"]], "Output",
 CellChangeTimes->{3.548757837199334*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hicksian demands and Slutsky equation", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
The Hicksian demand function  for good 1will be the derivative of this \
expenditure function with respect to p1.  We'll evaluate it at u=v[p1,p2,m]:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["h[p1_,p2_,u_] := D[e[p1,p2,m],p1]", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
slopeOfHicksianDemand=
  Simplify[D[h[p1,p2,u],p1]/.{u->v[p1,p2,m]}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox[
  RowBox[{"m", " ", 
   SqrtBox["p2"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["p1", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SqrtBox["p1"], "-", 
      SqrtBox["p2"]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{3.5487578372553377`*^9}]
}, Open  ]],

Cell["We want to compare this to the Slutsky equation:", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
slutskyTerm=Simplify[D[x1[p1,p2,m],p1] + 
               D[x1[p1,p2,m],m]*x1[p1,p2,m]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 FractionBox[
  RowBox[{"m", " ", 
   SqrtBox["p2"]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["p1", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SqrtBox["p1"], "-", 
      SqrtBox["p2"]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{3.54875783729734*^9}]
}, Open  ]],

Cell["Slutsky wins again...", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrability", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Here we'll solve the integrability equations for the linear demand function:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Linear demand", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["x[p_,m_] := a p + b m + c", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" wants the integrability equation and the boundary condition in \
order to solve for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["mu",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution=DSolve[{mu'[p]==a p + b mu[p] + c,mu[q]==m},
         mu[p],p][[1]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"mu", "[", "p", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "b"}], " ", "q"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "p"}]]}], "-", 
        RowBox[{"b", " ", "c", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "p"}]]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "q"}]]}], "+", 
        RowBox[{"b", " ", "c", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "q"}]]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "p"}]], " ", "m"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "q"}]], " ", "p"}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"b", " ", "p"}]], " ", "q"}]}], ")"}]}], 
     SuperscriptBox["b", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5487578377483654`*^9}]
}, Open  ]],

Cell["\<\
Here's the standard form for the money metric utility function\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
mm[p_,q_,m_] := mu[p]/.solution
mm[p,q,m]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "b"}], " ", "q"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]]}], "-", 
      RowBox[{"b", " ", "c", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "q"}]]}], "+", 
      RowBox[{"b", " ", "c", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "q"}]]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]], " ", "m"}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "q"}]], " ", "p"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]], " ", "q"}]}], ")"}]}], 
   SuperscriptBox["b", "2"]]}]], "Output",
 CellChangeTimes->{3.548757837837371*^9}]
}, Open  ]],

Cell["\<\
Let's see if we can figure out what the indifference curves for this indirect \
utility function looks like.  There are several ways to do this; one way is \
to solve for the Hicksian demands.  We'll put the parameters into the utility \
function since we want to see how the indifference curve changes as these \
parameters change.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
h1[p_,q_,m_,a_,b_,c_] := 
      Evaluate[x[p,income]/.{income->mm[p,q,m]}]
h1[p,q,m,a,b,c]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"c", "+", 
  RowBox[{"a", " ", "p"}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "b"}], " ", "q"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]]}], "-", 
      RowBox[{"b", " ", "c", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "q"}]]}], "+", 
      RowBox[{"b", " ", "c", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "q"}]]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]], " ", "m"}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "q"}]], " ", "p"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"b", " ", "p"}]], " ", "q"}]}], ")"}]}], "b"]}]], "Output",
 CellChangeTimes->{3.548757837878373*^9}]
}, Open  ]],

Cell["\<\
This is one Hicksian demand; the other one comes from the budget constraint:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
h2[p_,q_,m_,a_,b_,c_] := Evaluate[(income - 
                         p x[p,income])/.{income->mm[p,q,m]}]
h2[p,q,m,a,b,c]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "b"}], " ", "q"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "p"}]]}], "-", 
       RowBox[{"b", " ", "c", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "p"}]]}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "q"}]]}], "+", 
       RowBox[{"b", " ", "c", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "q"}]]}], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "p"}]], " ", "m"}], "+", 
       RowBox[{"a", " ", "b", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "q"}]], " ", "p"}], "-", 
       RowBox[{"a", " ", "b", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"b", " ", "p"}]], " ", "q"}]}], ")"}]}], 
    SuperscriptBox["b", "2"]]}], "-", 
  RowBox[{"p", " ", 
   RowBox[{"(", 
    RowBox[{"c", "+", 
     RowBox[{"a", " ", "p"}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "b"}], " ", "q"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "a"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "p"}]]}], "-", 
         RowBox[{"b", " ", "c", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "p"}]]}], "+", 
         RowBox[{"a", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "q"}]]}], "+", 
         RowBox[{"b", " ", "c", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "q"}]]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "p"}]], " ", "m"}], "+", 
         RowBox[{"a", " ", "b", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "q"}]], " ", "p"}], "-", 
         RowBox[{"a", " ", "b", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"b", " ", "p"}]], " ", "q"}]}], ")"}]}], "b"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.5487578379223757`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Now we'll fix ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["q",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["m",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", so that utility is held fixed,  pick some values for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["(a,b,c)",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and then plot these functions as ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" varies.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
hh1[p_] := Simplify[Evaluate[h1[p,1,10,-10,1,1]]]
hh2[p_] := Simplify[Evaluate[h2[p,1,10,-10,1,1]]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Simplify[{hh1[p],hh2[p]}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"10", "-", 
    RowBox[{"9", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "p"}]]}]}], ",", 
   FractionBox[
    RowBox[{"9", " ", 
     RowBox[{"(", 
      RowBox[{"\[ExponentialE]", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "p"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "p"}], ")"}]}]}], ")"}]}], 
    "\[ExponentialE]"]}], "}"}]], "Output",
 CellChangeTimes->{3.548757837981379*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot[{hh1[p],hh2[p]},{p,0,1.5},AxesOrigin->{0,0},
  PlotRange->{0,12},AspectRatio->1]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Hs01OkbAHBEJNcZ+535vgmDxvXHN5uVWPN0sRQrpdxJuigVwxZdplxK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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 12}, {0, 12}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5487578383594007`*^9}]
}, Open  ]],

Cell["\<\
Note that the indifference curve crosses the vertical axis.  This makes no  \
economic sense; it is a good warning to be careful in calculating welfare \
conclusions using this linear demand function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Log-Linear demand", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Suppose that demand takes the form", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["x[p_,m_] := p^a m^b E^c", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We estimate the demand function and find that ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["a=-0.2, b=1.2, and c=0.0.",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["   Initially, the consumer faces prices ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p=2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and has income of 1.  If the price rises to ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p=3",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", how much income would the consumer need to make her as well off \
as she was before the price increase?\n\nWe'll answer this question using \
integrability.  Before the price change,",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" e[2,u]=1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  We want to know what ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["e[3,u]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" equals.  First we find a numerical solution to the integrability \
equation.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
a=-0.2
b=1.2
c=0.0
dsolution=
  NDSolve[{e'[p]==(p^a)* (e[p]^b), e[2]==1},e,{p,1,4}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"-", "0.2`"}]], "Output",
 CellChangeTimes->{3.548757838416404*^9}],

Cell[BoxData["1.2`"], "Output",
 CellChangeTimes->{3.548757838417404*^9}],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{3.548757838419404*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"1.`", ",", "4.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.548757838560412*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["We can plot the function e[p] that ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" found for us as follows.  Note that ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["e[2]=1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", as required by the boundary condition.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Plot[Evaluate[e[p]/.dsolution],{p,1,4}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkH080wkcgPeCrQ2/0ji3n0SxSt1HV+niqu+XSiGnV4adTpb1zq6ka6m8
5bzdiaQXl5wkoauWl0rdyGl8OCqnvER5u4wyNmOJnfvj+Tz/PH891rtDtu2h
USgUz2n+929bQmZSKEoI/pCnyfFvg0G93pYquhJof1I3cQLbYPUDv5x4hhKk
Oa9zYoPboNXadeVsQgmZnfonD4jbwExlIeBZKuHGvYzidXFtkJJem7d5tRIW
fLcnjidtg6hWW7h0XAnfZBkeLWW3Q7Cw/dCyYSX01RX1cGTtEGgVnnJbMwwe
ZkRwlHcHKOwL7zQrRkDct+LVRG8nrPqj8NGKVhUknvuX85fsLZQ1tya2v1HD
6X2NF5sL3kH11hzfpY2j8CWd7sxO6wKDsEuD9c0aiM1r0ve+0g1spv/+7Ndj
ULJBileKeiDrY0mvVc04JHUQfbGPekEYgTxFvRaSOrX5qco+KNslFO6q+ARb
+1nPxNbv4fnd7cmsOxNQeVJadV3QD2RhqER37zPM25AQRVYrQK1dILp2fRIG
XF4Wt9gNgm7I0Dzx1hSEzn1atLLqAzTsfCwtKNABf6koNOPwEGQwYnjlnhSc
iPl+tD5eCQGrZDufNVCQo2eZKpMMw4fUmuiFblT06Ja4woERSK/Yd/52HRVJ
nkpQfEoFc2+GXG7wpKEosrJXfFUNoWUuWa7VNAwd99t76NEotGYWnu3aREfb
LeqBSvoYsAu6DzZV0rGXP5pb4zYOc8VnNgU66eGkfCBam6mFzez7BrPL9fDF
2qPhh2wmABvuP+U66GOW4Y6wwPzP4CnaHLSxTB9PS6+G3do/BatL3caNHQ0w
5f3M4E9WFFQt5SQtuWuADjHmn93ZVKw8FUYLWc7AkO1832NcGvpqcsIZRQx8
8m1HVMtCOr6wXdXlZMNE530va3es00PhoiD7tFwmCn/Uu9mZoI+Pvf0lzpYz
sHwwtUr23ADt+Yp8TvYMZDOfDa3wZOLeaNdXa0gW3i44cpFaMwNjgpmfqGks
tIv0Dfjah40P5gTqFBw2bvno5yfiGWHx1Fm63S9s3G3heOFnjTHWStcpkmcZ
Yp30wpwL8TOxwiq4OinVEFVLdD7FebPwTOnO7HcsI5z63YNdUW2C/HntAf7J
RpjDXFSqMOXgWIk9uZhhjEm5NS/Xi0zxOL2/Lv2UMRKww2Wo1gxNbBwDbSkE
9p5PJ/GAOR457K1m/UTg8r9bs7uNuWi+UijnSQgUuJp2RJhxsXxSnOkSQaDX
toF8riUXDZKT15+IJNCjMVLt/xUXLxdUne+PJ1BhPCWe9OBi5ftlDvLLBAYo
flCVx3PRJIg4FltOYEeJk6MDg8RSuznu2U8IzPQKEM4nSBSM2Fk+lhG49nkr
cL4g8Uaka7W6isAGRw17ikei07UIM2H9dO8uMB1xJXH3m4ESlw4CJU9MXgji
SGTkahMC3hIY15MQcexXEgsPMnad6CKQevVhf2oGiZqJeYx7fQR2h/GZTXkk
JnD9fKyHCPwnaLkkXE6ifZdo8ZphAuUNRm55jSQ25Yfp+CoCQ2waOltek2jp
eC4vZYzAk8ssD27sJ/EpJUtSqJ3+VVEaFDVM4l55oZd8gkDnbq+FMi2JhikP
5/dMEugePfiQQrPAuz7yMZ2OQF1imsV6lgX+BzcUNIc=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 0},
  PlotRange->{{1, 4}, {0., 7.0100254502349335`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.548757838615415*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["To find the value of",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox[" e[3,u]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", just substitute ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["3",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" into ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["e:",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["e[3]/.dsolution", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", "2.4900259260372133`", "}"}]], "Output",
 CellChangeTimes->{3.5487578386514173`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving for the direct utility function", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Given a normalized indirect utility function, we can find the direct utility \
function just by solving a minimization problem.  Let's try the Cobb-Douglas \
case.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
L = p1*p2 - lambda*(p1 x1 + p2 x2 - 1)
solution=Solve[{D[L,p1]==0,D[L,p2]==0,D[L,lambda]==0},
         {p1,p2,lambda}][[1]]
u[x1_,x2_] := p1*p2 /.solution
u[x1,x2]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", " ", "p2"}], "-", 
  RowBox[{"lambda", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"p1", " ", "x1"}], "+", 
     RowBox[{"p2", " ", "x2"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5487578386894197`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"p1", "\[Rule]", 
    FractionBox["1", 
     RowBox[{"2", " ", "x1"}]]}], ",", 
   RowBox[{"p2", "\[Rule]", 
    FractionBox["1", 
     RowBox[{"2", " ", "x2"}]]}], ",", 
   RowBox[{"lambda", "\[Rule]", 
    FractionBox["1", 
     RowBox[{"2", " ", "x1", " ", "x2"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5487578387094207`*^9}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"4", " ", "x1", " ", "x2"}]]], "Output",
 CellChangeTimes->{3.548757838722421*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1206, 903},
WindowMargins->{{36, Automatic}, {Automatic, 16}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP\n\
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 69, 2, 123, "Title",
 Evaluatable->False],
Cell[651, 26, 100, 5, 71, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[776, 35, 81, 2, 105, "Section",
 Evaluatable->False],
Cell[860, 39, 404, 14, 41, "Text",
 Evaluatable->False],
Cell[1267, 55, 67, 1, 43, "Input"],
Cell[CellGroupData[{
Cell[1359, 60, 82, 1, 43, "Input"],
Cell[1444, 63, 310, 10, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1791, 78, 101, 1, 43, "Input"],
Cell[1895, 81, 572, 19, 63, "Output"]
}, Open  ]],
Cell[2482, 103, 835, 30, 67, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[3342, 137, 287, 9, 178, "Input"],
Cell[3632, 148, 655, 21, 62, "Output"],
Cell[4290, 171, 1230, 45, 134, "Output"],
Cell[5523, 218, 168, 6, 65, "Output"],
Cell[5694, 226, 190, 7, 65, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5921, 238, 100, 2, 54, "Subsection",
 Evaluatable->False],
Cell[6024, 242, 99, 2, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6148, 248, 105, 4, 66, "Input"],
Cell[6256, 254, 189, 6, 69, "Output"]
}, Open  ]],
Cell[6460, 263, 153, 5, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6638, 272, 128, 5, 88, "Input"],
Cell[6769, 279, 252, 8, 69, "Output"],
Cell[7024, 289, 189, 6, 69, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7262, 301, 105, 2, 54, "Subsection",
 Evaluatable->False],
Cell[7370, 305, 219, 5, 66, "Text",
 Evaluatable->False],
Cell[7592, 312, 75, 1, 43, "Input"],
Cell[CellGroupData[{
Cell[7692, 317, 118, 4, 66, "Input"],
Cell[7813, 323, 323, 12, 79, "Output"]
}, Open  ]],
Cell[8151, 338, 110, 2, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[8286, 344, 136, 4, 66, "Input"],
Cell[8425, 350, 320, 12, 79, "Output"]
}, Open  ]],
Cell[8760, 365, 83, 2, 41, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8892, 373, 78, 2, 105, "Section",
 Evaluatable->False],
Cell[8973, 377, 146, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[9144, 385, 81, 2, 54, "Subsection",
 Evaluatable->False],
Cell[9228, 389, 67, 1, 43, "Input"],
Cell[9298, 392, 604, 24, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[9927, 420, 126, 4, 66, "Input"],
Cell[10056, 426, 1308, 36, 70, "Output"]
}, Open  ]],
Cell[11379, 465, 132, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11536, 473, 91, 4, 66, "Input"],
Cell[11630, 479, 1161, 33, 70, "Output"]
}, Open  ]],
Cell[12806, 515, 402, 8, 90, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[13233, 527, 140, 5, 88, "Input"],
Cell[13376, 534, 1174, 33, 69, "Output"]
}, Open  ]],
Cell[14565, 570, 146, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[14736, 578, 172, 5, 88, "Input"],
Cell[14911, 585, 2469, 69, 136, "Output"]
}, Open  ]],
Cell[17395, 657, 953, 38, 42, "Text",
 Evaluatable->False],
Cell[18351, 697, 149, 4, 66, "Input"],
Cell[CellGroupData[{
Cell[18525, 705, 67, 1, 43, "Input"],
Cell[18595, 708, 546, 18, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19178, 731, 145, 4, 66, "Input"],
Cell[19326, 737, 3511, 63, 567, "Output"]
}, Open  ]],
Cell[22852, 803, 270, 6, 66, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[23159, 814, 85, 2, 54, "Subsection",
 Evaluatable->False],
Cell[23247, 818, 96, 2, 41, "Text",
 Evaluatable->False],
Cell[23346, 822, 65, 1, 43, "Input"],
Cell[23414, 825, 1462, 49, 142, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[24901, 878, 134, 7, 133, "Input"],
Cell[25038, 887, 90, 2, 42, "Output"],
Cell[25131, 891, 73, 1, 42, "Output"],
Cell[25207, 894, 72, 1, 42, "Output"],
Cell[25282, 897, 370, 12, 42, "Output"]
}, Open  ]],
Cell[25667, 912, 608, 22, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[26300, 938, 81, 1, 43, "Input"],
Cell[26384, 941, 2081, 40, 372, "Output"]
}, Open  ]],
Cell[28480, 984, 645, 27, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[29150, 1015, 57, 1, 43, "Input"],
Cell[29210, 1018, 112, 2, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29383, 1027, 104, 2, 105, "Section",
 Evaluatable->False],
Cell[29490, 1031, 233, 6, 66, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[29748, 1041, 213, 7, 133, "Input"],
Cell[29964, 1050, 283, 9, 42, "Output"],
Cell[30250, 1061, 385, 12, 63, "Output"],
Cell[30638, 1075, 125, 3, 63, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
