(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      9720,        342]
NotebookOptionsPosition[      7984,        279]
NotebookOutlinePosition[      8763,        306]
CellTagsIndexPosition[      8720,        303]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Consumers' Surplus", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Compensating and Equivalent Variation", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["A consumer has a demand function of the form ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["x=0.1 m - p",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", where ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["m",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is income and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p ",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["is price.  The consumer has income of 100 and faces a price of 2.  \
If the price increases to 4, what is the compensating and equivalent \
variation?\n\nThe first thing we have to do is to compute the expenditure \
function associated with this demand function.  We know from Chapter 8 that \
there is an analytic expression for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["e[p,u]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", but we'll use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["'s numerical differential equation solver here just to be \
different:",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution1=NDSolve[{e'[p]==.10*e[p] - p, e[2]==100},e,{p,1,5}]
Plot[Evaluate[e[p]/.solution1],{p,1,5}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"1.`", ",", "5.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.549387254176364*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj3sw1AkAxxexHptd+0tRcUfHaJJctTVx1++Ljgrlvfa3u79D14vKq0mX
3jiV200lVyEbd+SRVx7dZDflikyRnFC46cFRYgtb7Xrc3h/f+c5n5jPfma9N
RHTAdl0Gg+Grzf/9tGHYnMFQkj4S7kDrlxCcM+hNMNBXkk8vmiXHq0Pg59Pa
wzJWktNLRmwsNCFo7arKsZynJHeVrqLCp0LwcDTRbpWDkrwRZSIfnwlBw2JT
3g4/JdmY0eltMYePsoMrgx7JlGT8ggxJmCkfp50Tz19y+0AeH6jJfW/Lh+Oy
CfP1Vz+SZ/5gT+/ZysdrMv1d8+txMimy7u7AQT68M1zVSttJ0mrcNz/xGh+y
+Fa2/REVaXrvpNXex3wY7k1OQMMn8k1u36RQxYf4g83gTusvZPaBtWSebSh+
qmmVOB5Qkz9zxUl6W0Jx9MLV1Ge1GlJifchvx4FQpEwFn5Jwp8mZSo9vF+WF
IveY84ul/BnybN7lGx0toYhyX7hz28VZklko9S/5GAqz5smpoAQG3k0VFLdZ
CfBJEz0WaaGDduJer+YHAQInxduZTTroIc8JYmIFOCXtSIiL00Viplqhky1A
UzW1yo+rh4CIosjcRgEOy4Ljqu/o4fP+2YJjowK4WkZQaeFz0G5zf/u++RRi
+K/uD3H0UcwYNM9yo3CU9/bxPLk++tPM8gaiKGTK9I7dFBsgY1lZkMcFCt+0
p9/sNmHCsGNI0y2nUC9dcS6mjIllLHur5AEKy0eCTbp8DeHssfCuP0uIeWyl
4V9qQzALX/7ov0YI/TtZ5UuyjXD07XLHKLEQe1bf7jHyNkbQs3iDqlQhSjdF
yBQqY7hkEr0WlUKo3i3kDGaaYKTu8pOrXULUBnrpZWxgQbF18X5vHRGOb0zJ
rR5kYZPEt9LSQQTbvs3d+Slz8dJOt5+1RQTXtckZlitNkZZqTX+dIILYuu2L
Tocpym66H6JyRFC1SF7FnGCj7/vVpeUPRPDRXeGylMuBl00Yx+m9CMZjlL9O
BActjflFT7liJClQnH2Lg3V7X1SkuYpxIqicH2tkBtmKI/bx4WK4PO7yNAo3
Q2uf4tfdZ8T4x3xDsmGdGZJmr4ckVYlhZLduvhuTC395I7u9S4zR+UPD39Fc
RGs8r9kzaIS2fcWNK+dCEnjhdZUdjXJ+1inTWS7yezfP3bWZxt17T7AvmMCT
8Sq1VZzWn5D6MgsI2D/0ceT8RuNBq7tzdCEB38LD/1ZreXWRitt1ncBMv1Qm
uESDTdPdBSUEvNkUK/+y1m9avs2zkkBl+OkWXjYNXtajgyn1BOTrXV9S12hw
3Y1/1+sgYBWxMyG/hMbxxYpfov4mwGuSj3qV0hhVxe7u6CTg6TCxbUTLD0t6
nPK7CeSeZ2zklWl986I/3fsJBKsuqh5U0Bgb8mo7MUygMzLv/XANDVGjpnL4
LYErFWPu0loaLTnlGf4jBNIbF2WurKNRELCAshkjINTnrEm8RYOuH3zTMEFA
OrhDxLpN41HmlSYHFYHPSddlFVp2id1SnP6JgBO/+VVQPQ1z+9roMLX2b2Be
WI6cxklGZECzhgAVIsp2U9BQPrfiOU8TSPKY6BzQMl3TvuDSDIHnzMi5Z+5o
98+mqGdnCcSly92dGmj8Bxe9Lhs=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 92.},
  PlotRange->{{1, 5}, {91.90325285731996, 123.00282352935918`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549387254485381*^9}]
}, Open  ]],

Cell["\<\
The compensating variation will be the amount of money the consumer needs at \
the new price, p=4, to restore the original utility level, minus the original \
income.  This will be\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["CV= (e[4]/.solution1) - 100", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", "15.57194514394105`", "}"}]], "Output",
 CellChangeTimes->{3.549387254611388*^9}]
}, Open  ]],

Cell["\<\
The equivalent variation will be the amount of money that the consumer needs \
at the old price to make him as well off as he would be at the new price.  We \
have to solve the integrability equation again with a new boundary condition.\
\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution2=NDSolve[{e'[p]==.10*e[p] - p, e[4]==100},e,{p,1,5}]
EV= 100-(e[2]/.solution2)\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"e", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"1.`", ",", "5.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.549387254660391*^9}],

Cell[BoxData[
 RowBox[{"{", "12.749230781429006`", "}"}]], "Output",
 CellChangeTimes->{3.549387254662391*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Finally, we'll calculate the consumer's surplus for the move from ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p=4",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" to ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["p=2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[":",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
CS=Integrate[10-p,p]
Change =  (CS/.{p->4})-(CS/.{p->2})\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"10", " ", "p"}], "-", 
  FractionBox[
   SuperscriptBox["p", "2"], "2"]}]], "Output",
 CellChangeTimes->{3.5493872549394073`*^9}],

Cell[BoxData["14"], "Output",
 CellChangeTimes->{3.5493872549544077`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["What relationship has to hold between ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["CV, EV",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["CS",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["?",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1539, 956},
WindowMargins->{{44, Automatic}, {Automatic, 31}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP\n\
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 81, 2, 123, "Title",
 Evaluatable->False],
Cell[663, 26, 100, 5, 71, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[788, 35, 102, 2, 105, "Section",
 Evaluatable->False],
Cell[893, 39, 1491, 50, 141, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2409, 93, 151, 4, 66, "Input"],
Cell[2563, 99, 370, 12, 42, "Output"],
Cell[2936, 113, 2082, 40, 361, "Output"]
}, Open  ]],
Cell[5033, 156, 250, 6, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5308, 166, 69, 1, 43, "Input"],
Cell[5380, 169, 109, 2, 42, "Output"]
}, Open  ]],
Cell[5504, 174, 308, 7, 66, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5837, 185, 137, 4, 66, "Input"],
Cell[5977, 191, 370, 12, 42, "Output"],
Cell[6350, 205, 110, 2, 42, "Output"]
}, Open  ]],
Cell[6475, 210, 558, 22, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[7058, 236, 106, 4, 66, "Input"],
Cell[7167, 242, 164, 5, 67, "Output"],
Cell[7334, 249, 73, 1, 42, "Output"]
}, Open  ]],
Cell[7422, 253, 534, 22, 42, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
