(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     17569,        509]
NotebookOptionsPosition[     15063,        420]
NotebookOutlinePosition[     15842,        447]
CellTagsIndexPosition[     15799,        444]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Uncertainty", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Risk Premium", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
A consumer has a constant relative risk aversion utility function with risk \
aversion of 3.  He currently has monthly income of 5,000 and has a 50 percent \
chance of incurring a loss of 500.  How much would he be willing to pay to \
avoid this loss?

First we define the CRRA utility function:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["u[wealth_,rho_] := (wealth^(1-rho))/(1-rho)", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Call the risk premium ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["pi",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  To find it, we need to solve the following equation:",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
rho=3
loss=500
FindRoot[u[5000-pi,rho] == .5*u[5000,rho] 
+ .5*u[5000-loss,rho],{pi,500}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.5494681505953674`*^9}],

Cell[BoxData["500"], "Output",
 CellChangeTimes->{3.549468150604368*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"pi", "\[Rule]", "269.70501895126904`"}], "}"}]], "Output",
 CellChangeTimes->{3.549468150696373*^9}]
}, Open  ]],

Cell["Let's graph the risk premium as a function of the loss.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
rho=3
plotrho3=Plot[5000 - (.5*5000^(1-rho) + 
.5*(5000-loss)^(1-rho))^(1/(1-rho)),
{loss,0,2000}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.5494681507543764`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVT3k01AkA/i0qx8aQ7lXDvISIReVo+BwRjWPlqZWjpZC1jliNRh4z4xj3
jPm5Yg5bdCjetkqzGjZeod4m3orQVtq2y5GhKaS1f3zv+773vfe97zOMSAg4
rkIQhM8y/ue3M4sMj6gVzsvS3yNqzunk+TQbd+n4smeQMumAM1NrImqjVOFM
wMVsZd24M0teT6hJVUF0bBOM1SmcP1dwfD5J1oBIVDY0nlOFXG1GoZDQQLSN
Co5cWIMtjqae7yU2IIxa7buaaPAd7JqekriBGDpz85zcBuBztPalBIJwmLLV
aXGHriKomR8ZhsyCTweMFb5w+p353RnKMRAXNTVNiwMhSZZfGT18Ah3DL2fd
jILxxGusf8EjHqCPbk+PDsfxA6cnIh4kgSrr6R2viICLTKn2ID4FHan9aX2n
jkOr9Rmx+VkqqElvcHFnDHa894zfm5cGSdwL+lHTH+Fwc1MHXSUdRHf+kPX8
T2jyCt92JyED05dvDJERibilSVnS5WWio1WfYvE2CZta60eaO7NA1bd7+zE0
GUachSTZBg6Ohg5yBmdTEGatIciN5oJghUf681Kha+pzrkucDSrB8Fq/iokE
ul9C3EwOEqPkDOtLaXCvyjXn7sxDH+d7tvFuFrr0MupWZvPQnJtWn/wqHacS
LeoYf+VD0q/k2FVmQLp2jVBFpxD7y81Kp9Zn4tTQdSdaZBGI+1b6VcpMdD0v
HbkmKQZTez5hrjcL7g9pKupDJaA8zbjMr2GjNV6WOC4shRVX1nCFzQFvQ8bw
aWs+mm+9zl88woXVQ4nIc4yPxA0GBUHe2ZheEJt84ArQHX5I4LAnB3Hesssh
hmWI2V/E7FmXi1sNNgUfe8tg12rwx/qv89Br0h3JOCFExyQr+L4iD+8323/F
ViNx4VGMImuYhwkDjYV3jSTUY/TWXlr+dd5tdkLHuxyU0B+ONXYWwJrpRI+Z
LUdIbLP9b92FYPX9ks0sq4C+uf63Pu1FGKv+RxBrWYnC4Tv9t68VY21KziJ/
qBLp6p99le0l0EhyDU9KrYL/dWN7YVgp+tNDt+QYVuOFlofh4delaJkPrEvv
qQbDs1vdKpmPgzXRW3dEnYX3cOGNPXN83GUMf9Sm1EDt0EDVPY4AH6hR9y5d
rUFmQIhXtGYZnKMfRJh41yKf8jflbkkZwtoqgkZmajHPS3bXMxLCbhfLzaNU
BPPTHl/0G4UYZLmarSgTQXZvMj/zqhA/39bQ7SJFeFpebfOuWYhf/SqfuJwV
oWt2aaSzRQjz2JY0er0IxS5avJR2IajiqSbbNhH8HVsCR/qF0NA49g3tlQjG
L8Kvyz8JccFvh+rzNyKEVFSOWywK4VE+81oyIQI74F+L2iUhuLSsG1sUInBN
ejamq5JYoosCNi2JkOd61ddxNYmZk0N5uvpisM3OWLRTSZTeFCf0rRMjihVs
bkUjYUlEB5VsFEP0PGi/dBuJuKI52uqty7l10yOOGYmXDXrt6mZicDkTB71t
SXAnh8/fNRfDznbAsW03CdouaWGOpRiUlFHstCdx9LZlsNouMWSPj9TpOS3v
UVeic48YkwYDS1yQqPWTb2c7iKFtmshUupLYW56t7UIXY5pnoxO7j8TjUcbc
F+fl/j8NOkc9SfwHBtk3vg==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 2000}, {0., 1361.965588060104}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5494681511033964`*^9}]
}, Open  ]],

Cell["\<\
If the consumer is more risk averse the risk premium increases more rapidly\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
rho=7
plotrho7=Plot[5000 - (.5*5000^(1-rho) + 
.5*(5000-loss)^(1-rho))^(1/(1-rho)),
{loss,0,2000}]
Show[{plotrho3,plotrho7}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData["7"], "Output",
 CellChangeTimes->{3.5494681511493993`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjns0lAkAxSePlmw1SEdqNUxZKnFMWsrMXO+tSFnZio0805ZHyWvKGcb7
EeMxfIP5Por0RppKgwltrd2T1DaxoYdlbZtVM5Eiu/aPe+79/XV/JkFR3qFq
NBrNcz7/99/KWQ+3ME3u/OS7hU1yjtUmslyqh7k0/tKje2secxN0xsNWVKu4
tMB9/Y5nhrm8tjqaRrU6aHzpnE+tivu5TOD5kdIH7X5cd8V5dbRpKFUqijnP
9jpbm/RhvNXC/R3FAq1j1VRmJxM7FV1vJyhn0BhqLzijLEAo0HGN9QF/uZZl
sI4rdFW+DcLgA6AN7q72bPIC53bC7lP0EMjdqU532z2gjrddHtgbAZTWP79g
6YehbYOPZtwiITfJkYwdC0TojqTxoJ4YMCy1Az5QwXBs+aDRExkLRpOj3OZJ
GHRuvqStfBkHRvn3eoyRCKx/5x7pkJUIhmI6SbbjKLbcMpKz1U4isFq6d8Q1
Gle3Baz9KSoZ9Ai3sc7RGLQuos/pZvPxtkwUtfb6cRjdrHvW0JmCXSI1DVrk
CZgKZmJaDAWIlvc26PrG44CNdlFmeBqszaTLYrmJ0LXwPNtFpiMwTNP1NZ2H
KLZX1BFlBujNp62z9E/BhcjckLYxC9b31NrGZ5PRpZdcszA9G/WNpgpeHh/x
0ZY1Hk9ywDAcNosWp6DaQL9EbWke7BxsX2SLUxHfJ+Uwg/PxrXTR5s5mAbpe
FT67Rp3G9MHP8hPyNLj0MtW0+grA+LKzub07HTcjW6KHSwqREJeoeDqRgWzD
5P4kGyHoh36Vbtac9+ilJO6DQth5mxe9sc3G2xnSfCqtCNZxoYRhaA6ObG+5
6G9SDLrMttdPkIvWc6zc6e5ihKg7N/Ba89Btfj/YI6IE/iVriuij+Xi30n5B
qkYptMiP+57qFGD8K+2ZN5dKkcSshMqsELXO78eXbhdBPDxZermtEDYJHPah
9yJ0Rwz73QgRgvfwTHpCcRlkk6vqLRYUYVA8UnTYqhxLXCi7BxVFMIjNmBX2
lYMesrhx1KUY2jFOATFxBO5fS6Emhovx6OQPxhkmYpgtPC/LEZbg+iefmpM/
i7E8fMhgE7sU31WGr14fVgHZQuGagKFS3PPon15Cr4S4g7OHdVqEKUbYLxeu
VEKRlNfixSoDN7wnyHx7FUznaky/UJThgKzM95myCmcd5fYJmeWws+U5uxVK
EGfMHuuzJKDgOa3TLJagO35t6h1rAic6tHW7SiXYlVa17gKLQJNX+ZBjhQRG
mhvP8ewJbDh8PZFdJ4HDnxE7V7sSYJATVzfJJHi9YIV3hD8Bbe2QVcwxCd7f
7lmmlUug3mu9+qvXEjhViBOV+QTcRMq/qHEJDtfz3wwUEkhjptwwVknAeVEw
2ygiMMeWeBvNSfDHxJ67/jUElMf6snSXkfC55DfVfItA4S0y6uFyEr4vLbZS
MgJWtHDfghUk+I/783PbCRzJn2QuXk1if91D/6C7BEbP6bVrrSORZyal6L3z
f//0197bQMLj4Eaf2ccEmLbVeRlWJK48+dFgTEEgsMNqv4YtCb1N5nfaB+Z9
tD6g8xsSv6lTFy8+J1Dl1fZ16hYS0r4HZ8peEXAQpS9xZJP4ZNZ4XjBC4PcB
j8l/uSQig51bo8YI/AdEDTn8
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 2000}, {0., 1658.1091204194486`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5494681511844015`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVT3k01AkA/i0qx8aQ7lXDvISIReVo+BwRjWPlqZWjpZC1jliNRh4z4xj3
jPm5Yg5bdCjetkqzGjZeod4m3orQVtq2y5GhKaS1f3zv+773vfe97zOMSAg4
rkIQhM8y/ue3M4sMj6gVzsvS3yNqzunk+TQbd+n4smeQMumAM1NrImqjVOFM
wMVsZd24M0teT6hJVUF0bBOM1SmcP1dwfD5J1oBIVDY0nlOFXG1GoZDQQLSN
Co5cWIMtjqae7yU2IIxa7buaaPAd7JqekriBGDpz85zcBuBztPalBIJwmLLV
aXGHriKomR8ZhsyCTweMFb5w+p353RnKMRAXNTVNiwMhSZZfGT18Ah3DL2fd
jILxxGusf8EjHqCPbk+PDsfxA6cnIh4kgSrr6R2viICLTKn2ID4FHan9aX2n
jkOr9Rmx+VkqqElvcHFnDHa894zfm5cGSdwL+lHTH+Fwc1MHXSUdRHf+kPX8
T2jyCt92JyED05dvDJERibilSVnS5WWio1WfYvE2CZta60eaO7NA1bd7+zE0
GUachSTZBg6Ohg5yBmdTEGatIciN5oJghUf681Kha+pzrkucDSrB8Fq/iokE
ul9C3EwOEqPkDOtLaXCvyjXn7sxDH+d7tvFuFrr0MupWZvPQnJtWn/wqHacS
LeoYf+VD0q/k2FVmQLp2jVBFpxD7y81Kp9Zn4tTQdSdaZBGI+1b6VcpMdD0v
HbkmKQZTez5hrjcL7g9pKupDJaA8zbjMr2GjNV6WOC4shRVX1nCFzQFvQ8bw
aWs+mm+9zl88woXVQ4nIc4yPxA0GBUHe2ZheEJt84ArQHX5I4LAnB3Hesssh
hmWI2V/E7FmXi1sNNgUfe8tg12rwx/qv89Br0h3JOCFExyQr+L4iD+8323/F
ViNx4VGMImuYhwkDjYV3jSTUY/TWXlr+dd5tdkLHuxyU0B+ONXYWwJrpRI+Z
LUdIbLP9b92FYPX9ks0sq4C+uf63Pu1FGKv+RxBrWYnC4Tv9t68VY21KziJ/
qBLp6p99le0l0EhyDU9KrYL/dWN7YVgp+tNDt+QYVuOFlofh4delaJkPrEvv
qQbDs1vdKpmPgzXRW3dEnYX3cOGNPXN83GUMf9Sm1EDt0EDVPY4AH6hR9y5d
rUFmQIhXtGYZnKMfRJh41yKf8jflbkkZwtoqgkZmajHPS3bXMxLCbhfLzaNU
BPPTHl/0G4UYZLmarSgTQXZvMj/zqhA/39bQ7SJFeFpebfOuWYhf/SqfuJwV
oWt2aaSzRQjz2JY0er0IxS5avJR2IajiqSbbNhH8HVsCR/qF0NA49g3tlQjG
L8Kvyz8JccFvh+rzNyKEVFSOWywK4VE+81oyIQI74F+L2iUhuLSsG1sUInBN
ejamq5JYoosCNi2JkOd61ddxNYmZk0N5uvpisM3OWLRTSZTeFCf0rRMjihVs
bkUjYUlEB5VsFEP0PGi/dBuJuKI52uqty7l10yOOGYmXDXrt6mZicDkTB71t
SXAnh8/fNRfDznbAsW03CdouaWGOpRiUlFHstCdx9LZlsNouMWSPj9TpOS3v
UVeic48YkwYDS1yQqPWTb2c7iKFtmshUupLYW56t7UIXY5pnoxO7j8TjUcbc
F+fl/j8NOkc9SfwHBtk3vg==
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjns0lAkAxSePlmw1SEdqNUxZKnFMWsrMXO+tSFnZio0805ZHyWvKGcb7
EeMxfIP5Por0RppKgwltrd2T1DaxoYdlbZtVM5Eiu/aPe+79/XV/JkFR3qFq
NBrNcz7/99/KWQ+3ME3u/OS7hU1yjtUmslyqh7k0/tKje2secxN0xsNWVKu4
tMB9/Y5nhrm8tjqaRrU6aHzpnE+tivu5TOD5kdIH7X5cd8V5dbRpKFUqijnP
9jpbm/RhvNXC/R3FAq1j1VRmJxM7FV1vJyhn0BhqLzijLEAo0HGN9QF/uZZl
sI4rdFW+DcLgA6AN7q72bPIC53bC7lP0EMjdqU532z2gjrddHtgbAZTWP79g
6YehbYOPZtwiITfJkYwdC0TojqTxoJ4YMCy1Az5QwXBs+aDRExkLRpOj3OZJ
GHRuvqStfBkHRvn3eoyRCKx/5x7pkJUIhmI6SbbjKLbcMpKz1U4isFq6d8Q1
Gle3Baz9KSoZ9Ai3sc7RGLQuos/pZvPxtkwUtfb6cRjdrHvW0JmCXSI1DVrk
CZgKZmJaDAWIlvc26PrG44CNdlFmeBqszaTLYrmJ0LXwPNtFpiMwTNP1NZ2H
KLZX1BFlBujNp62z9E/BhcjckLYxC9b31NrGZ5PRpZdcszA9G/WNpgpeHh/x
0ZY1Hk9ywDAcNosWp6DaQL9EbWke7BxsX2SLUxHfJ+Uwg/PxrXTR5s5mAbpe
FT67Rp3G9MHP8hPyNLj0MtW0+grA+LKzub07HTcjW6KHSwqREJeoeDqRgWzD
5P4kGyHoh36Vbtac9+ilJO6DQth5mxe9sc3G2xnSfCqtCNZxoYRhaA6ObG+5
6G9SDLrMttdPkIvWc6zc6e5ihKg7N/Ba89Btfj/YI6IE/iVriuij+Xi30n5B
qkYptMiP+57qFGD8K+2ZN5dKkcSshMqsELXO78eXbhdBPDxZermtEDYJHPah
9yJ0Rwz73QgRgvfwTHpCcRlkk6vqLRYUYVA8UnTYqhxLXCi7BxVFMIjNmBX2
lYMesrhx1KUY2jFOATFxBO5fS6Emhovx6OQPxhkmYpgtPC/LEZbg+iefmpM/
i7E8fMhgE7sU31WGr14fVgHZQuGagKFS3PPon15Cr4S4g7OHdVqEKUbYLxeu
VEKRlNfixSoDN7wnyHx7FUznaky/UJThgKzM95myCmcd5fYJmeWws+U5uxVK
EGfMHuuzJKDgOa3TLJagO35t6h1rAic6tHW7SiXYlVa17gKLQJNX+ZBjhQRG
mhvP8ewJbDh8PZFdJ4HDnxE7V7sSYJATVzfJJHi9YIV3hD8Bbe2QVcwxCd7f
7lmmlUug3mu9+qvXEjhViBOV+QTcRMq/qHEJDtfz3wwUEkhjptwwVknAeVEw
2ygiMMeWeBvNSfDHxJ67/jUElMf6snSXkfC55DfVfItA4S0y6uFyEr4vLbZS
MgJWtHDfghUk+I/783PbCRzJn2QuXk1if91D/6C7BEbP6bVrrSORZyal6L3z
f//0197bQMLj4Eaf2ccEmLbVeRlWJK48+dFgTEEgsMNqv4YtCb1N5nfaB+Z9
tD6g8xsSv6lTFy8+J1Dl1fZ16hYS0r4HZ8peEXAQpS9xZJP4ZNZ4XjBC4PcB
j8l/uSQig51bo8YI/AdEDTn8
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 2000}, {0., 1361.965588060104}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5494681511874013`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A simple portfolio problem", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Let's calculate how much a consumer would invest in a risky asset.\
\nAgain, we assume a CRRA utility function and suppose that the risk asset \
has a 50 percent chance of a rate of return of 70% and a 50  percent chance \
of -30%.  Utility as a function of the investment ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["a",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
eu[a_] := .5*u[wealth+.7*a,rho] + 
.5u[wealth-.3*a,rho]\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
Fix wealth at 1000, say, and rho at 3, and plot this as a function of a.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
wealth=1000
rho=5
Plot[Evaluate[eu[a]],{a,1,600}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData["1000"], "Output",
 CellChangeTimes->{3.549468151252405*^9}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.549468151281407*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0HtU03UYBvBJMC6pCUqsUMmh0bxgnAhIgb1Tmlxkfn9jUw7E5KpcBHVu
474LA3JRcRHIPAjBAYFhHRGhk/ii4uWYcJiogAMjJcW80IJw4ojZ+uM9z/n8
9zzvmviD/CQrGo223XL/582v8gYX0/5mLzv/r9yqksL+ojVlD9WuUFx4Zi5d
QeGR2emXv6tZMH6nU9qdRqFtULbzEtVn0LB3pca0ncIZh5hAY8c2eNZ+8psk
JoUGnVWHWhMM6glbRZs1hUvWzK1q+Y0H11oflTx4QvC9sVMjw/F8qJNyVe63
CF5Iy3ZdVy2EV+a4iq5fCO7XDrALzkeCJJrRNHWKYE9UuWurVxS4MGLat9YR
dH5b8ErXEg3i00UPPjlOUFKrLathx4BaOtNFlRO867VofcqwCDSBdkNeJQTf
f55Jd2HFQlnpQ+OHxQTDAgyZrydjQfJBV+clFUHzli/r3erjoEm/O2KpnOAZ
P7e+z6PjIdTFw82YQ3DSQ3UncF0C7H/KvcHNIrjK5Y8xX0MCxK9emxosIzha
vLPI9WUCmLWR6/0tPm7s9HxjSoATwRXLPrZ4xfBR1XV6IlSX0ncxLHao8vQQ
rk4Epqzs2DMpwTmnHLE4PBGuHnrXr9riu0sd7X9sS4TkjZphe4u/prN9mMlJ
kPxOemuchOBbek/eWdp+WLmnvn7aYrlV7PCv5clgcorLdbH0u1AXdHFwZwqw
bHiRByz95/1ZLXrbVMgtJqawfMs/+0YOnrudCo1tnWBj2a+MKvYtPZkGWt3x
blERwavTtLWTUQegwVfMXdAQtNXkLgtgpEMwp3V2bSnBAcdLY/sep8PGRfOZ
giqC1Sesm8vOZkCHOD2JWUOwUvVkuJN5CCr7mWZuG0FRD0NRN34IDBy79QXd
BE+/WE7/QnsY4kN7vffqCOa6j7VXJouhjQrKsXlEsN/mirOj+xHYZmzq9TUR
rNdLImOnjsDoxl0m2QoKX3XOXNyglUCW9UdBJk8KB9Vb6DdlUugbHciYDKdw
00KD9Wm2DBY27XgmzaDQQTHi4TAvg6BGu4Cb31KYNjPE2no9E87fKNw330Fh
eMYP5E91Fghc8/w67lHYXlWyWR+QDW2bJs6Vmyn8/ieYqrHNgYZGNfMKi49W
ty7r7l/JgRBd4H17AR8NE4vLDaW54E7/a9K2kI8xZvdMOS8PRE47CifO8jH8
WrQzZZ8Pqp/TOD0TfLycH1NhvJMP9iHsHbcZEdgVuMGbUS4HOwMnf094BG6e
7j23WKSAf5plfgVHI7CqGWUNy5VwQ/fp9OOrEXh7VNGUd1gJIS/Ys7w3EThI
b94OI0p4ukVEM4AAHX29Zzk+KhhP9RmKVQrQCQeVScdUIO+ZVTZeEuDQ1rt5
4jkVPNfT2F12QrzX41+CuwughXKY8+IJMZSW2isqKYCwlIHgKakQuznfvX5z
sQCauYrayFoh/gc1WAYQ
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, -3.08*^-13},
  PlotRange->{{1, 
    600}, {-3.0721792712434314`*^-13, -2.3383414601762214`*^-13}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5494681513124084`*^9}]
}, Open  ]],

Cell["\<\
It looks like this consumer would like to invest about $200.  Let's check:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["FindMinimum[-eu[a],{a,200}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.338277807521437`*^-13", ",", 
   RowBox[{"{", 
    RowBox[{"a", "\[Rule]", "174.72428588162984`"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.549468151387413*^9}]
}, Open  ]],

Cell["So the optimal investment is about $175.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mean-Variance Utility", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Let's check the calculation in the text for Normally distributed wealth and  \
constant absolute risk averse utility function.    [To be completed...]\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1539, 956},
WindowMargins->{{52, Automatic}, {30, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP\n\
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 74, 2, 123, "Title",
 Evaluatable->False],
Cell[656, 26, 100, 5, 71, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[781, 35, 77, 2, 105, "Section",
 Evaluatable->False],
Cell[861, 39, 365, 9, 115, "Text",
 Evaluatable->False],
Cell[1229, 50, 85, 1, 43, "Input"],
Cell[1317, 53, 387, 14, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1729, 71, 139, 6, 111, "Input"],
Cell[1871, 79, 72, 1, 42, "Output"],
Cell[1946, 82, 72, 1, 42, "Output"],
Cell[2021, 85, 140, 3, 42, "Output"]
}, Open  ]],
Cell[2176, 91, 117, 2, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2318, 97, 148, 6, 111, "Input"],
Cell[2469, 105, 72, 1, 42, "Output"],
Cell[2544, 108, 2063, 40, 355, "Output"]
}, Open  ]],
Cell[4622, 151, 145, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4792, 159, 174, 7, 133, "Input"],
Cell[4969, 168, 72, 1, 42, "Output"],
Cell[5044, 171, 2065, 40, 355, "Output"],
Cell[7112, 213, 3815, 70, 355, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10976, 289, 91, 2, 105, "Section",
 Evaluatable->False],
Cell[11070, 293, 585, 17, 91, "Text",
 Evaluatable->False],
Cell[11658, 312, 105, 4, 66, "Input"],
Cell[11766, 318, 142, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11933, 326, 99, 5, 88, "Input"],
Cell[12035, 333, 73, 1, 42, "Output"],
Cell[12111, 336, 70, 1, 42, "Output"],
Cell[12184, 339, 1920, 38, 327, "Output"]
}, Open  ]],
Cell[14119, 380, 144, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[14288, 388, 69, 1, 43, "Input"],
Cell[14360, 391, 212, 6, 48, "Output"]
}, Open  ]],
Cell[14587, 400, 102, 2, 41, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[14726, 407, 86, 2, 105, "Section",
 Evaluatable->False],
Cell[14815, 411, 220, 5, 41, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
