(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='%s' *)
(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       131,          6]
NotebookDataLength[     63710,       1314]
NotebookOptionsPosition[     61065,       1221]
NotebookOutlinePosition[     61564,       1242]
CellTagsIndexPosition[     61521,       1239]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Competitive Markets", "Title"],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["The supply function", "Section"],

Cell["\<\
Let's construct a supply function with U-shaped average variable costs.  \
First we experiment a bit to get a nice U-shape that we'll use for our AVC \
curve.  Then we multiply by y to get variable costs, and finally, add a fixed \
cost:\
\>", "Text"],

Cell[CellGroupData[{

Cell["avcPlot=Plot[10+(y-5)^2,{y,0,15},AxesOrigin->{0,0}]", "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmHlYDe8bxiNLaTvnzJzO6bQgc07riYrSou4KbdKi0kIhpZSiUsrSJqVE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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {0, 109.99999387755113`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5496373950564384`*^9}]
}, Open  ]],

Cell["c[y_] := 10y + y(y-5)^2+20", "Input"],

Cell[CellGroupData[{

Cell["acPlot=Plot[Evaluate[c[y]]/y,{y,.1,15}]", "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c0lu8fB3BUGvazrJKRwvM8yI50v32tjGSFPErkSzJCUejbRqlU0jBS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 15.},
  PlotRange->{{0.1, 15}, {13.860817871201544`, 160.1346381240483}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5496373952576914`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["mcPlot=Plot[Evaluate[D[c[y],y]],{y,.1,15}]", "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVVnk4FNwXHuuMGcuMLdmzZMiIijbcl7KEytZmyRLlS6RFGYk+CW2IFqRS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.1, 15}, {0., 409.99997871428593`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5496373953126926`*^9}]
}, Open  ]],

Cell["Here they are all together:", "Text"],

Cell[CellGroupData[{

Cell["Show[avcPlot,acPlot,mcPlot]", "Input"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmHlYDe8bxiNLaTvnzJzO6bQgc07riYrSou4KbdKi0kIhpZSiUsrSJqVE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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c0lu8fB3BUGvazrJKRwvM8yI50v32tjGSFPErkSzJCUejbRqlU0jBS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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVVnk4FNwXHuuMGcuMLdmzZMiIijbcl7KEytZmyRLlS6RFGYk+CW2IFqRS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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 15}, {0, 109.99999387755113`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549637395352693*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Welfare economics", "Section"],

Cell["\<\
Let's see how we get to a welfare maximum.  Take the following utility and \
cost functions:\
\>", "Text"],

Cell["\<\
u[x_] := Log[x]
c[y_] := y^2\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
inverseDemand[x_] := Evaluate[u'[x]]
inverseSupply[x_] := Evaluate[c'[x]]
Plot[{inverseSupply[x],inverseDemand[x]},{x,.1,3}]\
\>", "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtxWlME2YYAOC2FL6qWOX8jJqhxARToyZi4oHwvqhxXvXgh8eyYWVRMy0o
UTAyFRWNVGyyCd4HAWNExSsbwbZTgYEiHVJUpI2oyGFRcbVQKFBK1XzvjyfP
xKTtCZtkEolE/c33S/+pOX3urAHET6Cy/c+CtucG+glYlOtvTFMa6Rro0Ngf
VBwy0jUwxl/+/uM2E22GDHXszJi4+3QtRDjWdiSnltEWaMmsOawMr6RfwCON
qX3moJl+BfGG7KCpt+rpd1DwuLjBuKyBboc7JS+nmmbZ6A+gmhftMjY30Z2g
ql96NVzbTH8BydHZW/SJLXQXBOrgTdb0NtoFjowl+X9Fvad7QWHQ8l+H7LQb
WvYsj7SYP9D9kKeavju97BPtgb1RU7Iu5H6mvRATqrJ59A7aB6/LuzTHH36h
JXgv4vWdn646QSzFzJ7qK1WFXSCW4cbU+PQd+m4Q++G0TaZPpTkuEMvx53O5
qsQjPSD2xytpfQsXpvSCOABt1Ynyx1vdIGY4uWJ1vm5NH4gVaB0s9LsR2w/i
Ybjrdk/gb7MHQDwcpyganJsjPSAegbXWkt+lEwZBHIiWj66nA2O8IB6J/xeW
eaOlQyBWovuZvn6YdwjEShx3zX4gosMH4lG4srlucMkWCT0aWVFxTkKbhB6N
tRUrFZ51UjoIdWd3NqY2SukgTPj3l7xstYwORvNId8mKchkdjHNDg1StcX50
CJYmO3P43350CKqyEnBstJwORbUhaf1/t+V0KO6bP0fzwyR/OgwvH/3DEFfo
T4dhY8QtiY8H0OFosmYUp+QE0OF4Ul19vVjBaI57w5pOHdvHaI6ytxptXiaj
OWYXtcdfOshojrkxjs67RxjN8fpG2QKbntEcG29OdkRdYjTHGYvSfqx6wGiO
90YNjK8rYzTHWNv+LmsFozku1mZf7HzEaI4bTpzvDqljNMfjb8rzk94ymmNw
0aI07TtGczyTal6a3spojpflDT06O6M5GlUdy+46GM0RXdqJJiejOVbdd/ZW
djOao2WVp8DqZjTHNWMP7G7pZzTHpla5utPDaI5JN3WRvV5Gc7SnK/t8PkZz
/Ar4PFWs
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1fk/1AsbxnFmhkFjX7KUvUiikqy5by32pZykEiH0spbCOVERLYQWKqE4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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.5, 0},
  PlotRange->{{0.1, 3}, {0., 9.999994081636155}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549637395393944*^9}]
}, Open  ]],

Cell["We'll plot benefit minus cost on the same scale:", "Text"],

Cell[CellGroupData[{

Cell["Plot[u[x]-c[x],{x,.1,3}]", "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VdsbB/BDOMqYIkM5kTKkaDIk3iMyhaQ0oMhFZQgZKg1EbmTIjW4k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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.5, -8.},
  PlotRange->{{0.1, 3}, {-7.901387375957743, -0.846573904302042}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5496373954251947`*^9}]
}, Open  ]],

Cell[TextData[{
 "The equilibrium value of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is given by"
}], "Text"],

Cell[CellGroupData[{

Cell["solution1=Solve[inverseDemand[x] == inverseSupply[x],][[1]]", "Input",
 EmphasizeSyntaxErrors->True],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partw"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part \[NoBreak]\\!\\(1\\)\[NoBreak] of \
\[NoBreak]\\!\\({}\\)\[NoBreak] does not exist. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partw\\\", ButtonNote -> \
\\\"Part::partw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5496373958889513`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "}"}], "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}]], "Output",
 CellChangeTimes->{3.549637395931452*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Taxes", "Section"],

Cell["\<\
Let's use the same demand and supply functions to calculate equilibrium with \
taxes.  If a tax of t=.10 is imposed, the new equilibrium is\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
solution2=Solve[inverseDemand[x] == 
                inverseSupply[x]+ 0.1][[1]]\
\>", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", "\[Rule]", 
   RowBox[{"-", "0.7325485849042452`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5496373960014534`*^9}]
}, Open  ]],

Cell["\<\
Now we'll plug this into the welfare function and see what the deadweight \
loss is.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
deadweightLoss=N[(u[x]-c[x]/.solution2)-
                 (u[x]-c[x])/.solution1]\
\>", "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Part", "::", "partw"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Part \[NoBreak]\\!\\(1\\)\[NoBreak] of \
\[NoBreak]\\!\\({}\\)\[NoBreak] does not exist. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partw\\\", ButtonNote -> \
\\\"Part::partw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.549637396038954*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(\\(\\({}\\)\\) \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.549637396127705*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({\\(\\(\\({}\\)\\) \[LeftDoubleBracket] 1 \
\[RightDoubleBracket]\\)}\\)\[NoBreak] is neither a list of replacement rules \
nor a valid dispatch table, and so cannot be used for replacing. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\", \
ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5496373961589556`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "0.8478530420213712`"}], "+", 
     RowBox[{"3.141592653589793`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
   SuperscriptBox["x", "2"], "-", 
   RowBox[{"1.`", " ", 
    RowBox[{"Log", "[", "x", "]"}]}]}], "/.", "\[VeryThinSpace]", 
  RowBox[{
   RowBox[{"{", "}"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}]], "Output",
 CellChangeTimes->{3.5496373961639557`*^9}]
}, Open  ]],

Cell["\<\
Let's make a little graph depicting deadweight loss as a function of the tax \
level.  First we'll write a function to compute total benefits as a function \
of the tax rate.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
solution3=Solve[inverseDemand[x] == 
                inverseSupply[x]+ t,x][[1]]
netWelfare[t_] := (u[x]-c[x]/.solution3)
netWelfare[t]\
\>", "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x", "\[Rule]", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "-", 
      SqrtBox[
       RowBox[{"8", "+", 
        SuperscriptBox["t", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.549637396268957*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "-", 
      SqrtBox[
       RowBox[{"8", "+", 
        SuperscriptBox["t", "2"]}]]}], ")"}], "2"]}], "+", 
  RowBox[{"Log", "[", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "-", 
      SqrtBox[
       RowBox[{"8", "+", 
        SuperscriptBox["t", "2"]}]]}], ")"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.5496373962764573`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[netWelfare[t],{t,0,1}]
^*)#!@--END--cut here--<13compet.ma>  part:<1/1>\
\>", "Input"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAASmXo0cDpVT74HH1/IRfrv4EIsyeJ
GZQ/KMwa94YX679YWaGv8PGkP1wej2zcGOu/C/+BXEcerz8ajBq39xrrvyVR
7ujDi7Q/NKlZ+tkd6793zjk/mPS5P+0VpZzoIeu/F7QR3gEBvz+GeMsrlCbr
v7biQ8zPPMI/Vnitz50s67/Cap0bWezEP8QnDJyLM+u/9SY9D61txz8EB80o
6jrrvwL5qxAbJco/kKooJ+hD6782/2C2U67MPyxFtd5ATeu/zIQ0zsYqzz9d
f3C5UVfrvx+Q6/mp7tA/aongqkNj67/r99/e1TDSP1KbBdthb+u/pOq7yg6O
0z/X3q0hl33rvw4dp+/k5NQ/NN5zD6OM67+MabVmoCTWP5d5jlipm+u/9kCr
5Gh/1z/5v7dBDa3rv3QyxLQWw9g/9AgRiFK+67/frsSL0SHaP5B2QGsu0uu/
+2rUmyl62z+V5ciQ2ebrvytBB/5mu9w/lhgaZTD7679HoiFnsRfeP/hthwFo
Euy/dx1fIuFc3z+LzG5ZMCnsvyzsVQvXTeA/3mfTFpJA7L8TD/AIxPrgP5Zv
qKIeW+y/BL+bryOc4T+aRo4zBHXsv2s0u9kJS+I/n5mZZFGS7L+rSWKgvvbi
P8ooXGdYsOy/9esaEOaW4z9IH5Enfc3sv7VTRwOUROQ//nqQOFju7L9/SIWf
tObkP+X/qCozDu2/Id1K2KOF5T9olJY/jC7tvzo3hJQZMuY/fJo86OlS7b9c
Hs/5AdPmPxJ7J2wKdu2/9cqN4nCB5z963nrKb53tv5gEXnRSJOg/mlmISHjD
7b8T3rWiAsToP5xdBWHv6e2/BX2BVDlx6T+13nWV/BTuvwCpXq/iEuo/FGeE
bWw+7r9ymq+NEsLqP38Ykxe1bO6/vSuICBFu6z/jo7b7jZvuvxFKciyCDuw/
qwIYbYXI7r/cLdDTebzsP1f7Jkmr+u6/sJ4/JORe7T+LTi5EzSrvv12vNhEd
/u0/3ls8pjpb77+AhaGB3KruP8HcLy4rke+/regdmw5M7z/dEWOH0sTvv5cf
C/X//+8/iApZ/P//77+o/rFr
   "], {}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549637396313958*^9}],

Cell["Syntax::bktx: \"^*\" has extra \")\" after it.", "Message", "MSG",
 CellChangeTimes->{3.549637396320208*^9}],

Cell["Syntax::sntxi: Incomplete expression; more input is needed .", "Message", "MSG",
 CellChangeTimes->{3.5496373963352084`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{707, 850},
WindowMargins->{{490, Automatic}, {55, Automatic}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[553, 21, 36, 0, 83, "Title"],
Cell[592, 23, 54, 3, 47, "Subsubtitle"],
Cell[CellGroupData[{
Cell[671, 30, 38, 0, 71, "Section"],
Cell[712, 32, 261, 5, 47, "Text"],
Cell[CellGroupData[{
Cell[998, 41, 68, 0, 31, "Input"],
Cell[1069, 43, 6112, 106, 241, "Output"]
}, Open  ]],
Cell[7196, 152, 43, 0, 31, "Input"],
Cell[CellGroupData[{
Cell[7264, 156, 56, 0, 31, "Input"],
Cell[7323, 158, 8182, 140, 241, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15542, 303, 59, 0, 31, "Input"],
Cell[15604, 305, 5977, 104, 240, "Output"]
}, Open  ]],
Cell[21596, 412, 43, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[21664, 416, 44, 0, 31, "Input"],
Cell[21711, 418, 19622, 330, 241, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41382, 754, 36, 0, 71, "Section"],
Cell[41421, 756, 116, 3, 29, "Text"],
Cell[41540, 761, 53, 3, 48, "Input"],
Cell[CellGroupData[{
Cell[41618, 768, 149, 4, 65, "Input"],
Cell[41770, 774, 5313, 95, 252, "Output"]
}, Open  ]],
Cell[47098, 872, 64, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[47187, 876, 41, 0, 31, "Input"],
Cell[47231, 878, 6829, 118, 252, "Output"]
}, Open  ]],
Cell[54075, 999, 136, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[54236, 1009, 106, 1, 31, "Input"],
Cell[54345, 1012, 467, 10, 21, "Message"],
Cell[54815, 1024, 157, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55021, 1034, 24, 0, 71, "Section"],
Cell[55048, 1036, 163, 3, 47, "Text"],
Cell[CellGroupData[{
Cell[55236, 1043, 105, 3, 48, "Input"],
Cell[55344, 1048, 160, 4, 30, "Output"]
}, Open  ]],
Cell[55519, 1055, 110, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[55654, 1062, 106, 3, 48, "Input"],
Cell[55763, 1067, 465, 10, 21, "Message"],
Cell[56231, 1079, 593, 11, 21, "Message"],
Cell[56827, 1092, 595, 11, 21, "Message"],
Cell[57425, 1105, 464, 13, 30, "Output"]
}, Open  ]],
Cell[57904, 1121, 198, 4, 47, "Text"],
Cell[CellGroupData[{
Cell[58127, 1129, 160, 5, 82, "Input"],
Cell[58290, 1136, 315, 11, 46, "Output"],
Cell[58608, 1149, 556, 21, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59201, 1175, 101, 3, 48, "Input"],
Cell[59305, 1180, 1470, 30, 242, "Output"],
Cell[60778, 1212, 114, 1, 21, "Message"],
Cell[60895, 1215, 130, 1, 21, "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

