(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     88909,       1695]
NotebookOptionsPosition[     86579,       1611]
NotebookOutlinePosition[     87357,       1638]
CellTagsIndexPosition[     87314,       1635]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Monopoly", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Deadweight loss of monopoly", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Let's see how the deadweightloss of monopoly varies with the elasticity of \
demand.  Suppose that utility, demand and costs are given by the following \
functions\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
u[x_] := x^(1-e)/(1-e)
c[x_] := x
p[x_] := x^(-e)
demand[p_] := p^(-1/e)\
\>", "Input",
 AspectRatioFixed->True],

Cell["\<\
Given these relationships, we can easily calculate the equilibrium values:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
equilPrice[e_] := 1/(1-(1/e))
equilQuant[e_] := demand[equilPrice[e]]
equilWelfare[e_] := u[equilQuant[e]] - equilPrice[e]
equilWelfare[e]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", 
    RowBox[{"1", "-", 
     FractionBox["1", "e"]}]]}], "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        RowBox[{"1", "-", 
         FractionBox["1", "e"]}]], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "/", "e"}]], ")"}], 
    RowBox[{"1", "-", "e"}]], 
   RowBox[{"1", "-", "e"}]]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5497407737686167`*^9, 3.549795683089794*^9, 
  3.549876029622463*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 StyleBox["What a messy expression.  Note that this only makes sense for ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["e>1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  (A monopolist never operates at an inelastic portion of the \
demand curve.)  Let's see how welfare varies with the elasticity:",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Plot[Evaluate[equilWelfare[e]],{e,1.1,5}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzHk8lGsbB/AxTFlmmJmHsWVtkxOVKET3TWQJlY4OqveUV6GynqKcRusr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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1.5, -8.},
  PlotRange->{{1.1, 5}, {-7.922424700902168, -1.548860167844742}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549740774236644*^9, 3.5497956834372993`*^9, 
  3.549876030038719*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second-degree price discrimination", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
There are two classes of consumers with utility functions u1[x,t]=tLog[x] for \
t=1,2.  The monopolist has a constant marginal cost of c.  We want to find \
the optimal price discrimination scheme.  According to the text, we simply \
have to solve the following two equations:\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
u[x_] := Log[x]
solution=Solve[{u'[x1] -1 + u'[x1]-2u'[x2]==0,
               2u'[x2]-c == 0},{x1,x2}][[1]]
out1[c_] := Evaluate[x1/.solution]
out2[c_] := Evaluate[x2/.solution]
Plot[{out1[c],out2[c]},{c,.1,3}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x1", "\[Rule]", 
    FractionBox["2", 
     RowBox[{"1", "+", "c"}]]}], ",", 
   RowBox[{"x2", "\[Rule]", 
    FractionBox["2", "c"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.549740774558662*^9, 3.5497956837148037`*^9, 
  3.5498760303299737`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVk3lYzHkAh6dp6peVEh3W9lSyVjvIw5RF6vMtOYpxtB6rRaY8IToU1YMo
m6PZhJR1m4oIuR5lOtCh0tOgkkyzrl9zNNNlmuluZrTtH5/nfd6/3r8+00Ki
AkKZDAaDO7b/KXxWd+HypWIIv80TLrMzoEqRni1vKsaxvFsR3lYGNFgE3nO1
KAHH8lkWxhug4ilfVP5Vgkl5WXFLR/WYYsJq69hTig2/H3m6S6nHQa6nm4fX
c2SbTnRzKdLDUf2HKiK6HLVC4bu9m/WQJtYds7Ctwguheb0kT4caXqnCTS9C
iMOZsyt8RuBdnGI150EjBuesOV0zaRjZr/KbS1Y1o8avouIJcwiPCj/MKf1N
Au4HJ35S3wDYSzh9JfQn7D05dXun+Zg3+t+2Dacxqb4o8emMfjBOLtyZFiSF
x7szMVEb+mDOx5fkuXJ0L4405Qp6oT7oJ3gysw22r6XiayotzIrD7bZ/V+KA
Xht2z08L6YHVzg2idmi7RbF3hRpksufGx5V3Ir1M1rVgugYJM2clX83oRuaE
cwmc7B54WLMlujQ1OFFHZxfY9+BzhZZ3qqwHs68WMN/7qlHk+PnRn7c1mHzZ
XB8T8Q2J/bW51TljnfGrOZlnuxEc7R23N60Xe/arXKLedME1tLRTmNqHrF+b
bM1MurDlcgY76Hg/Yo7Ksy75dyI3dsjXN3IATbrCpe65HZDUBrFe7R7E2nlX
a5JH2uFSuV7A3zgE90WMHx+EtKNFn2N8z3MYQWHnFbveq7D/Yb952MIRVJvu
btYSFWaZNWt2OOvgdMt3QvBzJd60FB4yctLDCqcNajclGjr63o5MMWCyf9LW
xoI2fMspN3CMvmMwbmAdx6cNg+/SGscZviNhokiorFPgpzvKJEfVKDwfXfQb
3KbAWrpe77eTQW56WWnH6eSg8vJTA+QMwg6cobiVLsebyrVmuk1GJFJanamf
Lwf/0j5xtNiIeNgFPHZukCHg5dbMFC6TuOY4qF3jZRBNGCxcU8Ek9Sdeinud
ZVhsbcWWeRmTTk1ZSVmdFMIITapdgTEpEWXrvA5JwU4OIFM5LOI3XMU3cpGC
WxwS+Pohi4Rb5fFtJK047LOI5/CzCflc1BQjTm/FjZNni71yTMg11p0vlita
IXZ8wBi1MyW7/jX3jTVuRWnLwfzIVFOisTH+6PKSxnlu7d18M4rYrORxkhNp
JNh8+ufvwxRZUm3Ts9KHBvMrLzwzkSIfN4VleHjTSMlTeF8/SpHyoguBroRG
hoe66/FximxpDFtj7UXjbjBzqSSNIln7fpG0LqIhvu+innmdImFZjhHJ82jM
Xx67ovoFRXqCt/JoJxpFliP29eUU+brbKkDsSMNTckTbUkmRDrYo9K0DjZXh
Kde6aijSLHDvfWZPY9u5K72T6ylSuXNu7pUpNE59qRCEfKWIzpvF2zZx7Ed5
y2PDWymy47hJ1CZLGhejRf5xMorUJ94UrLegcYPV3M9XUiS/KTvU15xGCVu1
6rGaIn3tiuRZZjRIX/i0Ug1FFrx2EsygaFQ/1wxU9VJkGavmo6MpjYZ1uuyW
QYr4yt2LrVk0Nk5NipcOU4T/qjfQ0pjGJxmL26WjCOKZ9j8waYTc5zsPGCgy
/fzmUZYRDWWcxdDoKEXSqoaMGQwa/wHUy2Xi
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxX040wkcAPDZxm+zFV1vlN6cjqYnT1GEfL+UzNXo9OjtJIQeJZKXHtRF
UljiUGTRHXlIlt6cRHlJUhR1ydyFa/Zr1tQY8zazu/vj83xWBYR7BVEpFMrO
//y/YDcd1puJwWX54K1+RzZSLtodSfcVQ45ZROXBfhYyihc4vw0Sg//VLJrP
exYa1g8vWXhcDPOXCnQPv2ThqomyN9fjxSDSi/iS9oCFLkeMN1XkiSG+cpmJ
cwoLk9ym6W3vxHBZd2mckzUL9Rh1RQy3AejS3qE5ZOgjOxX6kqwkIDu0kLb3
IBPf391aEGgrgWMp3LtRu5koELn5uIIEzmeen5vvzkSOxa6/9DwlgFfdH6s3
MpH7wu9DapgEXAdDu40NmJise+5NhlAC1vqnc2uaGDib2PxUYEmCZiaSx7Ni
oCLO/cYD888gTQxZtsyEQEZN6OLDs1IolP8W3bxHF8WxO00722Rg8yGqcV4P
DXM4VqdiGuQQfVuk0omk4mlzy6Tr2V8hJjzX9bqnDjos4PSo0xWgKTYz7NxM
wd5Gpd+l+mGQyYzu0bNm4dGK3rsHSkfgB1o9X0DRwFlVa8nzIiVkRl4J845V
g3+Ec8yJ9FHgyevpeVbTsC6oVl7NH4M6861d5+ST4JOfzfFNVsEcQxdh2KsJ
KIme3LYtbBxqePyMkD/HoafVl/7i6AQItcFUt14VWDT9dCN1zyT41rbUxjFV
IJopot3eMgW9R9vV3dwxiKpUsUPspkFLzg/qvTAKloyukWBTNaRduz0V26eE
16KqeJ2VM3Az4v05bxsldH4ZezNtpIHYbAPur3kj8K2oQWOtMwsehYWf/A1H
YOJd+lumZhZu6lutrEoehqW3pAkrBrWgvVCyboo1DJ7/dMy4H6Hgolcz7Qmb
FECUVfC9JBQ08Jx1POX5DV43eTLU+3TQdrtFc1HSV0i9Ftkd0a2DzzhGa8Lv
D4HXs4M5KTwqzrG7H8udkkPbnIkqj0YqUl3L/PN3ysF+wTzOgBMNWytL6bH5
X6D6+Ah/8UMaRoWUR2+ekQEnyQuXWNPR+G/K6659MuDVBOxvr6RjwvjDHeyG
QTjjstlvuZkuVhvbV/fZDkLxxcwapyJdDHxixxaWS6F7xR2KdrEehhY63Uxb
K4VaUVxFGF8PVxfHM8VVn+EKr7W8gkHgmk9NNsH2n+H0wo9X084QWLDSRNnR
RgK13y805yyBtKxXMvlLElLKSOfCRAKd249tZLSSkO2gGLqXTGCnh1WrczMJ
5f7UrT3pBILJ/p5HdSR0Cy0U5oUEhlFcc/8QkrBhe7Tb86cECrOPyxUZJDwy
mDbpaCBQj1tju+gyCVt6flGKmghcn7mjy/ESCdzQlIKhFgJlTsM0fgoJh7IE
o/M7CPT/WbnWMpGES32NNwL6CQw2fiCIO0nCd2Xbo0M/EfgkqFxZcoKEvIi2
H2MGCGzRL7j2NoyEYnqXKlVKoPSCafeaYyQ85gzuuKcgMJw8ObfvMAk4Frqq
doTAQ4HMAVYACc+fjIw3jxLYgZN69n4kdO5S/y6aIPB7o8uOuT4k7FmScEo8
RaBDKduj5QAJHwfovCE1gTZ1WXdU+0gIEKaajmsI9NjA9l29lwRpzNxJrZbA
Unmgj7c3Cf8C3s1Iww==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.5, 0.5},
  PlotRange->{{0.1, 3}, {0.5000000073979592, 3.5297234796487666`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549740774558662*^9, 3.5497956837148037`*^9, 
  3.549876030333724*^9}]
}, Open  ]],

Cell["\<\
As marginal cost increases, the prices paid by the high-demand and low-demand \
consumers converge.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Third degree price discrimination", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Consider a two markets, each with linear demand curves.  We saw that \
sometimes it pays the monopolist to just sell to one market; when will that \
be the case?  Ideally, we would like a graph that would show us the good and \
bad regions.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
x1[p_,a_,b_] := a - b*p
x2[p_] := 1 - p\
\>", "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We know that if the monopolist does sell to both markets, the \
price will be ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["(1+a)/2",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  So all we need to do is to graph the set of points where this \
price makes at least one of the two demand functions negative.  One way to do \
this is to solve for the values of ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["a",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" and ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["b",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" where the product of the two demand functions  is negative:",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Solve[x1[(1+a)/2,a,b]*x2[(1+a)/2]==0,b][[1]]
ParametricPlot[{a,2a/(1+a)},{a,0,1}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"b", "\[Rule]", 
   FractionBox[
    RowBox[{"2", " ", "a"}], 
    RowBox[{"1", "+", "a"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.5497407746846695`*^9, 3.5497956838023047`*^9, 
  3.549876030412475*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxdlGlQk1cUhiGioARU2gZBUSNoRUdja8W69W0pAqKxsll1QARRiVMXZBtE
WlDigpFSoyBKrRUiGDUFS7FqpAiYEJU1aCBgJBCyQJKrBdGKwX4dmf7wzJx5
5znzPvfnZUbtCdpGs7KyYlP7X74/UUMM2RGXzyDIHGvod/bBO/ZBYHm4/xZG
yAiHAF+QmiUfRI9wNK6cZpQRevwIx+OjuvTwHVYZI5yBXbHOiVwdf4RPQTfx
QG5yeQFkQcFWz54XIuV3Z+miaWVIfbXwmu/U3+Dmf86mNfQOVGy/n6qPlyFM
lMu12FRjwYOTutyBm2i0WXnNmC1FY8nOw9bWfyHllaPD2aIHcIrce6FheRWc
5tuun2JqwFSDjGww1uDU9bSVD4eaECjgdF/dJQWf98uQuE6OzUmtGteZ9zF+
k+mE6o9HOJl6IjNY9BDDlcVTAnYrMHtU5EXJnAZMF1jN/m5CG9gN1prL5kYc
D9hnd1KqhMviwdpHC5qRbDcnPzSkA82ezWWOWXLkyKViw8ATLA+706bRtGB6
c0RfW9pT3Cp+sO6Cx2NcTsnLSY/rhEfa3fqYHxTIe7so5AVLjYuxyvOM6laY
SkqXCpVqOJiVCU1MJUSDYC/L6oKnsJfrub8dwXkuj1cv6cbGNDf99tsdWL8o
73xMSzcS1IsDS51VCLhzgKtP0kAQlkBXhz2FPdvm/kZ6D6rtI60U7E5Ib5Tc
ZJztgXD+kKX6dSfoXl6fS1lanFNdKnTPV0PUtTTu/g0taCGS+rGruxDWqN62
yU8Hb86u0xWDXVjhU/GE16gDz37WaG1ONyYr6+ex2XqsiQt6xffRILtccdir
SQ9GTPapMq0GbbXfM9asMuDPN6F1BdwezKUbJniLDWha/+Mxl0+1aIkSSEZ7
9aJ/hdJsLdfiiOabYnNhL3i9ZxR703Uomex8L9i1DywPDifIQ4/WtTueR3D7
ILRU5tJq9Oj2decN9/UhP5+3akmsAcfnWn8s22BEbi2nsMupF3s5Frmd2Iix
t24ddKqiWO8nnDfThJDVfMuE3X3gK9LU9EwTijmpzIOORpxoIQ+naE2IY7fX
JlNe5KRknczPDL+KABfNZhNsOrIqxvxqxkD9V2Pchk24507LEQ+a4Sy4mtgh
NGP6NlF5XSCBj51ntuMagmNuPem2AgL3aH2oai1BeflQeNIlAlpl0WQR1fN1
3eGiKyKoTJpVxP6WILCIPV8iJFiuc6/gRRHMTpU3HiwhWCiZahyXTOB4nffm
xW2CGRkf+ttS76zoVNNrmgmsO+UOimICrf3zdlYLQecyvvzSFYKgKlXmuUcE
5/snRviWEhS0bD+6r5XAdev4RK6Y4OKxC7RpKoKJ3uMKR8kJkvh7XsYaCJ79
LOPIKW/P/mhJey9B/T9HWQWU94kwJWGlkYBXanvbm/IO3WTGTyIEdszRzemU
p/+6ql88QKA7UJMbSPX+noGamYMEktZD4Uyqt7PrbXzWS4KMbJqhkurFVIYn
Rbwm2Gq8K8qm7pZlo2TSIQJv//T4LdTdLcjymmUhYBZ+uXQBlYmsdQ5nhgne
/VrP/s9/AZ2cdRA=
     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 1.}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5497407746846695`*^9, 3.5497956838023047`*^9, 
  3.549876030414975*^9}]
}, Open  ]],

Cell["\<\
Or we can compute an indicator function and do a density plot\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
indicator[a_,b_] := 
     If[x1[(1+a)/2,a,b]*x2[(1+a)/2]<0.0,0,1]
DensityPlot[indicator[a,b],{a,0,1},{b,0,1},PlotPoints->50]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJyF3XvIfVldgPGXUIguGCQFQplRkBEFUUFBvYVBVwwywj/CIoukqCgsDDJC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   "], {
    {GrayLevel[0.8], EdgeForm[None], 
     GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxMnXW4lNXXQO/0zA27u7uLFBEQUVTsbjEACxMDxe7u7u5A7O7u7u7u/Pb6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       "]]]}, {}, {}, {}, {}},
   VertexColors->CompressedData["
1:eJzt2bGuTUEYBeCToxAFT4DkPskplDpK0Qj17UTUSq3CAyglGo0X0N8noJJI
CAoRFS+gkNx79lr/fNVNvkxmZs/8s87sfU8enN55tN/tdr+u7naX/v59/vPJ
yY2bXw8vXp79vrf/cnj76tqPp28+HzjnPM0ff7z86e77s8P9/e0r1x++Prx7
duv0+7cPcfPknPN/5ZUc45ynubzinLf4/+aVHOOcyyvOOT9OXskxzrm84pzz
4+SVHOOcyyvO+Wq+VV7JMc55e17JMc65vOKct3taLskxzvnUvJJjnK/jaTkj
rzjnq+WVHON8nqfliRzjnMsrOcZ5u6flQ5qn7RfnK3taPrR42j5yvoKn5UC7
p+0v55M87bxP9bR957zR0871ap5WD5wne9r5Xc3T6oHzZE87v1yOcS6vZnha
/XAur7gc41xereZp9ca5vOJyjK/gaeeIyzHO5RWXY7zd084F7/K0euazPa3+
+QxPq3M+w9PqnK/paeeCZ3pa3XIux7i84pM87RxxecW5HOPyinP51uhp9cN5
gqedUy6vOJdjXZ5WD5xP8rTz3u5p+8v5Cp6WAy2eto+cc/kmrzif52l5Iq84
5/JNXnHOu/ItbX04570urzjnU11ecc7b/bxyTHvttddee+21v7j2af2c133D
uMe51xl3zbpKu+en5a1xZ+zv1HHTcpJnetp9dWr7tPOS9j0wbV/a62qre/jU
c5FWzy39pO1X2rhyKTOv0n43W+az1fx55rlLq6ut5r/afNKeNy2X0p5L//pP
uPe2vIfqZ9v32ZZ7ztT309XeU1q+a7WsW4u35GrLdxue+b0rLZ9b1r/9d7B9
PtZhzXHT5mNc4xo3Z9y0+aw2btp8rEPXfNrf9/Wvf/3rX//b9j/1uaxb13Ol
jWv+s++xnE/y9v+X6Uc/+snvx/zX3EfOGz3tftX+PtiyDu3j8sz3pnZPW3/7
xdU555xzPuNelLY+nPOL8z/AXZDm
    "]],
  AspectRatio->1,
  Frame->True,
  PlotRange->{{0, 1}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.549740775020688*^9, 3.5497956840310583`*^9, 
  3.549876030672479*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{747, 956},
WindowMargins->{{Automatic, 17}, {-1, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP\n\
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 71, 2, 123, "Title",
 Evaluatable->False],
Cell[653, 26, 100, 5, 71, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[778, 35, 92, 2, 105, "Section",
 Evaluatable->False],
Cell[873, 39, 233, 6, 90, "Text",
 Evaluatable->False],
Cell[1109, 47, 122, 6, 111, "Input"],
Cell[1234, 55, 144, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1403, 63, 188, 6, 111, "Input"],
Cell[1594, 71, 583, 21, 111, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[2192, 95, 503, 15, 91, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2720, 114, 83, 1, 43, "Input"],
Cell[2806, 117, 3204, 59, 364, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6059, 182, 99, 2, 105, "Section",
 Evaluatable->False],
Cell[6161, 186, 346, 7, 115, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6532, 197, 260, 8, 156, "Input"],
Cell[6795, 207, 300, 9, 62, "Output"],
Cell[7098, 218, 3889, 71, 360, "Output"]
}, Open  ]],
Cell[11002, 292, 169, 5, 66, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[11208, 302, 98, 2, 105, "Section",
 Evaluatable->False],
Cell[11309, 306, 310, 7, 115, "Text",
 Evaluatable->False],
Cell[11622, 315, 89, 4, 66, "Input"],
Cell[11714, 321, 988, 33, 141, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[12727, 358, 131, 4, 66, "Input"],
Cell[12861, 364, 244, 7, 62, "Output"],
Cell[13108, 373, 1966, 39, 543, "Output"]
}, Open  ]],
Cell[15089, 415, 131, 4, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[15245, 423, 174, 5, 88, "Input"],
Cell[15422, 430, 71117, 1176, 543, 62078, 1026, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
