(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     17172,        625]
NotebookOptionsPosition[     14333,        520]
NotebookOutlinePosition[     15110,        547]
CellTagsIndexPosition[     15067,        544]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Game Theory", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Computing Nash equilibria", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Computing Nash equilibria in a two-person game  is a straightforward but \
tedious task.  This is the kind of thing computers were made for.   Luckily \
John Dickhaut and Todd Kaplan of the University of Minnesota have written a \
Mathematica package to solve for Nash equilibrium in two-person games.  Let's \
load it into Mathematica and try it on a few examples from the text.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["<<~/",
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox["/MicroAn/Nash.m",
  AspectRatioFixed->True]
}], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Get", "::", "noopen"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Cannot open \
\[NoBreak]\\!\\(\\\"~/Mathematica/MicroAn/Nash.m\\\"\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/noopen\\\", \
ButtonNote -> \\\"Get::noopen\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5500555416153445`*^9}],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{3.550055541624095*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["?Nash", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Information", "::", "notfound"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \[NoBreak]\\!\\(\\\"Nash\\\"\\)\[NoBreak] not \
found. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/notfound\\\", ButtonNote -> \
\\\"Information::notfound\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5500555417440968`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nash[{{{2,1},{0,0}},{{0,0},{1,2}}}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Nash", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.5500555417865973`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dominated strategies example", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Nash[{{{3,3},{0,3},{0,0}},
      {{3,0},{2,2},{0,2}},
      {{0,0},{2,0},{1,1}}}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Nash", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.5500555418240976`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chicken", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Nash[{{{-3,-3},{2,0}},
      {{0,2  },{1,1}}}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Nash", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "3"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.5500555418615985`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coordination game", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Nash[{{{2,2},{-1,-1}},
      {{-1,-1},{1,1}}}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"Nash", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "}"}], "]"}]], "Output",
 CellChangeTimes->{3.550055541901599*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving for Bayes-Nash equilibria", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["We can use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" to solve the differential equation that arises in the text.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["DSolve[V'[b]*(V[b]-b) == V[b],V[b],b]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"V", "[", "b", "]"}], "\[Rule]", 
     RowBox[{"b", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          RowBox[{"C", "[", "1", "]"}]}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"V", "[", "b", "]"}], "\[Rule]", 
     RowBox[{"b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", 
          RowBox[{"C", "[", "1", "]"}]}]]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5500555423891068`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["We can use the same analysis to solve the symmetric game for other \
prior probability distribution on ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["v",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  Let ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["P[v]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" = probability that other player's valuation is less than ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["v",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".  The payoff to the first player if he bids ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["b",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["(v-b)P[V[b]]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["; ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["b",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" must maximize this expression which yields the first-order \
condition ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["(v-b)P'[V[b]]*V'[b] - P[V[b]] = 0",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".   We can use ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSlant->"Italic"],
 StyleBox[" to solve this differential equation, just as above.   Suppose, \
for example, that ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["P[v]",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" is the exponential CDF",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["P[v_] := 1-E^(-v)", "Input",
 AspectRatioFixed->True],

Cell["The equation we want to solve is then", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["DSolve[(V[b]-b)*P'[V[b]]*V'[b] -P[V[b]]==0,V[b],b]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Solve", "::", "ifun"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Inverse functions are being used by \
\[NoBreak]\\!\\(Solve\\)\[NoBreak], so some solutions may not be found; use \
Reduce for complete solution information. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.550055542532859*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"V", "[", "b", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "b", "-", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "b"}]], " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", 
         RowBox[{"C", "[", "1", "]"}]}], ")"}]}], "]"}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.550055542535359*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" doesn't know how to solve this ODE, so we try a numerical \
solution. ",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution=NDSolve[{(V[b]-b)*P'[V[b]]*V'[b] -P[V[b]]==0,
          V[0]==.001},V[b],
          {b,.001,.9}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"V", "[", "b", "]"}], "\[Rule]", 
    RowBox[{
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.001`", ",", "0.9`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False], "[", "b", "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5500555426428604`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot[Evaluate[V[b]/.solution],{b,.001,.9}]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkHk41HkAh41yzlRbT+jQwdKKPRCKnXy+i5QdQvKI6JhNiixRrlYphZ7K
lWuRylViHYnIjFDOVSGRMBgMo1+Mo4MR2/7xPu+f7/O8Kmyvfa6SEhISVt/4
35cfKYcdZdtgh22momrjH3hUMF/TIdiPdX6lNIrrhqEHPYssD0dscQ+e6H3r
gXSbl8z1Rkfxla1C26/pA9ruyFIpU3ewtDKrr40FoX+tjL2nph/yxeHLl7mG
wTrUVE1l42U0WRwojmPGQaZsgC5Wugl9lS2zDkYZKE+YajrjkAFadoKTfVIx
dKqTC6v/ysMrY4Pb/XJcqMdEpn/35CEyN1m6MPWfoTvDu0068TGuWzE3TDs3
wHc8q21kMwdfxVyvzp0vkLLMOFUmrAoxM0NN3latyCrqm9skqkGtFle6bvY1
bk8+qP5HuxZ/i9rjKy92oCDdvIJ3tx4tIYl+jqwuFE7QN1wRNkJ9V9+4pagb
Dk3hmoXqzbgSeGsgKJYHBcV29/OxL6G72Jq3ldsP/kKm3IB7Czj8tJu7NvJh
qrXHvz2zFc4hDRHijEEEpNUZyXe1wT/G9/SnrcPI7nN8GPTlNUITg66mpgpw
yNH+GVP7DaIUy0XJBqNYcdc1wtCuA9lmcjraXCFYKjxBeGQnHlmknrni+R5O
ozopa56/xRs3B1vupg9gBycvGRrqAn+i13pl5ThmfveQom3sRiTzRuqCmQgX
BDYVB0x6cEfikC9dZRK8hpX1U0d6wcv9V3n9wiTqB41O8RJ5SHMN3MKamUJO
c0Dt0id9kJIKJZ7906D7r3A2DupHp12JW/vIDLS0bEJSVg9Agb76Y+zUR+w2
T1mIzxxArveknuH0J+QEJ1uUEz62siLYrau+QEY5czywjY9j0QJ+mcYsXrmk
VB48OgjPlIi8OpM59FSYHzw+P4h1qpeOJYWIMRwyb7v8xhBqaaIyw5J56LGP
K/R9+8bx2fzRZdUCLjx4p2vFGYan5VDpNbdF6CUwz/WwBFhszi8ZZ0uQn9P2
RceNCKCUO7W9W5NG1Jb5LgoDRlBcG7/t0wSNHEna/esJxVF0PK56mdUmSaTr
5dJlikZBZ+VOB1QtIfedO9hmvwmR1OiRYJC/lEQtdxDl9ArBs793x+e5FPH9
gd+Z5zWGzq8no9X7pEnVoNNYy8IYfokSH3NbLkvsOOGNG5LfY6mBxVXOOTnC
F1dKympRMG4snlealyctzU8Von6iIDaxUDJeQifcW1UaitoUdnK2BZ+Qp5Mk
1OxV06eQZM0hTWvoxDq0NpmAgv7J68Y1+nTCkW/WDbSjoLeXEkV400n82i72
2DkKO+4/Hb4lpJNLY11nT5+nICyqknecpBPvincRX0Io3Ki4aLp2lk4sXXry
pcMoWJ99IZ8jyyCSd/vmVKMpqK4zaJDWYJA/NQSxBzMp6Jj/OFrtxiDOs4Is
fjaFM7o2Pa1eDGLRNFJ2ModCkdnY4RF/BlE7JeT551OQYH7Q/z6CQboLKM24
MgoaC59X9d1nkIaQDzvXV1Bgxub5KBcxSKntuE06l4I65XXvcDmDxE5P+BXW
fOvNnS/+3MggIc9FV7fXUih/GJBq2cYgnvGTqZX1FLoMe4PvvWMQp+NTBbua
KNTFhB6RHWSQPduna5qbKZRwTKy83jPIf2HUa70=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0.001, 0.9}, {0., 3.6149583850852545`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.550055542734112*^9}]
}, Open  ]],

Cell["\<\
[Note: their appears to be a singularity at b=1.  I'm not quite sure why, but \
I suspect that there is something funny about this solution.  I should look \
at it in more detail, and probably choose a better behaved example.]\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{832, 956},
WindowMargins->{{Automatic, 11}, {Automatic, 4}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP\n\
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 74, 2, 123, "Title",
 Evaluatable->False],
Cell[656, 26, 100, 5, 71, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[781, 35, 90, 2, 105, "Section",
 Evaluatable->False],
Cell[874, 39, 449, 8, 139, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1348, 51, 228, 9, 43, "Input"],
Cell[1579, 62, 460, 10, 35, "Message"],
Cell[2042, 74, 76, 1, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2155, 80, 47, 1, 43, "Input"],
Cell[2205, 83, 463, 10, 35, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2705, 98, 77, 1, 43, "Input"],
Cell[2785, 101, 471, 16, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3293, 122, 96, 2, 54, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[3414, 128, 131, 5, 88, "Input"],
Cell[3548, 135, 837, 28, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4434, 169, 75, 2, 54, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4534, 175, 96, 4, 66, "Input"],
Cell[4633, 181, 519, 18, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5201, 205, 85, 2, 54, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5311, 211, 96, 4, 66, "Input"],
Cell[5410, 217, 565, 20, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6036, 244, 98, 2, 105, "Section",
 Evaluatable->False],
Cell[6137, 248, 388, 14, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6550, 266, 79, 1, 43, "Input"],
Cell[6632, 269, 709, 23, 61, "Output"]
}, Open  ]],
Cell[7356, 295, 2149, 80, 168, "Text",
 Evaluatable->False],
Cell[9508, 377, 59, 1, 43, "Input"],
Cell[9570, 380, 99, 2, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[9694, 386, 92, 1, 43, "Input"],
Cell[9789, 389, 531, 11, 94, "Message"],
Cell[10323, 402, 490, 16, 48, "Output"]
}, Open  ]],
Cell[10828, 421, 325, 12, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11178, 437, 155, 5, 88, "Input"],
Cell[11336, 444, 452, 15, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11825, 464, 84, 1, 43, "Input"],
Cell[11912, 467, 2082, 40, 363, "Output"]
}, Open  ]],
Cell[14009, 510, 296, 6, 90, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
