(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     30953,        746]
NotebookOptionsPosition[     28638,        663]
NotebookOutlinePosition[     29417,        690]
CellTagsIndexPosition[     29374,        687]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Oligopoly", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Cournot equilibria with linear demands", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Let's draw some pictures of Cournot equilibrium with linear demands.  We \
start with the following inverse demand functions\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
p1[x1_,x2_] := 10 - b1 x1 - c x2
p2[x1_,x2_] := 10 - b2 x2 - c x1\
\>", "Input",
 AspectRatioFixed->True],

Cell["The profit functions become", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
profit1[x1_,x2_] := Evaluate[p1[x1,x2]*x1]
profit2[x1_,x2_] := Evaluate[p2[x1,x2]*x2]\
\>", "Input",
 AspectRatioFixed->True],

Cell["The reaction curves are determined by", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
solution1=Solve[D[profit1[x1,x2],x1]==0,x1][[1]]
solution2=Solve[D[profit2[x1,x2],x2]==0,x2][[1]]
r1[x2_] := Evaluate[x1/.solution1]
r2[x1_] := Evaluate[x2/.solution2]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x1", "\[Rule]", 
   FractionBox[
    RowBox[{"10", "-", 
     RowBox[{"c", " ", "x2"}]}], 
    RowBox[{"2", " ", "b1"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.55005549834593*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x2", "\[Rule]", 
   FractionBox[
    RowBox[{"10", "-", 
     RowBox[{"c", " ", "x1"}]}], 
    RowBox[{"2", " ", "b2"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.55005549835093*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["If we fix the parameters, we can plot these isoprofit contours.  \
We will set ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["c=b1",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[", so that the two goods are perfect substitutes.",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
b1=b2=c=1
isoprofitLines=ContourPlot[profit1[x1,x2],
{x1,0,7},{x2,0,7},ContourShading->False]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.550055498394681*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJyFmw+UXFV9xzeTye7s7sxmZnZ2dv5BjIpARSWtYio07xKKPVKQEI5ViICk
Uk8hEaEoTRvOmZoYpVoQoWgFUqCCWKsiKkQJuCQoaFoJGCGUfwEWmIS4TJZl
mWyG2Dfv3e99vs92jvfMyW+/c++77/7+/+69k4UrL1x+XqKnp+efkz09Hfr/
t11eHDeBW8A9Jg6TwCngNHAWOA9cAC4Cl4ArwDVgNfFJ2gRuAYtf4SRwCjgN
nAXOAxeAi8Al4ApwDViNfDW70Baw+G2C3yb4bYLfJvhtgt8m+G2C3yb4bYLf
JvjtZqfUI/kkFb8t8NsCvy3w2wK/LfDbAr8t8NsCvy3w2wK/3fyQdko9kk/S
JHAKOA2cBc4DF4CLwCXgCnANWI1+R7uk3shXsgtNAaeBs8B54AJwEbgEXAGu
AasxrtDvaJfUG/lKdaFp4CxwHrgAXAQuAVeAa8BqjJuMK/Q72iX1Rr7SXWgW
OA9cAC4Cl4ArwDVgNeYFxk3GFfod7ZJ6I1/ZLjQPXAAuApeAK8A1YDXmPeYF
xk3GFfod7ZJ6I1/5LrQAXAQuAVeAa8BqzOvMe8wLjJuMK/Q72iX1Rr4KXWgR
uARcAa4Bq7FuYV5n3mNeYNxkXKHf0S6pN/JV7EJLwBXgGrAa6zLWLczrzHvM
C4ybjCv0O9ol9Ua+Sl1oBbgGrMa6k3UZ6xbmdeY95gXGTcYV+h3tknojX5Uu
tAasxrqadSfrMtYtzOvMe8wLjJuMK/Q72iX1Rr5qXWjbrr9q8XYvTtWEBzBu
CDjXBasNo38Y/SPoH0H/KPq1ngbW08D7G3hfA/ML91o8hfmnMP8U5p/C/FOY
fwrztzF/G/O3MX8b87cxv3DCxGkv8ADwEHAOeBiY85IOAA8B54CHgSkXrpvv
IR0CzgEPA1Pueh/XzXmHutAcMPWYwDjKhevmvKS0O9qJ3kc5Uw7CQ8C0Y9qd
5hfuBR4AHgKW38mvp4DbwHqfcC/wAPAQsN5XxvuE28B6n3Av8ACw4pLiaQNY
/TynUv9Ul+eZbzhe/Vqv+tvo70W/xqt/AP3dqMYzT6TxfRY4D1wAlp44XwPz
NTBfA/MJK99KTmngLHAeuACs+dqYr4352pivjfmEVR8kTHx+4TRwFjgPrPmk
5xRwGjgLnAdWPSO7SAKngNPAWeA8sOaXnyaBU8Bp4Cyw5lN8TAKngNPAWWD5
m6tTTBwngVPAaWDN5+oaE8dJ4BRwGrgJv2nRj0wcJ4FTwGngJuJhC1jzCyeB
U8C7EL+awJpPOAmcAq4Bj3kxWs/Hv68XuozT89PAB+OY1DXNIz1r/j8UBw5i
XepXXT/VBavO1/Pqb6Nf/Ajree0LDqK/jf4GsPiS3DW/+mcgv0ngKeAZzGdp
nfq0rY5zljrPIfQ95q9jf+rwNN5/MI7rsLM69yuSu81fdfnlGLCa5C0+ZmA3
M3huGvqVPEcxfhT9ZfQL7+0iD+hrVj0gv5X9KF93q3u2YzzrPNZhDYzvVpex
ruG+h3Ui6zjWqawjNT/rOtaROYwX1vzD6B8G1bgycBVY8452oWXgKvAQxvG9
nKfaZTy/Fx60dBx6UxOW/UjOso8UcAWYeYN1p+bnOaPsqQQ8BbvpRnluxX0B
z3n4vPjU+xOWMg9rvRqv+WhfeWCee1GvPPej3fCciPbD80PaQwXjea5Ge9F7
WLewDuu3dKftH+oyXng4jl1cnURcYB1m7c6N13tZJ7Ou1biMpYPArFMzcaq4
6+Kv+m1c7pkTn7eei+OoLrdN9qw4rvHin/JodbF32WMf1pUCBl8uT2n9kpf0
M4j+NLD6G9CX3it59APrPfMx31Ac11XPT8J+hOea+DoSwPMsFf+9wN3OTXgP
ZfudfjLA3Nco3uk948A836T+pxGHJAfpV3ITn5PQRxPzqU6zzzu58pynEMeu
rhnE+CGMH8J4yrcF/57G+lqwP61PdiN+++L97n12XJ37fz3PcyvFD62/H/1p
9Evfet804tc05K/1ws5dHbcTdZ3qSsVxa9fOP6U37V9y8fk0Ts87WgUewXNl
jJPe9tj1WH+tyx6UV8ax79A45Rvrdy5eFuLPa5yjmkf61b5Bcp0BZZ0vOxKW
HGEfTh/Sp+xAWH68J+4vavVB9Ge6jJc/9GL+/jh29qLxA+jHepx9K790O49R
3JCcpA/ZM+Or5pO8JmHf2pdonNYnO2f+FGb+4/pl18hXDjM/UX7Yx8/ad8oO
dsG/FI9hz67OsXw7v8jH8ax7PfpRCeP1nm7nyruwXp6jKx8r36NucHgalOfE
OKcZE1/yD9nbeFzfPS8C2/UbPc97PNX3TWDZ1Riw4qHqKmHFk73gaxLjD0IO
4rcFrPgxB1h1hOKx7L4Sxy6e5YE1vgxaiWM3vgTM93KfILsqxJ/robyqcdwD
+Tn7lzzFP/dLODdz8qU/8B6f9o91GuUtxi+tD78rkn317AvxGHDXOl75mxRx
3uUNvR/7kzFh+z4DHO2X7feyT8mrBax++bHi5ySw6jfFZ8ZrrU94H+xYchAW
vwlLWR8Ta7zyBn+npLwmrLyHeoXnkM7Ox2Ff2yGXBuTXgPxozzznTJj4++Tv
3e7peI4mv+C9YSmO3fslt273qnZ/5uo5jdf88mvFCclV848Aq25SXVdEfzU+
zvml6j/EpR7EIdePc2u3/klgxXnJifd3wsoz49CraBNYfjGO+ZUvZWc7oS/J
W/qSHwiPxPsdH13k3AM513keU0G/1oG8P6sukJ+KT2H5v/AE+JW/CstfZZe8
F1NdJdwPzN/JSM4tYPmF7LcNPR+EnhUXhecCJ7Ae7SM4XnWxHV/n/rQPWPzy
3oP14XTcvpwfyd5QLzp7UlyUvvk7rQbiieZrw85nYOf4HYB7XnJRXJD/4Xep
Y8ITyBfKe/hdsfJHnfW/4ivO54yw8g3PIYRlj9rXyB4lb8Vj3gP/oX0F86HG
yT9wXuT6tV6dk4lf7bO1fvVn0K/183cnuJfjPY5bt9YjfvZBP7J3+KeTl/xI
9sN8uQv2JHsTXzuBtR8Sfs72I747e5L8cP7l7EfymQ86BMzfXRzEumQXfcDy
Z/mB4s1cjJ+L8QmMl/4UX6W/SchZ6+HvCHlOJXlLX+InA5w22aWpheuz7j09
h39mpf+ZfT/ylbd+wP9s8f7nvzstuh/Zc8qF//Dr62QP0e/s//SK5xdf8XzT
u3nzhsnKL2ffb3wgmHC/Nz9os+8vLnn4xNGzLplnrjr0tuuf2sL9bcUEyzw8
+l3yt/+z04pm0U+//bNTvhbtb99y1Ovv3nIx7xcqZu/9H/Q/FbNp7ba71m4r
m8s65K4nvcq5P/5m7toRsyO17c/+5fa93qFBm3b0miW7r16yu2yWzXzj1Jlv
/M67/sr79peuHzWLF6x7ddHiuebkDR87ZPXTVUtzbv0hHTW3f6/TRiwt23UP
mA8F7QXv4toDF9UemGMC8S2O7glCee32Rvb/V/Xkq3i+nXfjzz5hTeaF90Tn
L98fPtb/yA52OTs5Nuh43vuboE16fxK0rd6vH+m0Se9HP+y0HV64vopd32+8
u1Y/cefqJ4puPeH3r9lxkxj/hsUzlibMRX/xZO7S+0vmuSs2vWXiC3PMqhO3
f2r56xVL8yb+/LB5+4Ha8uEvFS0tmaTXnOs1K5aWML5spm/6/pJ3P1qwtGIC
9Z/6qotH4fp7nT2H36fMX1n+Aqjzn9+7L/z6v3Xas27/+h9ffOdPGje/7PpD
+c0xvtH6lhvdJ4f4DU/2HLfXhAnUfdHs+7yFg2c8uLSYNIcFgsb98rLo3mx9
4MCz79VCvY6YzXd3WlQX+sLwXWL2PV7Hi5+e0ria6UjpztVRvfn+gBHxOfv+
rrFm40trNvp6POJ7N23eEN3nPpq59cFPPMV7wbIJ40h0L73h3JL/mXDx/B1B
GzSPX37DzstvSFl7fcLlr1Dfv3XjQ3uN7u+qv7zAX0lU/+++uaOwtJsvjHMZ
E4S/pYOWRnk91E/aFM/ZN3LOvoiG+sy4+Vr/tMD/VBwtBAtNm1ODALPH+lfO
8jtgQv/OWb0PmB3HH+J/eP/W8uQ/jcGZz9574+sur96/tdMOoG5oe6E9J63/
91kanV+G80XnEKH/Zhyf4fcZO24E8h00vz3sh1/dfvaLXmfWax7rMZ/3o/oF
R/Sb4DXX8P5sjjkzaP2mYxUvrRly+g3XGd1PhvEm4fQdfp9w8gngjQmjdYTr
mufWHeLo/uzpp/x21rC1+5S5bd37/M+IWdb3af/Tax5a+b4v7j6qbOmIKV14
3r+fcP6oo4UTT/M/ZUurTt/y93Ceklnfmfa2573Qnkounr7ce/r4Dz5ZtHaf
NIqX0s/hnz7n0BW5iqUFc9KXv5lcc1LJ0qKJx9eS4y+kt9j4Ne0pfwZs1619
1A/Y9bS80L5/5/L3JwOHzpl3PjP5jmcmcf/i+4v0GfD55tn3E/KXQBxnpSzN
WD2lbf7Z492zu1MQDJogfN3RcHVHmIcVL/vMCcU7vvy5ozJG8Vj2GPpLv6UZ
G3cjLDu4d/10/n//MoP8aedbMWBpxtrh7PuKJYGi+q1c3nBx4luvrNpx6Z1Z
s/yZx297ZdWgET9abyfLL1g3ZKmd9+joPmHpP/b7rtLn1ic5av2+EfkSrtp4
+oD151ET1hcvuvpd9UAo5+g+IOD3/GrI9/nR+X+QXk7Lm8c/fvUpx5xRtTTa
14d6jfb9oT8/4vaT0lcoz9fcOeLaoCCa9ta/sPH9H5nQ91XLX9u79Qdf+9XK
n+TNyZ9YdMPPLuk3oT/nnf+v3nHpMXuOHTQnf/dNb/tw9iVX3wfrffglb3j8
yOM35vPmsAdP/+xxhw0Y1RHhe7bbeDHpPRnko7vD9f3Rq3adT4Z1y99VbF56
zMbNop1H919a9z5vcaDQinlm6tb33rP7DS+0W9XLCVsv7bd+1GPtb7+n/B7i
A7YOtnV9MzqP//NOW1+xdNicFgTi6FwrtWBt877PVywtW/vDObVfnyrfhXYc
naf3Xnb8Odv9+sL/Z2reZQ/beBDdR2WXtHat8+tpf/a+BWsb3sLMI2/KPML/
r18xig+SX/j9QW/dV09vXjxQNQNnf/C+bUdGv497+OyOZUf2Feox7/JeOC66
B9j8r5cNfevy6N7gpns6BlMyL66494UVS6Jzpwd2jD296D04j/efX9Mp+K4u
myu3vHbER+fnzILPvXzapkOj8/mgDH6o6X1m3ZGTZ7w3b+Nt09pL3saVpid7
jNUHt1u/GWu6+BTad9oEZcPmjKXRebzmU/7W/ubvO21Tzjz3bKc1vT/+eemv
v7QoZwLy86a3pdBZac6tN4wPr3vyn9CueB4/3zx25gXf+dGj0XnJ6jt+8bbr
VjVt/s3G65sbtd8VP3NNMGxZdH6+spN+N6QtH/MsTYdxZ2PBHBe06Lx8UXrr
0emtveE+6VfReXrw3oVls3NZx7Cf9cK6Ceflijc3b/NuuWb5SUfeMuXd+WiH
oQkvrEtwPu7nIcWHICx+uGze1QmU35X/VW38nAnrqd7RsJ5KJ8M4+ZsR6+/z
zEcm/tZXZdnSgrW7UUuLZqtvTlcuHbHU2tsmW69ukv2NmOOCDcpeT/lH9f95
vvk//vFXvWMCR3jWU7xXPA3EdnTJBOI+NxHK+e6SpSNhfDlQtHQ0rEcPKVpa
Nh2tn/lyydKq3S9l3HrCeNzr7FX2GcaRAZuvDnjaP4T5JjrvDO1xjst/ob8k
3PPhfMPmU/uvvXD/tdHvUYLt7YJXPH8TdtcdDxXMVV//mO/iE1a/hVn2et2q
jsEOGtlrzB79+f0o4H+a3uXHdhgbNm+d+IL/V9PKd9jZu/xhRSCQtKsnZc/h
vnu+W1/4/Fz3/v8DSp7QhA==
   "], {{{}, {}, {}, {}, {}, {}}, {{}, 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNzr1KgmEYgOFXbWu1WmqQBNEDqOwI8gcqhX42k1oVp7asqMChNkkosANQ
8yQiawxcbci9nFq9hov7eZ4XPr5EtV6qRUIIZZqxEOILIVQ5YYtVuu5p3WSD
e/sFFfOrzvhjxb7MEmecss0aL94zOtSsPmhNJ/rGpfmKJmn/cqN33PLpvaBF
dsiT49p9T/fZpUyJD/cjPeaQlO+19IAfbyPOzVP9JWb+0ogu8miOakeTus63
uc0zdfuTvtOnYR9oj3/GzAHwjCiO
         "]]},
       "20"],
      Annotation[#, 20, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0MkvnAEYwOFPjCqhqDtGYkko7sW1Jw7CpaiEWHoxMid7qNGKS7lISEjQ
mxNa/Q9EYmkTYmkr0Sa6uXHRJpZnDr887/vOzJcvE26N1HUnBEEQ01BiEBSF
gmCehVxgMVfYwy1fbOOIvYSLzGGu3ppHda1/OlK9+yEb+J9PWaZyPdGyWwWP
2c8Trivd3OJ9Bnhm/6FB83fO6KeG7L94rufmSUX8ppG/3Zq4zV7+YRJD+mJ+
zK8MuMNsPlCy7uypTNFD7doz+I2n+qQa+2fWco8TzNQbRT32FR9pTJs+f8Ys
7Zv7eMBZFZjnmMaw8nVjv9VfDdvbPa85/n/ohS7cP+ql+TUvdaUNdbmNc1rv
FbV/4DutqiP+TpxSpblKpVqy57Faa+ZOxngPAYNGFg==
         "]]},
       "10"],
      Annotation[#, 10, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{105, 467, 119, 468, 133, 469, 147, 471, 161, 473, 175, 476, 
         189, 480, 203, 323, 217}]},
       "0"],
      Annotation[#, 0, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{221, 1077, 938, 961, 1132, 907, 916, 959, 1141, 960, 935, 
         1014, 956, 1140, 957, 1005, 955, 1131, 905, 1013, 953, 1139, 954, 
         1004, 952, 1130, 904, 1012, 1089, 1090, 1074, 934, 1073, 933, 1087, 
         1088, 1048, 1049, 903, 914, 1019}]},
       RowBox[{"-", "10"}]],
      Annotation[#, -10, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{958, 1020, 915, 906, 1051, 1050, 1092, 1091, 936, 1075, 937, 
         1076, 1094, 1093, 977, 908, 1133, 962, 1006, 964, 1142, 963}]},
       RowBox[{"-", "20"}]],
      Annotation[#, -20, "Tooltip"]& ], {}, {}}}],
  AspectRatio->1,
  Frame->True,
  PlotRange->{{0, 7}, {0, 7}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5500554988809385`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["We can also plot the reaction curves.  Here's a neat way to do it \
using ",
  Evaluatable->False,
  AspectRatioFixed->True],
 StyleBox["ParametricPlot",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[".",
  Evaluatable->False,
  AspectRatioFixed->True]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
reactionCurves=ParametricPlot[{{r1[t],t},{t,r2[t]}},{t,0,7}]
Show[isoprofitLines,reactionCurves]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw11H0w1AkYB/DdjdV62fbFy24/IsQdbryUW0M8T9mkhBJHb5db3HlJ2dFw
unQ5kyjCtNEZKp3zchoTzl6dTZe2Uo3o8lJnZcNtWdFRo98u1nXT7TPzzPf7
+ff541ktOhSRQKNQKKEf9r/8OOaobx2UsxUqHRfniHc9X5R9BdlUJ+/uRb3F
oKFtS66Y1zsHZg3P9617r3cpjJt4NCRN610NXVaxEU8UejdDifsfNbXX9b4F
smuLh0SpXEx7FUxp2fkneEsC2W5OXEzNKhrM9h2CDj4zbI+Sg/bxq2xDtC9g
jIxqvijh4H3xJbWBVAVRLrXqmVAOSndXRb2wmwRRW/rWXVQOjjTIY1LUbyBH
fWeTk5SN8429j7vDZmFSbGdFTWNjfdpC0Pvv38FsBMmccWBjeqJ/fqZyDoR5
TxXTChYqu/34BTwN1Mf5B0WUs/D2qPmj1E3zUFdhO/AghIV3XJaFN1QvwlsH
4/U7DFmYpGyyzehfgjaz8ZJn4hVYNi54vs2ainXON5RDQ0xsuXoiIDiYhh6q
WoUmnIkX17YEmcYuw9no02s2XjND6+0Tv35XbIAhB4+vrHUxw2SHpQetvxii
QpC2d12pKW4usd1cPkzHkqik/iKtCY5EfhY1brwcFVbpWtpBEwzu5ZtoHRgY
W5R54HK/MeLfLOf2SGM8Wld4at9mY2Q0q9RCsQn+btE4MtbOwKK+BvTJN0UP
gTxH4sjA6tLMhQGpGfovTvXEli/HPEPH2IDHTMzN4KRE64wwu2BKUk9l4WQg
+vMTjdBCdrNT9eEu6rZj7XNDdLTcmiNkOLLRfui3PF0gHZ87BmdRZWycqaHq
VksNccUeHfX5Fg6OdUZeYbkaoo1/4843fRw0k1yu+1RigG9T9sUMpHCxh0EN
/9LIAD3ndFerSS7e99odeOPgMhR0/yzbWGqOuynyMYGShrVLftZdthbItBe0
Z0fScHa4S/hDowVq52pGpmRUpDP22HECLfFYmsPVLHcq/lCsCM/rtUTfqspu
9zIK3hXFefUmWaHX+gChaGkJXr5QDodReLjqZPymSpUOxLLQ4eZCHh7xOa50
kS7C7bGbxWpHPtLX3njyz48LkP316jKjVj4O9Jt6h+bOg8W5rIRdASuRN7LD
QxephcOswZfH+1divue1XJWvBta/dOgoFBHYub1hQuutgYvRrqdpCQQuHKoI
X+GpAVqXV8y33xCY1nSU8HHWQFf9htm4AwTGuG5oLeBqIDJ5v5NfBoFOax6M
ur0mIXWq4sxEAYFynmJDehUJF96y9wc1E6gTdNedPE8CNZ7vJmsl0Ce6w6zy
LAnxfXYaTymBV85deiYvIMGlzf2sTTuBEk6C2DKDBGlG6L13cgJFptOXroeR
0KPJd//pKYGVriP0R1tI8EouWeANEdi3tffAqJCEsr/K758ZJjC4oMXHxI+E
ve21cUdGCfSgZ/budSbh1VF5+Y7XBCavSfxcbE9CyNTD+HvTBNYId1WesCGh
ad8TT/8ZAnm5folNXBIOB4w+/GSOwIjLbo86mSQMNk2cv0ASWHjLZt0ggwRf
25kE83kC7yqZFZMGJFQVk16nFon//xYJH9Ma/wVo4yb7
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxV1H0w1AkYB/DdjdV62fbFy24/IsQdbryUW0M8j2xSQomjt8st7ryk7Gg4
XbpkEkWYNjpDpXNeTmPC2auz6dJWqhFdXuqsbLgtKzpq9NvFum46f9x35pnv
fP59/viuFh0Mj6dRKJSQD/dv/z+mOEu86/6i9Ctop5wtV+m4/1kMWVQHz66F
JWeDhrY1qXxuySUwo3++d937JVfBmJFbfeLUkpug0yIm/Iliybeg2PX36prr
XEx9FURp3vEHyK4tHBSlcDEls3Agy3sQPCUBbBcHLtrGrbIO1r6Adj4zdLeS
g/fFl9R6UhWMkpFNFyUclO6qjHxhMwGRTjXq6RAODtfLo5PVb0DUmrZlJ5WD
cw09j7tCZyBbfWejg5SNdanzge+/fwcTYhsLaiob0xJ88zKUszATTjKn7dio
7PLh5/M0IMx9qphSsPD2iOmjlI1zUBfrGxhexsI7TsvC6qsWoLbcuv9BMAsT
lY3W6X2L8NbOcP12fRaWjgmeb7WkYqvJWPEz8QpsvnrCLyiIhrWON5SDg0y8
uLY50DhmGbqpahSaMCZabhv/5bsiPZyJOr1mwzUTTLJbfNDysz4GHzi2ssbJ
BDcVW28qG6KjQpC6Z12JMQ5HfBY5ZrgciyMT+wq1RhjUwzfS2jFQYZGmpR0w
QvyL5dgWYYgxhRn7L/cZIqNJpRaKjfBIbcGpvZsMsbC3Hr3yjPE3s4bh0TYG
VpVkzPdLTdBNIM+W2DMwV98+xu8xE30XJrtjypZjVv6kpI7Kwpx0TnKUzgDN
ZDc7VB/+MBGAvvwEAzTfki1k2LNR3Xq0bXaQjs/tgzKpMjbaDv6aqwug44rd
OurzzRycrqbqVkv10cq3YcebXg6OdkRcYTnr49vkvdH9yVw0kVyu/VSih+6z
uqtVJBe7GdSwLw30UND1k2xDiSne99gVcOPAMqxZ9LHstDbDXRT5qEBJw5mh
TuHxBjNk2grasiJoSGfstuEEmKN2tnp4UkbF40WKsNweczyaanc105WKd0Wx
Hj2JFuhdWdHlWkrBly+UQ6EUHnqs9xOKFhdBLAsZairg4aqTcRsrVDq4PXqz
SG3Px8Nex5RO0gXI+np1qUELH+lrbzz5+4d5MDuXGb/TbyX29xl7huTMwSHW
wMtjfSuRN7zdTRehhfUv7doLRATmuV/LUXlr4GKU82laPIEd2+rHtZ4aoHV6
RH/7DYHzB8vDVrhroLPOfyZ2P4GpjUcIL0cNRCTtc/BJJzDa2b8ln6uBlMny
M+P5BDqseTDi8pqEC2/Z+wKbCJTzFP5plSRQ4/gushYCdYKu2pPnSYjrtdG4
Swn0imo3qThLglOr61mrNgKvnLv0TJ5PgjQ95N47OYESTrzYPJ2Ebk2e649P
CRQZT126HkqCR1LxPG+QwArnYfqjzSSU/ll2/8wQgb1bevaPCEnY01YTe3iE
wKD8Zi8jHxJeHZGXbX9NoBs9o2ePIwnBkw/j7k0RmLQm4XOxLQmNe5+4+04T
WC3cWXHCioRDfiMPP5klkJfjk9DIJWGgcfz8BZLA8MsujzqYJHhbT8ebzhFY
cMtq3QCDhMoi0uPUAoF3lczyCT0SPu6WJX5sEv4BmZMm+w==
     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 7.}, {0., 7.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.550055498927189*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyFmw+UXFV9xzeTye7s7sxmZnZ2dv5BjIpARSWtYio07xKKPVKQEI5ViICk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    "], {{{}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwNzr1KgmEYgOFXbWu1WmqQBNEDqOwI8gcqhX42k1oVp7asqMChNkkosANQ
8yQiawxcbci9nFq9hov7eZ4XPr5EtV6qRUIIZZqxEOILIVQ5YYtVuu5p3WSD
e/sFFfOrzvhjxb7MEmecss0aL94zOtSsPmhNJ/rGpfmKJmn/cqN33PLpvaBF
dsiT49p9T/fZpUyJD/cjPeaQlO+19IAfbyPOzVP9JWb+0ogu8miOakeTus63
uc0zdfuTvtOnYR9oj3/GzAHwjCiO
          "]]},
        "20"],
       Annotation[#, 20, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0MkvnAEYwOFPjCqhqDtGYkko7sW1Jw7CpaiEWHoxMid7qNGKS7lISEjQ
mxNa/Q9EYmkTYmkr0Sa6uXHRJpZnDr887/vOzJcvE26N1HUnBEEQ01BiEBSF
gmCehVxgMVfYwy1fbOOIvYSLzGGu3ppHda1/OlK9+yEb+J9PWaZyPdGyWwWP
2c8Trivd3OJ9Bnhm/6FB83fO6KeG7L94rufmSUX8ppG/3Zq4zV7+YRJD+mJ+
zK8MuMNsPlCy7uypTNFD7doz+I2n+qQa+2fWco8TzNQbRT32FR9pTJs+f8Ys
7Zv7eMBZFZjnmMaw8nVjv9VfDdvbPa85/n/ohS7cP+ql+TUvdaUNdbmNc1rv
FbV/4DutqiP+TpxSpblKpVqy57Faa+ZOxngPAYNGFg==
          "]]},
        "10"],
       Annotation[#, 10, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{105, 467, 119, 468, 133, 469, 147, 471, 161, 473, 175, 476, 
          189, 480, 203, 323, 217}]},
        "0"],
       Annotation[#, 0, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{221, 1077, 938, 961, 1132, 907, 916, 959, 1141, 960, 935, 
          1014, 956, 1140, 957, 1005, 955, 1131, 905, 1013, 953, 1139, 954, 
          1004, 952, 1130, 904, 1012, 1089, 1090, 1074, 934, 1073, 933, 1087, 
          1088, 1048, 1049, 903, 914, 1019}]},
        RowBox[{"-", "10"}]],
       Annotation[#, -10, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{958, 1020, 915, 906, 1051, 1050, 1092, 1091, 936, 1075, 937,
           1076, 1094, 1093, 977, 908, 1133, 962, 1006, 964, 1142, 963}]},
        RowBox[{"-", "20"}]],
       Annotation[#, -20, "Tooltip"]& ], {}, {}}}], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw11H0w1AkYB/DdjdV62fbFy24/IsQdbryUW0M8T9mkhBJHb5db3HlJ2dFw
unQ5kyjCtNEZKp3zchoTzl6dTZe2Uo3o8lJnZcNtWdFRo98u1nXT7TPzzPf7
+ff541ktOhSRQKNQKKEf9r/8OOaobx2UsxUqHRfniHc9X5R9BdlUJ+/uRb3F
oKFtS66Y1zsHZg3P9617r3cpjJt4NCRN610NXVaxEU8UejdDifsfNbXX9b4F
smuLh0SpXEx7FUxp2fkneEsC2W5OXEzNKhrM9h2CDj4zbI+Sg/bxq2xDtC9g
jIxqvijh4H3xJbWBVAVRLrXqmVAOSndXRb2wmwRRW/rWXVQOjjTIY1LUbyBH
fWeTk5SN8429j7vDZmFSbGdFTWNjfdpC0Pvv38FsBMmccWBjeqJ/fqZyDoR5
TxXTChYqu/34BTwN1Mf5B0WUs/D2qPmj1E3zUFdhO/AghIV3XJaFN1QvwlsH
4/U7DFmYpGyyzehfgjaz8ZJn4hVYNi54vs2ainXON5RDQ0xsuXoiIDiYhh6q
WoUmnIkX17YEmcYuw9no02s2XjND6+0Tv35XbIAhB4+vrHUxw2SHpQetvxii
QpC2d12pKW4usd1cPkzHkqik/iKtCY5EfhY1brwcFVbpWtpBEwzu5ZtoHRgY
W5R54HK/MeLfLOf2SGM8Wld4at9mY2Q0q9RCsQn+btE4MtbOwKK+BvTJN0UP
gTxH4sjA6tLMhQGpGfovTvXEli/HPEPH2IDHTMzN4KRE64wwu2BKUk9l4WQg
+vMTjdBCdrNT9eEu6rZj7XNDdLTcmiNkOLLRfui3PF0gHZ87BmdRZWycqaHq
VksNccUeHfX5Fg6OdUZeYbkaoo1/4843fRw0k1yu+1RigG9T9sUMpHCxh0EN
/9LIAD3ndFerSS7e99odeOPgMhR0/yzbWGqOuynyMYGShrVLftZdthbItBe0
Z0fScHa4S/hDowVq52pGpmRUpDP22HECLfFYmsPVLHcq/lCsCM/rtUTfqspu
9zIK3hXFefUmWaHX+gChaGkJXr5QDodReLjqZPymSpUOxLLQ4eZCHh7xOa50
kS7C7bGbxWpHPtLX3njyz48LkP316jKjVj4O9Jt6h+bOg8W5rIRdASuRN7LD
QxephcOswZfH+1divue1XJWvBta/dOgoFBHYub1hQuutgYvRrqdpCQQuHKoI
X+GpAVqXV8y33xCY1nSU8HHWQFf9htm4AwTGuG5oLeBqIDJ5v5NfBoFOax6M
ur0mIXWq4sxEAYFynmJDehUJF96y9wc1E6gTdNedPE8CNZ7vJmsl0Ce6w6zy
LAnxfXYaTymBV85deiYvIMGlzf2sTTuBEk6C2DKDBGlG6L13cgJFptOXroeR
0KPJd//pKYGVriP0R1tI8EouWeANEdi3tffAqJCEsr/K758ZJjC4oMXHxI+E
ve21cUdGCfSgZ/budSbh1VF5+Y7XBCavSfxcbE9CyNTD+HvTBNYId1WesCGh
ad8TT/8ZAnm5folNXBIOB4w+/GSOwIjLbo86mSQMNk2cv0ASWHjLZt0ggwRf
25kE83kC7yqZFZMGJFQVk16nFon//xYJH9Ma/wVo4yb7
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxV1H0w1AkYB/DdjdV62fbFy24/IsQdbryUW0M8j2xSQomjt8st7ryk7Gg4
XbpkEkWYNjpDpXNeTmPC2auz6dJWqhFdXuqsbLgtKzpq9NvFum46f9x35pnv
fP59/viuFh0Mj6dRKJSQD/dv/z+mOEu86/6i9Ctop5wtV+m4/1kMWVQHz66F
JWeDhrY1qXxuySUwo3++d937JVfBmJFbfeLUkpug0yIm/Iliybeg2PX36prr
XEx9FURp3vEHyK4tHBSlcDEls3Agy3sQPCUBbBcHLtrGrbIO1r6Adj4zdLeS
g/fFl9R6UhWMkpFNFyUclO6qjHxhMwGRTjXq6RAODtfLo5PVb0DUmrZlJ5WD
cw09j7tCZyBbfWejg5SNdanzge+/fwcTYhsLaiob0xJ88zKUszATTjKn7dio
7PLh5/M0IMx9qphSsPD2iOmjlI1zUBfrGxhexsI7TsvC6qsWoLbcuv9BMAsT
lY3W6X2L8NbOcP12fRaWjgmeb7WkYqvJWPEz8QpsvnrCLyiIhrWON5SDg0y8
uLY50DhmGbqpahSaMCZabhv/5bsiPZyJOr1mwzUTTLJbfNDysz4GHzi2ssbJ
BDcVW28qG6KjQpC6Z12JMQ5HfBY5ZrgciyMT+wq1RhjUwzfS2jFQYZGmpR0w
QvyL5dgWYYgxhRn7L/cZIqNJpRaKjfBIbcGpvZsMsbC3Hr3yjPE3s4bh0TYG
VpVkzPdLTdBNIM+W2DMwV98+xu8xE30XJrtjypZjVv6kpI7Kwpx0TnKUzgDN
ZDc7VB/+MBGAvvwEAzTfki1k2LNR3Xq0bXaQjs/tgzKpMjbaDv6aqwug44rd
OurzzRycrqbqVkv10cq3YcebXg6OdkRcYTnr49vkvdH9yVw0kVyu/VSih+6z
uqtVJBe7GdSwLw30UND1k2xDiSne99gVcOPAMqxZ9LHstDbDXRT5qEBJw5mh
TuHxBjNk2grasiJoSGfstuEEmKN2tnp4UkbF40WKsNweczyaanc105WKd0Wx
Hj2JFuhdWdHlWkrBly+UQ6EUHnqs9xOKFhdBLAsZairg4aqTcRsrVDq4PXqz
SG3Px8Nex5RO0gXI+np1qUELH+lrbzz5+4d5MDuXGb/TbyX29xl7huTMwSHW
wMtjfSuRN7zdTRehhfUv7doLRATmuV/LUXlr4GKU82laPIEd2+rHtZ4aoHV6
RH/7DYHzB8vDVrhroLPOfyZ2P4GpjUcIL0cNRCTtc/BJJzDa2b8ln6uBlMny
M+P5BDqseTDi8pqEC2/Z+wKbCJTzFP5plSRQ4/gushYCdYKu2pPnSYjrtdG4
Swn0imo3qThLglOr61mrNgKvnLv0TJ5PgjQ95N47OYESTrzYPJ2Ebk2e649P
CRQZT126HkqCR1LxPG+QwArnYfqjzSSU/ll2/8wQgb1bevaPCEnY01YTe3iE
wKD8Zi8jHxJeHZGXbX9NoBs9o2ePIwnBkw/j7k0RmLQm4XOxLQmNe5+4+04T
WC3cWXHCioRDfiMPP5klkJfjk9DIJWGgcfz8BZLA8MsujzqYJHhbT8ebzhFY
cMtq3QCDhMoi0uPUAoF3lczyCT0SPu6WJX5sEv4BmZMm+w==
      "]]}}},
  AspectRatio->1,
  Frame->True,
  PlotRange->{{0, 7}, {0, 7}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.550055498934689*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stackelberg equilibrium", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
We derived the reaction curve for firm 2 above.  We can calculate the \
Stackelberg equilibrium by plugging this reaction curve into firm 1's profit \
function and maximizing that.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
stackProfit1[x1_] := Evaluate[profit1[x1,x2]/.solution2]
stackProfit1[x1]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"10", "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "10"}], "+", "x1"}], ")"}]}], "-", "x1"}], ")"}], " ", 
  "x1"}]], "Output",
 CellChangeTimes->{3.55005549898594*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
solutionStack=Solve[D[stackProfit1[x1],x1]==0,x1][[1]]
stackX1=x1/.solutionStack
stackX2=r2[x1]/.solutionStack\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x1", "\[Rule]", "5"}], "}"}]], "Output",
 CellChangeTimes->{3.5500554990321903`*^9}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.5500554990346904`*^9}],

Cell[BoxData[
 FractionBox["5", "2"]], "Output",
 CellChangeTimes->{3.5500554990359406`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bertrand equilibrium", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Do Nash with upward sloping reaction functions...", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1539, 956},
WindowMargins->{{36, Automatic}, {30, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"AVU/IFiQKFD000000V8nh09RAj0000000OXQ<097PXP0AP1Y06`0I@1^0642HSkP\n\
0V97`0000001nR4@0TN2R000000000000000009R?^0000000000000000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 72, 2, 123, "Title",
 Evaluatable->False],
Cell[654, 26, 100, 5, 71, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[779, 35, 103, 2, 105, "Section",
 Evaluatable->False],
Cell[885, 39, 194, 5, 41, "Text",
 Evaluatable->False],
Cell[1082, 46, 115, 4, 66, "Input"],
Cell[1200, 52, 89, 2, 41, "Text",
 Evaluatable->False],
Cell[1292, 56, 135, 4, 66, "Input"],
Cell[1430, 62, 99, 2, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1554, 68, 217, 6, 111, "Input"],
Cell[1774, 76, 222, 7, 63, "Output"],
Cell[1999, 85, 222, 7, 63, "Output"]
}, Open  ]],
Cell[2236, 95, 439, 15, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2700, 114, 143, 5, 88, "Input"],
Cell[2846, 121, 70, 1, 42, "Output"],
Cell[2919, 124, 8212, 155, 572, "Output"]
}, Open  ]],
Cell[11146, 282, 397, 15, 42, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[11568, 301, 146, 4, 66, "Input"],
Cell[11717, 307, 3656, 67, 572, "Output"],
Cell[15376, 376, 11670, 213, 572, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27095, 595, 88, 2, 105, "Section",
 Evaluatable->False],
Cell[27186, 599, 250, 6, 41, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[27461, 609, 123, 4, 66, "Input"],
Cell[27587, 615, 281, 10, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27905, 630, 160, 5, 88, "Input"],
Cell[28068, 637, 124, 3, 42, "Output"],
Cell[28195, 642, 72, 1, 42, "Output"],
Cell[28270, 645, 92, 2, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28411, 653, 85, 2, 105, "Section",
 Evaluatable->False],
Cell[28499, 657, 111, 2, 41, "Text",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
